#
#                      Yeppp! library implementation
#
# This file is part of Yeppp! library and licensed under 2-clause BSD license.
# See library/LICENSE.txt for details.
#

__author__ = 'Marat'

from peachpy.x64 import *


def Map_V64f_V64f(scalarFunction, batchFunction, xPointer, yPointer, length, sourceAlignment, batchElements):
	CMP( length, 0 )
	JZ( 'returnOk' )
	TEST( xPointer, sourceAlignment - 1 )
	JZ( 'source_%db_aligned' % sourceAlignment )

	# Alignment loop
	LABEL( 'source_%db_misaligned' % sourceAlignment )
	scalarFunction(xPointer, yPointer)
	ADD( xPointer, 8 )
	ADD( yPointer, 8 )
	SUB( length, 1 )
	JZ( 'returnOk' )
	TEST( xPointer, sourceAlignment - 1 )
	JNZ( 'source_%db_misaligned' % sourceAlignment )

	LABEL( 'source_%db_aligned' % sourceAlignment )

	SUB( length, batchElements )
	JB( 'process_restore' )

	ALIGN( 32 )
	LABEL( 'process_batch' )
	batchFunction(xPointer, yPointer)
	ADD( xPointer, batchElements * 8 )
	ADD( yPointer, batchElements * 8 )
	SUB( length, batchElements )
	JAE( 'process_batch' )

	LABEL( 'process_restore' )
	ADD( length, batchElements )
	JZ( 'returnOk' )

	LABEL( 'process_single')
	scalarFunction(xPointer, yPointer)
	ADD( xPointer, 8 )
	ADD( yPointer, 8 )
	SUB( length, 1 )
	JNZ( 'process_single' )

	LABEL( 'returnOk' )
	RETURN(0)

# def Log_V64f_V64f_Nehalem(codegen, function_signature, module, function, inputs, outputs, arguments):
# 	if codegen.abi.name in ['x64-ms', 'x64-sysv']:
# 		if module == 'Math':
# 			if function == 'Log':
# 				x_argument = arguments[0]
# 				y_argument = arguments[1]
# 				length_argument = arguments[2]
#
# 				x_type = x_argument.get_type().get_primitive_type()
# 				y_type = y_argument.get_type().get_primitive_type()
#
# 				if not x_type.is_floating_point() or not y_type.is_floating_point():
# 					return
#
# 				x_size = x_type.get_size(codegen.abi)
# 				y_size = y_type.get_size(codegen.abi)
#
# 				if x_size != 8 or y_size != 8:
# 					return
#
# 				parameters = [x_argument, y_argument, length_argument]
# 				codegen.begin_function(function_signature, parameters, 'Nehalem')
#
# 				c2 = Constant.float64x2('-0x1.0000000000004p-1')
# 				c3 = Constant.float64x2('0x1.5555555555524p-2')
# 				c4 = Constant.float64x2('-0x1.FFFFFFFFFD99Cp-3')
# 				c5 = Constant.float64x2('0x1.99999999A037Bp-3')
# 				c6 = Constant.float64x2('-0x1.5555555707EC0p-3')
# 				c7 = Constant.float64x2('0x1.24924922E0177p-3')
# 				c8 = Constant.float64x2('-0x1.FFFFFEE6E9A74p-4')
# 				c9 = Constant.float64x2('0x1.C71C7190489D4p-4')
# 				c10 = Constant.float64x2('-0x1.9999CAC62E0ADp-4')
# 				c11 = Constant.float64x2('0x1.745D4E8088327p-4')
# 				c12 = Constant.float64x2('-0x1.55505B48AD061p-4')
# 				c13 = Constant.float64x2('0x1.3B0A137482D51p-4')
# 				c14 = Constant.float64x2('-0x1.24DCC4EF07DB3p-4')
# 				c15 = Constant.float64x2('0x1.11DFFAEDD082Ep-4')
# 				c16 = Constant.float64x2('-0x1.FB780993249D2p-5')
# 				c17 = Constant.float64x2('0x1.CF5EFF4973CFAp-5')
# 				c18 = Constant.float64x2('-0x1.D0CACFA711D8Cp-5')
# 				c19 = Constant.float64x2('0x1.0BA1125E4CABDp-4')
# 				c20 = Constant.float64x2('-0x1.ED49EDACFD1C0p-5')
# 				c21 = Constant.float64x2('0x1.AE7E3413896B4p-6')
# 				ln2_hi = Constant.float64x2('0x1.62E42FEFA3800p-1')
# 				ln2_lo = Constant.float64x2('0x1.EF35793C76730p-45')
# 				magic_mask = Constant.float64x2('0x1.0000000000040p+52')
# 				magic_bias = Constant.float64x2('0x1.000000000043Fp+52')
# 				sqrt2 = Constant.float64x2('0x1.6A09E667F3BCDp+0')
# 				one = Constant.float64x2('0x1.0000000000000p+0')
# 				mantissa_mask = Constant.uint64x2(0x000FFFFFFFFFFFFFL)
# 				half_exp_mask = Constant.uint64x2(0x0010000000000000L)
#
# 				sign_mask = Constant.uint64x2(0x8000000000000000L)
# 				min_normal = Constant.float64x2('0x1.0000000000000p-1022')
# 				denormal_exp_shift = Constant.uint64x2(0x0400000000000000L)
# 				special_magic_mask = Constant.float64x2('0x1.0000000000000p+52')
# 				nan = Constant.uint64x2(0x7FF8000000000000L)
# 				plus_inf = Constant.uint64x2(0x7FF0000000000000)
# 				minus_inf = Constant.uint64x2(0xFFF0000000000000)
#
# 				e = [LocalVariable(SSERegister) for index in range(10)]
#
# 				xPointer = GeneralPurposeRegister64()
# 				yPointer = GeneralPurposeRegister64()
# 				length = GeneralPurposeRegister64()
#
# 				LOAD.PARAMETER( xPointer, x_argument )
# 				LOAD.PARAMETER( yPointer, y_argument )
# 				LOAD.PARAMETER( length, length_argument )
#
# 				def SCALAR_LOG(xPointer, yPointer):
# 					xmm_denormal_exp_shift = SSERegister()
# 					xmm_one = SSERegister()
# 					xmm_min_normal = SSERegister()
# 					xmm_special_magic_mask = SSERegister()
#
# 					LOAD.CONSTANT( xmm_denormal_exp_shift, denormal_exp_shift )
# 					LOAD.CONSTANT( xmm_one, one )
# 					LOAD.CONSTANT( xmm_min_normal, min_normal )
# 					LOAD.CONSTANT( xmm_special_magic_mask, special_magic_mask )
#
# 					xmm_x = SSERegister()
# 					xmm_e = SSERegister()
# 					xmm_copy = SSERegister()
# 					xmm_mask = SSERegister()
#
# 					# Load an element
# 					MOVSD( xmm_e, [xPointer] )
# 					# Duplicate the element
# 					MOVAPS( xmm_copy, xmm_e )
# 					# Check for denormals (zero and negatives will be processed separately later)
# 					CMPLTSD( xmm_e, xmm_min_normal )
# 					# Load 1.0 into two lanes
# 					MOVDQA( xmm_x, xmm_one )
# 					# Get 0x40 in the exponent field if the input element is denormal
# 					PAND( xmm_e, xmm_denormal_exp_shift )
# 					# Set the factor to 0x1.0p+64 if the element is denormal (otherwise leave it 1.0)
# 					PADDD( xmm_x, xmm_e )
# 					# Get 64 in the exponent field if the input element is no denormal
# 					PXOR( xmm_e, xmm_denormal_exp_shift )
# 					# If the input element is denormal, multiply it by 0x1.0p+64
# 					MULSD( xmm_x, xmm_copy )
# 					# Get the normalized exponent of the initial number + 64 in the higher 12 bits of xmm_x
# 					# This works for positive number, negative numbers will be separately processed later
# 					PADDD( xmm_e, xmm_x )
# 					# Shift the (normalized exponent + 64) values to the mantissa
# 					PSRLQ( xmm_e, 52 )
#
# 					# Get normalized mantissa (without the implied bit)
# 					PAND( xmm_x, mantissa_mask )
# 					# Insert the exponent to make elements between 1.0 (inclusive) and 2.0 (exclusive)
# 					POR( xmm_x, xmm_one )
#
# 					# Load mask with square root of two
# 					LOAD.CONSTANT( xmm_mask, sqrt2 )
# 					# Check if the normalized element is above square root of two
# 					CMPLEPD( xmm_mask, xmm_x )
# 					# If yes, increment the exponent variable
# 					PSUBQ( xmm_e, xmm_mask )
# 					# Convert the exponent variable into double precision number (and subtract 64)
# 					POR( xmm_e, xmm_special_magic_mask )
# 					# And get 1 in the exponent part of double-precision number
# 					PAND( xmm_mask, half_exp_mask )
# 					# If normalized element is above square root of two, multiply it by 0.5 (by subtracting 1 from exponent)
# 					PSUBQ( xmm_x, xmm_mask )
# 					# Store the exponent variable back
# 					MOVDQA( e[0], xmm_e )
#
# 					xmm_nan = SSERegister()
# 					xmm_ones_mask = SSERegister()
# 					LOAD.CONSTANT( xmm_nan, nan )
# 					PCMPEQB( xmm_ones_mask, xmm_ones_mask )
#
# 					xmm_mask = SSERegister()
#
# 					# Load the input element
# 					MOVSD( xmm_mask, [xPointer] )
# 					# Check if the input element is not negative
# 					# Mask is ones if negative
# 					PCMPGTQ( xmm_mask, xmm_ones_mask )
# 					# If negative, then set x to zero
# 					PAND( xmm_x, xmm_mask )
# 					# If negative, then set the mask to NaN
# 					PANDN( xmm_mask, xmm_nan )
# 					# If negative, then set x to NaN
# 					POR( xmm_x, xmm_mask )
#
# 					xmm_minus_inf = SSERegister()
# 					xmm_zero = SSERegister()
# 					LOAD.CONSTANT( xmm_minus_inf, minus_inf )
# 					PXOR( xmm_zero, xmm_zero )
#
# 					xmm_temp = SSERegister()
#
# 					# Load the pair of input elements
# 					MOVSD( xmm_temp, [xPointer] )
# 					# Compare to +0.0 (-0.0 produces NaN)
# 					PCMPEQQ( xmm_temp, xmm_zero )
# 					# If the input element is +0.0 get -inf in the temp register
# 					PAND( xmm_temp, xmm_minus_inf )
# 					# If the input element is +0.0 then x is 1.0
# 					# Set the high 12 bits to get -inf (-inf OR 1.0 == -inf)
# 					POR( xmm_x, xmm_temp )
#
# 					xmm_plus_inf = SSERegister()
# 					LOAD.CONSTANT( xmm_plus_inf, plus_inf )
#
# 					xmm_temp = SSERegister()
#
# 					# Load the pair of input elements
# 					MOVSD( xmm_temp, [xPointer] )
# 					# Check if the input is +inf
# 					PCMPEQQ( xmm_temp, xmm_plus_inf )
# 					# If the input is +inf, get +inf in the temp register
# 					PAND( xmm_temp, xmm_plus_inf )
# 					# If the input element is +inf then x is 1.0
# 					# Set the exponent bits of x to get +inf (+inf OR 1.0 == +inf)
# 					POR( xmm_x, xmm_temp )
#
# 					xmm_temp = SSERegister()
# 					xmm_copy = SSERegister()
#
# 					# Load the pair of input elements
# 					MOVSD( xmm_temp, [xPointer] )
# 					# Duplicate the pair of elements
# 					MOVAPS( xmm_copy, xmm_temp )
# 					# Test the input elements for being NaN.
# 					# If they are not NaN then temp variable is set to all ones
# 					CMPEQSD( xmm_temp, xmm_temp )
# 					# Zero x if the input element is NaN
# 					PAND( xmm_x, xmm_temp )
# 					# Get the input element in the temp register if the former is NaN
# 					PANDN( xmm_temp, xmm_copy )
# 					# Replace x with the input element if the latter is NaN
# 					POR( xmm_x, xmm_temp )
#
# 					xmm_one = SSERegister()
# 					LOAD.CONSTANT( xmm_one, one )
#
# 					SUBPD( xmm_x, xmm_one )
#
# 					acc = SSERegister()
#
# 					LOAD.CONSTANT( acc, c21 )
#
# 					def HORNER_STEP(coef):
# 						xmm_c = SSERegister()
# 						LOAD.CONSTANT( xmm_c, coef )
# 						MULSD( acc, xmm_x )
# 						ADDSD( acc, xmm_c )
#
# 					HORNER_STEP(c20)
# 					HORNER_STEP(c19)
# 					HORNER_STEP(c18)
# 					HORNER_STEP(c17)
# 					HORNER_STEP(c16)
# 					HORNER_STEP(c15)
# 					HORNER_STEP(c14)
# 					HORNER_STEP(c13)
# 					HORNER_STEP(c12)
# 					HORNER_STEP(c11)
# 					HORNER_STEP(c10)
# 					HORNER_STEP(c9)
# 					HORNER_STEP(c8)
# 					HORNER_STEP(c7)
# 					HORNER_STEP(c6)
# 					HORNER_STEP(c5)
# 					HORNER_STEP(c4)
# 					HORNER_STEP(c3)
# 					HORNER_STEP(c2)
#
# 					xmm_magic_bias = SSERegister()
# 					LOAD.CONSTANT( xmm_magic_bias, magic_bias )
#
# 					xmm_e = SSERegister()
# 					MOVAPS( xmm_e, e[0] )
# 					SUBPD( xmm_e, xmm_magic_bias )
# 					MOVAPS( e[0], xmm_e )
#
# 					MULSD( acc, xmm_x )
# 					MULSD( acc, xmm_x )
# 					ADDSD( acc, xmm_x )
#
# 					xmm_ln2_hi = SSERegister()
# 					LOAD.CONSTANT( xmm_ln2_hi, ln2_hi )
#
# 					xmm_e = SSERegister()
# 					xmm_temp = SSERegister()
#
# 					MOVAPS( xmm_e, e[0] )
# 					LOAD.CONSTANT( xmm_temp, ln2_lo )
# 					MULSD( xmm_temp, xmm_e )
# 					ADDSD( acc, xmm_temp )
# 					MULSD( xmm_e, xmm_ln2_hi )
# 					ADDSD( acc, xmm_e )
# 					MOVSD( [yPointer], acc )
#
#
# 				LABEL( 'process_by_1_prolog' )
# 				TEST( xPointer, 15 )
# 				JZ( 'process_by_20_prolog' )
#
# 				SCALAR_LOG( xPointer, yPointer )
#
# 				ADD( xPointer, 8 )
# 				ADD( yPointer, 8 )
# 				SUB( length, 1 )
# 				JNZ( 'process_by_1_prolog' )
#
# 				LABEL( 'process_by_20_prolog' )
#
# 				SUB( length, 20 )
# 				JB('process_by_20_epilog')
#
# 				ALIGN(32)
# 				LABEL('process_by_20')
#
# 				xmm_magic_mask = SSERegister()
# 				xmm_half_exp_mask = SSERegister()
# 				xmm_mantissa_mask = SSERegister()
# 				xmm_one = SSERegister()
#
# 				LOAD.CONSTANT( xmm_magic_mask, magic_mask )
# 				LOAD.CONSTANT( xmm_half_exp_mask, half_exp_mask )
# 				LOAD.CONSTANT( xmm_mantissa_mask, mantissa_mask )
# 				LOAD.CONSTANT( xmm_one, one )
#
# 				xmm_x_global = [SSERegister() for index in range(10)]
#
# 				xmm_x = xmm_x_global
#
# 				for index in range(10):
# 					x_hi = GeneralPurposeRegister32()
# 					xmm_temp = SSERegister()
# 					xmm_mask = SSERegister()
#
# 					# Load a pair of elements
# 					MOVDQA( xmm_x[index], [xPointer + index * 16] )
# 					# Load the high part of the first element
# 					MOV( x_hi, [xPointer + index * 16 + 4] )
# 					MOVDQA( xmm_temp, xmm_x[index] )
# 					PAND( xmm_x[index], xmm_mantissa_mask )
# 					SUB( x_hi, 0x80100000 )
# 					PSRLQ( xmm_temp, 52 )
# 					POR( xmm_x[index], xmm_one )
# 					CMP( x_hi, 0xFFD00000 )
# 					JG( 'process_by_20_special' )
# 					LOAD.CONSTANT( xmm_mask, sqrt2 )
# 					CMPLEPD( xmm_mask, xmm_x[index] )
# 					MOV( x_hi, [xPointer + index * 16 + 12] )
# 					PSUBQ( xmm_temp, xmm_mask )
# 					PADDQ( xmm_temp, xmm_magic_mask )
# 					SUB( x_hi, 0x80100000 )
# 					PAND( xmm_mask, xmm_half_exp_mask )
# 					PSUBQ( xmm_x[index], xmm_mask )
# 					CMP( x_hi, 0xFFD00000 )
# 					JG( 'process_by_20_special' )
# 					MOVDQA( e[index], xmm_temp )
#
# 				LABEL( 'process_by_20_horner' )
#
# 				x = xmm_x[0:4] + [LocalVariable(SSERegister) for index in range(6)]
#
# 				xmm_one = SSERegister()
# 				LOAD.CONSTANT( xmm_one, one )
#
# 				for index in range(10):
# 					SUBPD( xmm_x[index], xmm_one )
# 					if isinstance(x[index], LocalVariable):
# 						MOVAPS( x[index], xmm_x[index] )
#
# 				acc = [SSERegister() for index in range(10)]
#
# 				for index in range(10):
# 					if index % 4 == 0:
# 						LOAD.CONSTANT( acc[index], c21 )
# 					else:
# 						MOVAPS( acc[index], acc[index & -4] )
#
# 				def HORNER_STEP(coef):
# 					xmm_c = SSERegister()
# 					LOAD.CONSTANT( xmm_c, coef )
#
# 					for index in range(10):
# 						if isinstance(x[index], SSERegister):
# 							xmm_x = x[index]
# 						else:
# 							xmm_x = SSERegister()
# 							MOVAPS( xmm_x, x[index] )
# 						MULPD( acc[index], xmm_x )
# 						ADDPD( acc[index], xmm_c )
#
# 				HORNER_STEP(c20)
# 				HORNER_STEP(c19)
# 				HORNER_STEP(c18)
# 				HORNER_STEP(c17)
# 				HORNER_STEP(c16)
# 				HORNER_STEP(c15)
# 				HORNER_STEP(c14)
# 				HORNER_STEP(c13)
# 				HORNER_STEP(c12)
# 				HORNER_STEP(c11)
# 				HORNER_STEP(c10)
# 				HORNER_STEP(c9)
# 				HORNER_STEP(c8)
# 				HORNER_STEP(c7)
# 				HORNER_STEP(c6)
# 				HORNER_STEP(c5)
# 				HORNER_STEP(c4)
# 				HORNER_STEP(c3)
# 				HORNER_STEP(c2)
#
# 				xmm_magic_bias = SSERegister()
# 				LOAD.CONSTANT( xmm_magic_bias, magic_bias )
#
# 				for index in range(10):
# 					xmm_e = SSERegister()
#
# 					MOVAPS( xmm_e, e[index] )
# 					SUBPD( xmm_e, xmm_magic_bias )
# 					MOVAPS( e[index], xmm_e )
#
# 				for index in range(10):
# 					if isinstance(x[index], SSERegister):
# 						xmm_x = x[index]
# 					else:
# 						xmm_x = SSERegister()
# 						MOVAPS( xmm_x, x[index] )
#
# 					MULPD( acc[index], xmm_x )
# 					MULPD( acc[index], xmm_x )
# 					ADDPD( acc[index], xmm_x )
#
# 				xmm_ln2_hi = SSERegister()
# 				LOAD.CONSTANT( xmm_ln2_hi, ln2_hi )
#
# 				for index in range(10):
# 					xmm_e = SSERegister()
# 					xmm_temp = SSERegister()
#
# 					MOVAPS( xmm_e, e[index] )
# 					LOAD.CONSTANT( xmm_temp, ln2_lo )
# 					MULPD( xmm_temp, xmm_e )
# 					ADDPD( acc[index], xmm_temp )
# 					MULPD( xmm_e, xmm_ln2_hi )
# 					ADDPD( acc[index], xmm_e )
# 					MOVUPS( [yPointer + 16 * index], acc[index] )
#
# 				ADD( xPointer, 160 )
# 				ADD( yPointer, 160 )
# 				SUB( length, 20 )
# 				JAE( 'process_by_20' )
#
# 				LABEL( 'process_by_20_epilog' )
#
# 				ADD( length, 20 )
# 				JZ( 'return_ok' )
#
# 				LABEL( 'process_by_1_epilog' )
#
# 				SCALAR_LOG( xPointer, yPointer )
#
# 				ADD( xPointer, 8 )
# 				ADD( yPointer, 8 )
# 				SUB( length, 1 )
# 				JNZ( 'process_by_1_epilog' )
#
# 				LABEL( 'return_ok' )
# 				RETURN( 0 )
#
# 				LABEL( 'process_by_20_special' )
#
# 				xmm_denormal_exp_shift = SSERegister()
# 				xmm_one = SSERegister()
# 				xmm_min_normal = SSERegister()
# 				xmm_special_magic_mask = SSERegister()
#
# 				LOAD.CONSTANT( xmm_denormal_exp_shift, denormal_exp_shift )
# 				LOAD.CONSTANT( xmm_one, one )
# 				LOAD.CONSTANT( xmm_min_normal, min_normal )
# 				LOAD.CONSTANT( xmm_special_magic_mask, special_magic_mask )
#
# 				xmm_x = xmm_x_global
#
# 				for index in range(10):
# 					xmm_e = SSERegister()
# 					xmm_copy = SSERegister()
# 					xmm_mask = SSERegister()
#
# 					# Load a pair of elements
# 					MOVAPS( xmm_e, [xPointer + index * 16] )
# 					# Duplicate the pair of elements
# 					MOVAPS( xmm_copy, xmm_e )
# 					# Check for denormals (zero and negatives will be processed separately later)
# 					CMPLTPD( xmm_e, xmm_min_normal )
# 					# Load 1.0 into two lanes
# 					MOVDQA( xmm_x[index], xmm_one )
# 					# Get 0x40 in the exponent field if the input element is denormal
# 					PAND( xmm_e, xmm_denormal_exp_shift )
# 					# Set the factor to 0x1.0p+64 if the element is denormal (otherwise leave it 1.0)
# 					PADDD( xmm_x[index], xmm_e )
# 					# Get 64 in the exponent field if the input element is no denormal
# 					PXOR( xmm_e, xmm_denormal_exp_shift )
# 					# If the input element is denormal, multiply it by 0x1.0p+64
# 					MULPD( xmm_x[index], xmm_copy )
# 					# Get the normalized exponent of the initial number + 64 in the higher 12 bits of xmm_x
# 					# This works for positive number, negative numbers will be separately processed later
# 					PADDD( xmm_e, xmm_x[index] )
# 					# Shift the (normalized exponent + 64) values to the mantissa
# 					PSRLQ( xmm_e, 52 )
#
# 					# Get normalized mantissa (without the implied bit)
# 					PAND( xmm_x[index], mantissa_mask )
# 					# Insert the exponent to make elements between 1.0 (inclusive) and 2.0 (exclusive)
# 					POR( xmm_x[index], xmm_one )
#
# 					# Load mask with square root of two
# 					LOAD.CONSTANT( xmm_mask, sqrt2 )
# 					# Check if the normalized element is above square root of two
# 					CMPLEPD( xmm_mask, xmm_x[index] )
# 					# If yes, increment the exponent variable
# 					PSUBQ( xmm_e, xmm_mask )
# 					# Convert the exponent variable into double precision number (and subtract 64)
# 					POR( xmm_e, xmm_special_magic_mask )
# 					# And get 1 in the exponent part of double-precision number
# 					PAND( xmm_mask, half_exp_mask )
# 					# If normalized element is above square root of two, multiply it by 0.5 (by subtracting 1 from exponent)
# 					PSUBQ( xmm_x[index], xmm_mask )
# 					# Store the exponent variable back
# 					MOVDQA( e[index], xmm_e )
#
# 				xmm_nan = SSERegister()
# 				xmm_ones_mask = SSERegister()
# 				LOAD.CONSTANT( xmm_nan, nan )
# 				PCMPEQB( xmm_ones_mask, xmm_ones_mask )
#
# 				for index in range(10):
# 					xmm_mask = SSERegister()
#
# 					# Load the input element
# 					MOVDQA( xmm_mask, [xPointer + index * 16] )
# 					# Check if the input element is not negative
# 					# Mask is ones if negative
# 					PCMPGTQ( xmm_mask, xmm_ones_mask )
# 					# If negative, then set x to zero
# 					PAND( xmm_x[index], xmm_mask )
# 					# If negative, then set the mask to NaN
# 					PANDN( xmm_mask, xmm_nan )
# 					# If negative, then set x to NaN
# 					POR( xmm_x[index], xmm_mask )
#
# 				xmm_minus_inf = SSERegister()
# 				xmm_zero = SSERegister()
# 				LOAD.CONSTANT( xmm_minus_inf, minus_inf )
# 				PXOR( xmm_zero, xmm_zero )
#
# 				for index in range(10):
# 					xmm_temp = SSERegister()
#
# 					# Load the pair of input elements
# 					MOVDQA( xmm_temp, [xPointer + index * 16] )
# 					# Compare to +0.0 (-0.0 produces NaN)
# 					PCMPEQQ( xmm_temp, xmm_zero )
# 					# If the input element is +0.0 get -inf in the temp register
# 					PAND( xmm_temp, xmm_minus_inf )
# 					# If the input element is +0.0 then x is 1.0
# 					# Set the high 12 bits to get -inf (-inf OR 1.0 == -inf)
# 					POR( xmm_x[index], xmm_temp )
#
# 				xmm_plus_inf = SSERegister()
# 				LOAD.CONSTANT( xmm_plus_inf, plus_inf )
#
# 				for index in range(10):
# 					xmm_temp = SSERegister()
#
# 					# Load the pair of input elements
# 					MOVDQA( xmm_temp, [xPointer + index * 16] )
# 					# Check if the input is +inf
# 					PCMPEQQ( xmm_temp, xmm_plus_inf )
# 					# If the input is +inf, get +inf in the temp register
# 					PAND( xmm_temp, xmm_plus_inf )
# 					# If the input element is +inf then x is 1.0
# 					# Set the exponent bits of x to get +inf (+inf OR 1.0 == +inf)
# 					POR( xmm_x[index], xmm_temp )
#
# 				for index in range(10):
# 					xmm_temp = SSERegister()
# 					xmm_copy = SSERegister()
#
# 					# Load the pair of input elements
# 					MOVAPS( xmm_temp, [xPointer + index * 16] )
# 					# Duplicate the pair of elements
# 					MOVAPS( xmm_copy, xmm_temp )
# 					# Test the input elements for being NaN.
# 					# If they are not NaN then temp variable is set to all ones
# 					CMPEQPD( xmm_temp, xmm_temp )
# 					# Zero x if the input element is NaN
# 					PAND( xmm_x[index], xmm_temp )
# 					# Get the input element in the temp register if the former is NaN
# 					PANDN( xmm_temp, xmm_copy )
# 					# Replace x with the input element if the latter is NaN
# 					POR( xmm_x[index], xmm_temp )
#
# 				JMP('process_by_20_horner')
#
# 				return codegen.end_function()

def Log_V64f_V64f_Nehalem(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-sysv', 'x64-ms']:
		if module == 'Math':
			if function == 'Log':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'Nehalem')

				c2 = Constant.float64x2('-0x1.FFFFFFFFFFFF2p-2')
				c3 = Constant.float64x2('0x1.5555555555103p-2')
				c4 = Constant.float64x2('-0x1.00000000013C7p-2')
				c5 = Constant.float64x2('0x1.9999999A43E4Fp-3')
				c6 = Constant.float64x2('-0x1.55555554A6A2Bp-3')
				c7 = Constant.float64x2('0x1.249248DAE4B2Ap-3')
				c8 = Constant.float64x2('-0x1.FFFFFFBD8606Dp-4')
				c9 = Constant.float64x2('0x1.C71C90DB06248p-4')
				c10 = Constant.float64x2('-0x1.9999C5BE751E3p-4')
				c11 = Constant.float64x2('0x1.745980F3FB889p-4')
				c12 = Constant.float64x2('-0x1.554D5ACD502ABp-4')
				c13 = Constant.float64x2('0x1.3B4ED39194B87p-4')
				c14 = Constant.float64x2('-0x1.25480A82633AFp-4')
				c15 = Constant.float64x2('0x1.0F23916A44515p-4')
				c16 = Constant.float64x2('-0x1.EED2E2BB64B2Ep-5')
				c17 = Constant.float64x2('0x1.EA17E14773369p-5')
				c18 = Constant.float64x2('-0x1.1654764F478ECp-4')
				c19 = Constant.float64x2('0x1.0266CD08DB2F2p-4')
				c20 = Constant.float64x2('-0x1.CC4EC078138E3p-6')
				ln2_hi = Constant.float64x2('0x1.62E42FEFA3800p-1')
				ln2_lo = Constant.float64x2('0x1.EF35793C76730p-45')
				sqrt2 = Constant.float64x2('0x1.6A09E667F3BCDp+0')
				one = Constant.float64x2('0x1.0000000000000p+0')
				mantissa_mask = Constant.uint64x2(0x000FFFFFFFFFFFFFL)
				half_exponent = Constant.uint64x2(0x0010000000000000L)
				denormal_magic = Constant.uint64x2(0x4330000000000000L)
				denormal_bias = Constant.float64x2('0x1.0000000000000p+52')
				denormal_exponent_shift = Constant.uint64x2(1022L + 52L)
				default_exponent = one
				exponent_magic = Constant.uint64x2(0x4338000000000000L - 1023L)
				exponent_bias = Constant.float64x2('0x1.8000000000000p+52')
				nan = Constant.uint64x2(0x7FF8000000000000L)
				plus_inf = Constant.uint64x2(0x7FF0000000000000L)
				minus_inf = Constant.uint64x2(0xFFF0000000000000L)

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				def SCALAR_LOG(xPointer, yPointer):
					xmm_x = SSERegister()
					xmm_dx = SSERegister()
					xmm_ne = SSERegister()
					xmm_de = SSERegister()
					xmm_dmask = xmm0

					# x = *xPointer
					MOVSD( xmm_x, [xPointer] )
					# ne = as_ulong(x) >> 52
					MOVAPS( xmm_ne, xmm_x )
					PSRLQ( xmm_ne, 52 )
					# dx = as_double(as_ulong(x) | denormal_magic) - denormal_bias
					MOVAPS( xmm_dx, xmm_x )
					ORPS( xmm_dx, denormal_magic )
					SUBPD( xmm_dx, denormal_bias )
					# dmask = (ne == 0)
					PXOR( xmm_dmask, xmm_dmask )
					PCMPEQQ( xmm_dmask, xmm_ne )
					# de = (as_ulong(dx) >> 52) - denormal_exponent_shift
					MOVDQA( xmm_de, xmm_dx )
					PSRLQ( xmm_de, 52 )
					PSUBQ( xmm_de, denormal_exponent_shift )
					# m = dmask ? dx : x
					PBLENDVB( xmm_x, xmm_dx, xmm_dmask )
					xmm_m = xmm_x
					xmm_x = None
					# m = (m & mantissa_mask) | default_exponent
					PAND( xmm_m, mantissa_mask )
					POR( xmm_m, default_exponent )
					# e = (de & dmask) | ne
					PAND( xmm_de, xmm_dmask )
					POR( xmm_de, xmm_ne )
					xmm_e = xmm_de
					xmm_de = None

					# amask = m >= sqrt2
					xmm_amask = SSERegister()
					LOAD.CONSTANT( xmm_amask, sqrt2 )
					CMPLTPD( xmm_amask, xmm_m )
					# If (amask) then e += 1
					PSUBQ( xmm_e, xmm_amask )
					# If (amask) then m *= 0.5
					PAND( xmm_amask, half_exponent )
					PSUBD( xmm_m, xmm_amask )

					# t = m - 1.0
					SUBPD( xmm_m, one )
					xmm_t = xmm_m
					xmm_m = None

					# pt = c20
					xmm_pt = SSERegister()
					LOAD.CONSTANT( xmm_pt, c20 )

					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c19 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c18 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c17 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c16 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c15 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c14 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c13 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c12 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c11 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c10 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c9 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c8 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c7 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c6 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c5 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c4 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c3 )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, c2 )

					# rf = (pt * t) * t + t
					MULPD( xmm_pt, xmm_t )
					MULPD( xmm_pt, xmm_t )
					ADDPD( xmm_pt, xmm_t )
					xmm_rf = xmm_pt

					# fe = as_double(as_ulong(e) + exponent_magic) - exponent_bias
					PADDQ( xmm_e, exponent_magic )
					SUBPD( xmm_e, exponent_bias )
					xmm_fe = xmm_e
					xmm_e = None

					# f = fe * ln2_lo + rf
					xmm_f = SSERegister()
					MOVAPS( xmm_f, xmm_fe )
					MULPD( xmm_f, ln2_lo )
					ADDPD( xmm_f, xmm_rf )
					# f += fe * ln2_hi
					MULPD( xmm_fe, ln2_hi )
					ADDPD( xmm_f, xmm_fe )

					xmm_x = xmm0
					# x = *xPointer
					MOVSD( xmm_x, [xPointer] )
					# if sign(x) == -1 then f = NaN
					xmm_nan = SSERegister()
					LOAD.CONSTANT( xmm_nan, nan )
					BLENDVPD( xmm_f, xmm_nan, xmm_x )

					# xmm_zero_mask = SSERegister()
					# xmm_minus_inf = SSERegister()
					# PXOR( xmm_zero_mask, xmm_zero_mask )
					# LOAD.CONSTANT( xmm_minus_inf, minus_inf )
					# # zeroMask = (x == +0.0)
					# PCMPEQQ( xmm_zero_mask, xmm_x )
					# # f = (zeroMask) ? -inf : f
					# PAND( xmm_minus_inf, xmm_zero_mask )
					# PANDN( xmm_zero_mask, xmm_f )
					# POR( xmm_zero_mask, xmm_minus_inf )
					# xmm_f = xmm_zero_mask

					# if !(x < inf) then f = x
					xmm_x_copy = SSERegister()
					MOVAPS( xmm_x_copy, xmm_x )
					CMPNLTPD( xmm_x, plus_inf )
					BLENDVPD( xmm_f, xmm_x_copy, xmm_x )

					# *yPointer = f
					MOVSD( [yPointer], xmm_f )

				def VECTOR_LOG(xPointer, yPointer):
					xmm_x = [SSERegister() for i in range(8)]
					e = [LocalVariable(SSERegister) for i in range(8)]
					xmm_e = [SSERegister() for i in range(8)]

					xmm_denormal_magic = SSERegister()
					MOVAPS( xmm_denormal_magic, denormal_magic )

					for i in range(0, 4):
						xmm_dx = SSERegister()
						xmm_ne = SSERegister()
						xmm_de = SSERegister()
						xmm_dmask = xmm0

						# x = *xPointer
						MOVAPS( xmm_x[i], [xPointer + i * 16] )
						# ne = as_ulong(x) >> 52
						MOVAPS( xmm_ne, xmm_x[i] )
						PSRLQ( xmm_ne, 52 )
						# dx = as_double(as_ulong(x) | denormal_magic) - denormal_bias
						MOVAPS( xmm_dx, xmm_x[i] )
						ORPS( xmm_dx, xmm_denormal_magic )
						SUBPD( xmm_dx, denormal_bias )
						# dmask = (ne == 0)
						PXOR( xmm_dmask, xmm_dmask )
						PCMPEQQ( xmm_dmask, xmm_ne )
						# de = (as_ulong(dx) >> 52) - denormal_exponent_shift
						MOVDQA( xmm_de, xmm_dx )
						PSRLQ( xmm_de, 52 )
						PSUBQ( xmm_de, denormal_exponent_shift )
						# m = dmask ? dx : x
						PBLENDVB( xmm_x[i], xmm_dx, xmm_dmask )
						# m = (m & mantissa_mask) | default_exponent
						PAND( xmm_x[i], mantissa_mask )
						POR( xmm_x[i], one )
						# e = (de & dmask) | ne
						PAND( xmm_de, xmm_dmask )
						POR( xmm_de, xmm_ne )
						xmm_e[i] = xmm_de

					for i in range(0, 4):
						# amask = m >= sqrt2
						xmm_amask = SSERegister()
						LOAD.CONSTANT( xmm_amask, sqrt2 )
						CMPLTPD( xmm_amask, xmm_x[i] )
						# If (amask) then e += 1
						PSUBQ( xmm_e[i], xmm_amask )
						# If (amask) then m *= 0.5
						PAND( xmm_amask, half_exponent )
						PSUBD( xmm_x[i], xmm_amask )
						MOVAPD( e[i], xmm_e[i] )

					xmm_denormal_magic = SSERegister()
					MOVAPS( xmm_denormal_magic, denormal_magic )

					for i in range(4, 8):
						xmm_dx = SSERegister()
						xmm_ne = SSERegister()
						xmm_de = SSERegister()
						xmm_dmask = xmm0

						# x = *xPointer
						MOVAPS( xmm_x[i], [xPointer + i * 16] )
						# ne = as_ulong(x) >> 52
						MOVAPS( xmm_ne, xmm_x[i] )
						PSRLQ( xmm_ne, 52 )
						# dx = as_double(as_ulong(x) | denormal_magic) - denormal_bias
						MOVAPS( xmm_dx, xmm_x[i] )
						ORPS( xmm_dx, xmm_denormal_magic )
						SUBPD( xmm_dx, denormal_bias )
						# dmask = (ne == 0)
						PXOR( xmm_dmask, xmm_dmask )
						PCMPEQQ( xmm_dmask, xmm_ne )
						# de = (as_ulong(dx) >> 52) - denormal_exponent_shift
						MOVDQA( xmm_de, xmm_dx )
						PSRLQ( xmm_de, 52 )
						PSUBQ( xmm_de, denormal_exponent_shift )
						# m = dmask ? dx : x
						PBLENDVB( xmm_x[i], xmm_dx, xmm_dmask )
						# m = (m & mantissa_mask) | default_exponent
						PAND( xmm_x[i], mantissa_mask )
						POR( xmm_x[i], one )
						# e = (de & dmask) | ne
						PAND( xmm_de, xmm_dmask )
						POR( xmm_de, xmm_ne )
						xmm_e[i] = xmm_de

					for i in range(4, 8):
						# amask = m >= sqrt2
						xmm_amask = SSERegister()
						LOAD.CONSTANT( xmm_amask, sqrt2 )
						CMPLTPD( xmm_amask, xmm_x[i] )
						# If (amask) then e += 1
						PSUBQ( xmm_e[i], xmm_amask )
						# If (amask) then m *= 0.5
						PAND( xmm_amask, half_exponent )
						PSUBD( xmm_x[i], xmm_amask )
						MOVAPD( e[i], xmm_e[i] )

					xmm_one = SSERegister()
					LOAD.CONSTANT( xmm_one, one )
					xmm_rf = [SSERegister() for i in range(8)]
					t = [SSERegister() for i in range(6)] + [LocalVariable(SSERegister) for i in range(2)]
					for i in range(8):
						# t = m - 1.0
						SUBPD( xmm_x[i], xmm_one )
						if isinstance(t[i], SSERegister):
							t[i] = xmm_x[i]
						else:
							MOVAPD( t[i], xmm_x[i] )
						if i % 4 == 0:
							LOAD.CONSTANT( xmm_rf[i], c20 )
						else:
							MOVAPD( xmm_rf[i], xmm_rf[(i/4)*4] )

					def HORNER_STEP(coef):
						xmm_c = SSERegister()
						LOAD.CONSTANT( xmm_c, coef )
						for i in range(8):
							MULPD( xmm_rf[i], t[i] )
							ADDPD( xmm_rf[i], xmm_c )

					HORNER_STEP(c19)
					HORNER_STEP(c18)
					HORNER_STEP(c17)
					HORNER_STEP(c16)
					HORNER_STEP(c15)
					HORNER_STEP(c14)
					HORNER_STEP(c13)
					HORNER_STEP(c12)
					HORNER_STEP(c11)
					HORNER_STEP(c10)
					HORNER_STEP(c9)
					HORNER_STEP(c8)
					HORNER_STEP(c7)
					HORNER_STEP(c6)
					HORNER_STEP(c5)
					HORNER_STEP(c4)
					HORNER_STEP(c3)
					HORNER_STEP(c2)

					# rf = (pt * t) * t + t
					for i in range(8):
						if isinstance(t[i], SSERegister):
							xmm_t = t[i]
						else:
							xmm_t = SSERegister()
							MOVAPD( xmm_t, t[i] )

						MULPD( xmm_rf[i], xmm_t )
						MULPD( xmm_rf[i], xmm_t )
						ADDPD( xmm_rf[i], xmm_t )

					xmm_f = [SSERegister() for i in range(8)]

					xmm_exponent_magic = SSERegister()
					xmm_exponent_bias = SSERegister()
					xmm_ln2_lo = SSERegister()
					xmm_ln2_hi = SSERegister()
					LOAD.CONSTANT( xmm_exponent_magic, exponent_magic )
					LOAD.CONSTANT( xmm_exponent_bias, exponent_bias )
					LOAD.CONSTANT( xmm_ln2_lo, ln2_lo )
					LOAD.CONSTANT( xmm_ln2_hi, ln2_hi )
					for i in range(8):
						xmm_e = SSERegister()

						MOVAPD( xmm_e, e[i] )
						# e = as_double(as_ulong(e) + exponent_magic) - exponent_bias
						PADDQ( xmm_e, xmm_exponent_magic )
						SUBPD( xmm_e, xmm_exponent_bias )

						# f = e * ln2_lo + rf
						MOVAPS( xmm_f[i], xmm_e )
						MULPD( xmm_f[i], xmm_ln2_lo )
						ADDPD( xmm_f[i], xmm_rf[i] )
						# f += e * ln2_hi
						MULPD( xmm_e, xmm_ln2_hi )
						ADDPD( xmm_f[i], xmm_e )

					xmm_nan = SSERegister()
					xmm_plus_inf = SSERegister()
					LOAD.CONSTANT( xmm_nan, nan )
					LOAD.CONSTANT( xmm_plus_inf, plus_inf )
					for i in range(8):
						xmm_x = xmm0

						# x = *xPointer
						MOVAPD( xmm_x, [xPointer + i * 16] )
						# if sign(x) == -1 then f = NaN
						BLENDVPD( xmm_f[i], xmm_nan, xmm_x )

						# xmm_zero_mask = SSERegister()
						# xmm_minus_inf = SSERegister()
						# PXOR( xmm_zero_mask, xmm_zero_mask )
						# LOAD.CONSTANT( xmm_minus_inf, minus_inf )
						# # zeroMask = (x == +0.0)
						# PCMPEQQ( xmm_zero_mask, xmm_x )
						# # f = (zeroMask) ? -inf : f
						# PAND( xmm_minus_inf, xmm_zero_mask )
						# PANDN( xmm_zero_mask, xmm_f[i] )
						# POR( xmm_zero_mask, xmm_minus_inf )
						# MOVDQA( xmm_f[i], xmm_zero_mask )

						# if !(x < inf) then f = x
						xmm_x_copy = SSERegister()
						MOVAPS( xmm_x_copy, xmm_x )
						CMPNLTPD( xmm_x, xmm_plus_inf )
						BLENDVPD( xmm_f[i], xmm_x_copy, xmm_x )

						# *yPointer = f
						MOVUPD( [yPointer + i * 16], xmm_f[i] )

				Map_V64f_V64f(SCALAR_LOG, VECTOR_LOG, xPointer, yPointer, length, 16, 16)

				return codegen.end_function()

def Log_V64f_V64f_SandyBridge(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-ms', 'x64-sysv']:
		if module == 'Math':
			if function == 'Log':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'SandyBridge')

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				def SCALAR_LOG(xPointer, yPointer):
					c2 = Constant.float64x2('-0x1.FFFFFFFFFFFF2p-2')
					c3 = Constant.float64x2('0x1.5555555555103p-2')
					c4 = Constant.float64x2('-0x1.00000000013C7p-2')
					c5 = Constant.float64x2('0x1.9999999A43E4Fp-3')
					c6 = Constant.float64x2('-0x1.55555554A6A2Bp-3')
					c7 = Constant.float64x2('0x1.249248DAE4B2Ap-3')
					c8 = Constant.float64x2('-0x1.FFFFFFBD8606Dp-4')
					c9 = Constant.float64x2('0x1.C71C90DB06248p-4')
					c10 = Constant.float64x2('-0x1.9999C5BE751E3p-4')
					c11 = Constant.float64x2('0x1.745980F3FB889p-4')
					c12 = Constant.float64x2('-0x1.554D5ACD502ABp-4')
					c13 = Constant.float64x2('0x1.3B4ED39194B87p-4')
					c14 = Constant.float64x2('-0x1.25480A82633AFp-4')
					c15 = Constant.float64x2('0x1.0F23916A44515p-4')
					c16 = Constant.float64x2('-0x1.EED2E2BB64B2Ep-5')
					c17 = Constant.float64x2('0x1.EA17E14773369p-5')
					c18 = Constant.float64x2('-0x1.1654764F478ECp-4')
					c19 = Constant.float64x2('0x1.0266CD08DB2F2p-4')
					c20 = Constant.float64x2('-0x1.CC4EC078138E3p-6')
					ln2_hi = Constant.float64x2('0x1.62E42FEFA3800p-1')
					ln2_lo = Constant.float64x2('0x1.EF35793C76730p-45')
					sqrt2 = Constant.float64x2('0x1.6A09E667F3BCDp+0')
					one = Constant.float64x2('0x1.0000000000000p+0')
					mantissa_mask = Constant.uint64x2(0x000FFFFFFFFFFFFFL)
					half_exponent = Constant.uint64x2(0x0010000000000000L)
					denormal_magic = Constant.uint64x2(0x4330000000000000L)
					denormal_bias = Constant.float64x2('0x1.0000000000000p+52')
					denormal_exponent_shift = Constant.uint64x2(1022L + 52L)
					default_exponent = one
					exponent_magic = Constant.uint64x2(0x4338000000000000L - 1023L)
					exponent_bias = Constant.float64x2('0x1.8000000000000p+52')
					nan = Constant.uint64x2(0x7FF8000000000000L)
					plus_inf = Constant.uint64x2(0x7FF0000000000000L)
					minus_inf = Constant.uint64x2(0xFFF0000000000000L)

					xmm_x = SSERegister()
					xmm_dx = SSERegister()
					xmm_ne = SSERegister()
					xmm_de = SSERegister()
					xmm_e = SSERegister()
					xmm_dmask = xmm0

					# x = *xPointer
					VMOVSD( xmm_x, [xPointer] )
					# ne = as_ulong(x) >> 52
					VPSRLQ( xmm_ne, xmm_x, 52 )
					# dx = as_double(as_ulong(x) | denormal_magic) - denormal_bias
					VORPS( xmm_dx, xmm_x, denormal_magic )
					VSUBPD( xmm_dx, xmm_dx, denormal_bias )
					# dmask = (ne == 0)
					VPXOR( xmm_dmask, xmm_dmask, xmm_dmask )
					VPCMPEQQ( xmm_dmask, xmm_dmask, xmm_ne )
					# de = (as_ulong(dx) >> 52) - denormal_exponent_shift
					VPSRLQ( xmm_de, xmm_dx, 52 )
					VPSUBQ( xmm_de, xmm_de, denormal_exponent_shift)
					# x = dmask ? dx : x
					VPBLENDVB( xmm_x, xmm_x, xmm_dx, xmm_dmask )
					# x = (x & mantissa_mask) | default_exponent
					VPAND( xmm_x, xmm_x, mantissa_mask )
					VPOR( xmm_x, xmm_x, default_exponent )
					# e = (de & dmask) | ne
					VPAND( xmm_e, xmm_de, xmm_dmask )
					VPOR( xmm_e, xmm_e, xmm_ne )

					# amask = x >= sqrt2
					xmm_amask = SSERegister()
					LOAD.CONSTANT( xmm_amask, sqrt2 )
					VCMPLTPD( xmm_amask, xmm_amask, xmm_x )
					# If (amask) then e += 1
					VPSUBQ( xmm_e, xmm_e, xmm_amask )
					# If (amask) then x *= 0.5
					VPAND( xmm_amask, xmm_amask, half_exponent )
					VPSUBD( xmm_x, xmm_x, xmm_amask )

					xmm_t = SSERegister()
					# t = x - 1.0
					VSUBPD( xmm_t, xmm_x, one )

					# rf = c20
					xmm_rf = SSERegister()
					LOAD.CONSTANT( xmm_rf, c20 )

					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c19 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c18 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c17 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c16 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c15 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c14 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c13 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c12 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c11 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c10 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c9 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c8 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c7 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c6 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c5 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c4 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c3 )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, c2 )

					# rf = (pt * t) * t + t
					VMULPD( xmm_rf, xmm_t )
					VMULPD( xmm_rf, xmm_t )
					VADDPD( xmm_rf, xmm_t )

					# fe = as_double(as_ulong(e) + exponent_magic) - exponent_bias
					VPADDQ( xmm_e, exponent_magic )
					VSUBPD( xmm_e, exponent_bias )

					# f = e * ln2_lo + rf
					xmm_f = SSERegister()
					VMULPD( xmm_f, xmm_e, ln2_lo )
					VADDPD( xmm_f, xmm_f, xmm_rf )
					# f += fe * ln2_hi
					VMULPD( xmm_e, xmm_e, ln2_hi )
					VADDPD( xmm_f, xmm_f, xmm_e )

					xmm_x = xmm0
					# x = *xPointer
					VMOVSD( xmm_x, [xPointer] )
					# if sign(x) == -1 then f = NaN
					xmm_nan = SSERegister()
					LOAD.CONSTANT( xmm_nan, nan )
					VBLENDVPD( xmm_f, xmm_f, xmm_nan, xmm_x )

					# xmm_zero_mask = SSERegister()
					# xmm_minus_inf = SSERegister()
					# PXOR( xmm_zero_mask, xmm_zero_mask )
					# LOAD.CONSTANT( xmm_minus_inf, minus_inf )
					# PCMPEQQ( xmm_zero_mask, xmm_x )
					# PAND( xmm_minus_inf, xmm_zero_mask )
					# PANDN( xmm_zero_mask, xmm_f )
					# POR( xmm_zero_mask, xmm_minus_inf )
					# xmm_f = xmm_zero_mask

					# if !(x < inf) then f = x
					xmm_inf_mask = SSERegister()
					VCMPNLTPD( xmm_inf_mask, xmm_x, plus_inf )
					VBLENDVPD( xmm_f, xmm_f, xmm_x, xmm_inf_mask )

					# *yPointer = f
					VMOVSD( [yPointer], xmm_f )

				def VECTOR_LOG(xPointer, yPointer):
					c2 = Constant.float64x4('-0x1.FFFFFFFFFFFF2p-2')
					c3 = Constant.float64x4('0x1.5555555555103p-2')
					c4 = Constant.float64x4('-0x1.00000000013C7p-2')
					c5 = Constant.float64x4('0x1.9999999A43E4Fp-3')
					c6 = Constant.float64x4('-0x1.55555554A6A2Bp-3')
					c7 = Constant.float64x4('0x1.249248DAE4B2Ap-3')
					c8 = Constant.float64x4('-0x1.FFFFFFBD8606Dp-4')
					c9 = Constant.float64x4('0x1.C71C90DB06248p-4')
					c10 = Constant.float64x4('-0x1.9999C5BE751E3p-4')
					c11 = Constant.float64x4('0x1.745980F3FB889p-4')
					c12 = Constant.float64x4('-0x1.554D5ACD502ABp-4')
					c13 = Constant.float64x4('0x1.3B4ED39194B87p-4')
					c14 = Constant.float64x4('-0x1.25480A82633AFp-4')
					c15 = Constant.float64x4('0x1.0F23916A44515p-4')
					c16 = Constant.float64x4('-0x1.EED2E2BB64B2Ep-5')
					c17 = Constant.float64x4('0x1.EA17E14773369p-5')
					c18 = Constant.float64x4('-0x1.1654764F478ECp-4')
					c19 = Constant.float64x4('0x1.0266CD08DB2F2p-4')
					c20 = Constant.float64x4('-0x1.CC4EC078138E3p-6')
					ln2_hi = Constant.float64x4('0x1.62E42FEFA3800p-1')
					ln2_lo = Constant.float64x4('0x1.EF35793C76730p-45')
					mantissa_mask = Constant.uint64x4(0x000FFFFFFFFFFFFFL)
					exponent_mask = Constant.uint64x4(0x7FF0000000000000L)
					sqrt2 = Constant.float64x4('0x1.6A09E667F3BCDp+0')
					one = Constant.float64x4('0x1.0000000000000p+0')
					half = Constant.float64x4('0x1.0000000000000p-1')
					denormal_magic = Constant.float64x4('0x1.8000000000000p+52')
					min_normal = Constant.float64x4('0x1.0000000000000p-1022')
					normalized_exponent_bias   = Constant.float64x4('0x1.800003FF00000p+32')
					denormalized_exponent_bias = Constant.float64x4('0x1.8000083100000p+32')
					exponent_magic = Constant.float64x4('0x1.8000000000000p+32')

					nan = Constant.uint64x4(0x7FF8000000000000L)
					plus_inf = Constant.uint64x4(0x7FF0000000000000L)
					minus_inf = Constant.uint64x4(0xFFF0000000000000L)

					t = [AVXRegister() for i in range(6)] + [LocalVariable(AVXRegister) for i in range(2)]
					e = [LocalVariable(AVXRegister) for i in range(8)]

					ymm_normalized_exponent_bias = AVXRegister()
					ymm_denormal_magic = AVXRegister()
					ymm_one = AVXRegister()
					LOAD.CONSTANT( ymm_normalized_exponent_bias, normalized_exponent_bias )
					LOAD.CONSTANT( ymm_denormal_magic, denormal_magic )
					LOAD.CONSTANT( ymm_one, one )
					for i in range(8):
						ymm_x = AVXRegister()
						ymm_e = AVXRegister()
						ymm_dx = AVXRegister()
						ymm_dmask = AVXRegister()
						ymm_tx = AVXRegister()
						ymm_m = AVXRegister()
						ymm_exponent_bias = AVXRegister()
						ymm_amask = AVXRegister()
						if isinstance(t[i], AVXRegister):
							ymm_t = t[i]
						else:
							ymm_t = AVXRegister()

						# x = *xPointer
						VMOVAPD( ymm_x, [xPointer + i * 32] )
						# dx = as_double(as_ulong(x) | denormal_magic) - denormal_shift
						VORPD( ymm_dx, ymm_x, ymm_denormal_magic )
						VSUBPD( ymm_dx, ymm_dx, ymm_denormal_magic )
						# dmask = x < min_normal
						VCMPLTPD( ymm_dmask, ymm_x, min_normal )
						# tx = (dmask ? dx : x )
						VBLENDVPD( ymm_tx, ymm_x, ymm_dx, ymm_dmask )
						# m = (tx & mantissa_mask) | one
						VANDPD( ymm_m, ymm_tx, mantissa_mask )
						VORPD( ymm_m, ymm_m, ymm_one )
						# e = tx & exponent_mask
						VANDPD( ymm_e, ymm_tx, exponent_mask )
						# exponent_bias = (dmask ? denormalized_exponent_bias : normalized_exponent_bias)
						VBLENDVPD( ymm_exponent_bias, ymm_normalized_exponent_bias, denormalized_exponent_bias, ymm_dmask )
						# convert e to double
						VMOVSHDUP( ymm_e, ymm_e )
						VBLENDPS( ymm_e, ymm_e, exponent_magic, 0xAA )
						VSUBPD( ymm_e, ymm_exponent_bias )

						# amask = m > sqrt(2)
						VCMPGTPD( ymm_amask, ymm_m, sqrt2 )
						ymm_temp = AVXRegister()
						VANDPD( ymm_temp, ymm_amask, ymm_one )
						VADDPD( ymm_e, ymm_e, ymm_temp )
						VMOVAPD( e[i], ymm_e )
						# if m > sqrt(2) then m *= 0.5
						ymm_half_m = AVXRegister()
						VMULPD( ymm_half_m, ymm_m, half )
						VBLENDVPD( ymm_m, ymm_m, ymm_half_m, ymm_amask)
						VSUBPD( ymm_t, ymm_m, ymm_one )
						if isinstance(t[i], LocalVariable):
							VMOVAPD( t[i], ymm_t )

					ymm_f = [AVXRegister() for i in range(8)]
					ymm_c20 = AVXRegister()
					ymm_c19 = AVXRegister()
					LOAD.CONSTANT( ymm_c20, c20 )
					LOAD.CONSTANT( ymm_c19, c19 )
					for i in range(8):
						VMULPD( ymm_f[i], ymm_c20, t[i] )
						VADDPD( ymm_f[i], ymm_f[i], ymm_c19 )

					def HORNER_STEP(coef):
						ymm_c = AVXRegister()
						LOAD.CONSTANT( ymm_c, coef )
						for i in range(8):
							VMULPD( ymm_f[i], ymm_f[i], t[i] )
							VADDPD( ymm_f[i], ymm_f[i], ymm_c )

					HORNER_STEP(c18)
					HORNER_STEP(c17)
					HORNER_STEP(c16)
					HORNER_STEP(c15)
					HORNER_STEP(c14)
					HORNER_STEP(c13)
					HORNER_STEP(c12)
					HORNER_STEP(c11)
					HORNER_STEP(c10)
					HORNER_STEP(c9)
					HORNER_STEP(c8)
					HORNER_STEP(c7)
					HORNER_STEP(c6)
					HORNER_STEP(c5)
					HORNER_STEP(c4)
					HORNER_STEP(c3)
					HORNER_STEP(c2)

					for i in range(8):
						if isinstance(t[i], AVXRegister):
							ymm_t = t[i]
						else:
							ymm_t = AVXRegister()
							VMOVAPD( ymm_t, t[i] )

						VMULPD( ymm_f[i], ymm_f[i], ymm_t )
						VMULPD( ymm_f[i], ymm_f[i], ymm_t )
						VADDPD( ymm_f[i], ymm_f[i], ymm_t )

					ymm_ln2_lo = AVXRegister()
					ymm_ln2_hi = AVXRegister()
					LOAD.CONSTANT( ymm_ln2_lo, ln2_lo )
					LOAD.CONSTANT( ymm_ln2_hi, ln2_hi )
					for i in range(8):
						ymm_e = AVXRegister()
						VMOVAPD( ymm_e, e[i] )

						ymm_temp = AVXRegister()
						VMULPD( ymm_temp, ymm_e, ymm_ln2_lo )
						VADDPD( ymm_f[i], ymm_f[i], ymm_temp )

						ymm_temp = AVXRegister()
						VMULPD( ymm_temp, ymm_e, ymm_ln2_hi )
						VADDPD( ymm_f[i], ymm_f[i], ymm_temp )

					ymm_zero = AVXRegister()
					ymm_minus_inf = AVXRegister()
					ymm_plus_inf = AVXRegister()
					ymm_nan = AVXRegister()
					VXORPD( ymm_zero, ymm_zero, ymm_zero )
					VMOVAPD( ymm_plus_inf, plus_inf )
					VSUBPD( ymm_minus_inf, ymm_zero, ymm_plus_inf )
					VMULPD( ymm_nan, ymm_plus_inf, ymm_zero )
					for i in range(8):
						ymm_x = AVXRegister()
						VMOVAPD( ymm_x, [xPointer + i * 32] )

						ymm_zero_mask = AVXRegister()
						VCMPEQPD( ymm_zero_mask, ymm_x, ymm_zero )
						VBLENDVPD( ymm_f[i], ymm_f[i], ymm_minus_inf, ymm_zero_mask )
						VBLENDVPD( ymm_f[i], ymm_f[i], ymm_nan, ymm_x )
						ymm_inf_nan_mask = AVXRegister()
						VCMPNLTPD( ymm_inf_nan_mask, ymm_x, ymm_plus_inf )
						VBLENDVPD( ymm_f[i], ymm_f[i], ymm_x, ymm_inf_nan_mask )

						VMOVUPD( [yPointer + i * 32], ymm_f[i].get_oword() )
						VEXTRACTF128( [yPointer + i * 32 + 16], ymm_f[i], 1 )

				Map_V64f_V64f(SCALAR_LOG, VECTOR_LOG, xPointer, yPointer, length, 32, 32)

				return codegen.end_function()

def Log_V64f_V64f_Bulldozer(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-ms', 'x64-sysv']:
		if module == 'Math':
			if function == 'Log':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'Bulldozer')

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				def SCALAR_LOG(xPointer, yPointer):
					c2 = Constant.float64x2('-0x1.FFFFFFFFFFFF2p-2')
					c3 = Constant.float64x2('0x1.5555555555103p-2')
					c4 = Constant.float64x2('-0x1.00000000013C7p-2')
					c5 = Constant.float64x2('0x1.9999999A43E4Fp-3')
					c6 = Constant.float64x2('-0x1.55555554A6A2Bp-3')
					c7 = Constant.float64x2('0x1.249248DAE4B2Ap-3')
					c8 = Constant.float64x2('-0x1.FFFFFFBD8606Dp-4')
					c9 = Constant.float64x2('0x1.C71C90DB06248p-4')
					c10 = Constant.float64x2('-0x1.9999C5BE751E3p-4')
					c11 = Constant.float64x2('0x1.745980F3FB889p-4')
					c12 = Constant.float64x2('-0x1.554D5ACD502ABp-4')
					c13 = Constant.float64x2('0x1.3B4ED39194B87p-4')
					c14 = Constant.float64x2('-0x1.25480A82633AFp-4')
					c15 = Constant.float64x2('0x1.0F23916A44515p-4')
					c16 = Constant.float64x2('-0x1.EED2E2BB64B2Ep-5')
					c17 = Constant.float64x2('0x1.EA17E14773369p-5')
					c18 = Constant.float64x2('-0x1.1654764F478ECp-4')
					c19 = Constant.float64x2('0x1.0266CD08DB2F2p-4')
					c20 = Constant.float64x2('-0x1.CC4EC078138E3p-6')
					ln2_hi = Constant.float64x2('0x1.62E42FEFA39EFp-1')
					ln2_lo = Constant.float64x2('0x1.ABC9E3B39803Fp-56')
					sqrt2 = Constant.float64x2('0x1.6A09E667F3BCDp+0')
					one = Constant.float64x2('0x1.0000000000000p+0')
					mantissa_mask = Constant.uint64x2(0x000FFFFFFFFFFFFFL)
					half_exponent = Constant.uint64x2(0x0010000000000000L)
					denormal_magic = Constant.uint64x2(0x4330000000000000L)
					denormal_bias = Constant.float64x2('0x1.0000000000000p+52')
					denormal_exponent_shift = Constant.uint64x2(1022L + 52L)
					default_exponent = one
					exponent_magic = Constant.uint64x2(0x4338000000000000L - 1023L)
					exponent_bias = Constant.float64x2('0x1.8000000000000p+52')
					nan = Constant.uint64x2(0x7FF8000000000000L)
					plus_inf = Constant.uint64x2(0x7FF0000000000000L)
					minus_inf = Constant.uint64x2(0xFFF0000000000000L)

					xmm_x = SSERegister()
					xmm_dx = SSERegister()
					xmm_ne = SSERegister()
					xmm_de = SSERegister()
					xmm_e = SSERegister()
					xmm_dmask = xmm0

					# x = *xPointer
					VMOVSD( xmm_x, [xPointer] )
					# ne = as_ulong(x) >> 52
					VPSRLQ( xmm_ne, xmm_x, 52 )
					# dx = as_double(as_ulong(x) | denormal_magic) - denormal_bias
					VORPS( xmm_dx, xmm_x, denormal_magic )
					VSUBPD( xmm_dx, xmm_dx, denormal_bias )
					# dmask = (ne == 0)
					VPXOR( xmm_dmask, xmm_dmask, xmm_dmask )
					VPCMPEQQ( xmm_dmask, xmm_dmask, xmm_ne )
					# de = (as_ulong(dx) >> 52) - denormal_exponent_shift
					VPSRLQ( xmm_de, xmm_dx, 52 )
					VPSUBQ( xmm_de, xmm_de, denormal_exponent_shift)
					# x = dmask ? dx : x
					VPBLENDVB( xmm_x, xmm_x, xmm_dx, xmm_dmask )
					# x = (x & mantissa_mask) | default_exponent
					VPAND( xmm_x, xmm_x, mantissa_mask )
					VPOR( xmm_x, xmm_x, default_exponent )
					# e = (de & dmask) | ne
					VPAND( xmm_e, xmm_de, xmm_dmask )
					VPOR( xmm_e, xmm_e, xmm_ne )

					# amask = x >= sqrt2
					xmm_amask = SSERegister()
					LOAD.CONSTANT( xmm_amask, sqrt2 )
					VCMPLTPD( xmm_amask, xmm_amask, xmm_x )
					# If (amask) then e += 1
					VPSUBQ( xmm_e, xmm_e, xmm_amask )
					# If (amask) then x *= 0.5
					VPAND( xmm_amask, xmm_amask, half_exponent )
					VPSUBD( xmm_x, xmm_x, xmm_amask )

					xmm_t = SSERegister()
					# t = x - 1.0
					VSUBPD( xmm_t, xmm_x, one )

					# rf = c20
					xmm_rf = SSERegister()
					LOAD.CONSTANT( xmm_rf, c20 )

					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c19 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c18 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c17 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c16 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c15 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c14 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c13 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c12 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c11 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c10 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c9 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c8 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c7 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c6 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c5 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c4 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c3 )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, c2 )

					# rf = (pt * t) * t + t
					VMULPD( xmm_rf, xmm_t )
					VFMADDPD( xmm_rf, xmm_rf, xmm_t, xmm_t )

					# fe = as_double(as_ulong(e) + exponent_magic) - exponent_bias
					VPADDQ( xmm_e, exponent_magic )
					VSUBPD( xmm_e, exponent_bias )

					# f = e * ln2_lo + rf
					xmm_f = SSERegister()
					VFMADDPD( xmm_f, xmm_e, ln2_lo, xmm_rf )
					# f += fe * ln2_hi
					VFMADDPD( xmm_f, xmm_e, ln2_hi, xmm_f )

					xmm_x = xmm0
					# x = *xPointer
					VMOVSD( xmm_x, [xPointer] )
					# if sign(x) == -1 then f = NaN
					xmm_nan = SSERegister()
					LOAD.CONSTANT( xmm_nan, nan )
					VBLENDVPD( xmm_f, xmm_f, xmm_nan, xmm_x )

					# xmm_zero_mask = SSERegister()
					# xmm_minus_inf = SSERegister()
					# PXOR( xmm_zero_mask, xmm_zero_mask )
					# LOAD.CONSTANT( xmm_minus_inf, minus_inf )
					# PCMPEQQ( xmm_zero_mask, xmm_x )
					# PAND( xmm_minus_inf, xmm_zero_mask )
					# PANDN( xmm_zero_mask, xmm_f )
					# POR( xmm_zero_mask, xmm_minus_inf )
					# xmm_f = xmm_zero_mask

					# if !(x < inf) then f = x
					xmm_inf_mask = SSERegister()
					VCMPNLTPD( xmm_inf_mask, xmm_x, plus_inf )
					VBLENDVPD( xmm_f, xmm_f, xmm_x, xmm_inf_mask )

					# *yPointer = f
					VMOVSD( [yPointer], xmm_f )

				def VECTOR_LOG(xPointer, yPointer):
					c2 = Constant.float64x4('-0x1.FFFFFFFFFFFF2p-2')
					c3 = Constant.float64x4('0x1.5555555555103p-2')
					c4 = Constant.float64x4('-0x1.00000000013C7p-2')
					c5 = Constant.float64x4('0x1.9999999A43E4Fp-3')
					c6 = Constant.float64x4('-0x1.55555554A6A2Bp-3')
					c7 = Constant.float64x4('0x1.249248DAE4B2Ap-3')
					c8 = Constant.float64x4('-0x1.FFFFFFBD8606Dp-4')
					c9 = Constant.float64x4('0x1.C71C90DB06248p-4')
					c10 = Constant.float64x4('-0x1.9999C5BE751E3p-4')
					c11 = Constant.float64x4('0x1.745980F3FB889p-4')
					c12 = Constant.float64x4('-0x1.554D5ACD502ABp-4')
					c13 = Constant.float64x4('0x1.3B4ED39194B87p-4')
					c14 = Constant.float64x4('-0x1.25480A82633AFp-4')
					c15 = Constant.float64x4('0x1.0F23916A44515p-4')
					c16 = Constant.float64x4('-0x1.EED2E2BB64B2Ep-5')
					c17 = Constant.float64x4('0x1.EA17E14773369p-5')
					c18 = Constant.float64x4('-0x1.1654764F478ECp-4')
					c19 = Constant.float64x4('0x1.0266CD08DB2F2p-4')
					c20 = Constant.float64x4('-0x1.CC4EC078138E3p-6')
					ln2_hi = Constant.float64x4('0x1.62E42FEFA3800p-1')
					ln2_lo = Constant.float64x4('0x1.EF35793C76730p-45')
					mantissa_mask = Constant.uint64x4(0x000FFFFFFFFFFFFFL)
					exponent_mask = Constant.uint64x4(0x7FF0000000000000L)
					sqrt2 = Constant.float64x4('0x1.6A09E667F3BCDp+0')
					one = Constant.float64x4('0x1.0000000000000p+0')
					half = Constant.float64x4('0x1.0000000000000p-1')
					denormal_magic = Constant.float64x4('0x1.8000000000000p+52')
					min_normal = Constant.float64x4('0x1.0000000000000p-1022')
					normalized_exponent_bias   = Constant.float64x4('0x1.800003FF00000p+32')
					denormalized_exponent_bias = Constant.float64x4('0x1.8000083100000p+32')
					exponent_magic = Constant.float64x4('0x1.8000000000000p+32')

					nan = Constant.uint64x4(0x7FF8000000000000L)
					plus_inf = Constant.uint64x4(0x7FF0000000000000L)
					minus_inf = Constant.uint64x4(0xFFF0000000000000L)

					t = [AVXRegister() for i in range(6)]
					e = [LocalVariable(AVXRegister) for i in range(6)]

					ymm_normalized_exponent_bias = AVXRegister()
					ymm_denormal_magic = AVXRegister()
					ymm_one = AVXRegister()
					LOAD.CONSTANT( ymm_normalized_exponent_bias, normalized_exponent_bias )
					LOAD.CONSTANT( ymm_denormal_magic, denormal_magic )
					LOAD.CONSTANT( ymm_one, one )
					for i in range(6):
						ymm_x = AVXRegister()
						ymm_e = AVXRegister()
						ymm_dx = AVXRegister()
						ymm_dmask = AVXRegister()
						ymm_tx = AVXRegister()
						ymm_m = AVXRegister()
						ymm_exponent_bias = AVXRegister()
						ymm_amask = AVXRegister()
						ymm_t = t[i]

						# x = *xPointer
						VMOVAPD( ymm_x, [xPointer + i * 32] )
						# dx = as_double(as_ulong(x) | denormal_magic) - denormal_shift
						VORPD( ymm_dx, ymm_x, ymm_denormal_magic )
						VSUBPD( ymm_dx, ymm_dx, ymm_denormal_magic )
						# dmask = x < min_normal
						VCMPLTPD( ymm_dmask, ymm_x, min_normal )
						# tx = (dmask ? dx : x )
						VBLENDVPD( ymm_tx, ymm_x, ymm_dx, ymm_dmask )
						# m = (tx & mantissa_mask) | one
						VANDPD( ymm_m, ymm_tx, mantissa_mask )
						VORPD( ymm_m, ymm_m, ymm_one )
						# e = tx & exponent_mask
						VANDPD( ymm_e, ymm_tx, exponent_mask )
						# exponent_bias = (dmask ? denormalized_exponent_bias : normalized_exponent_bias)
						VBLENDVPD( ymm_exponent_bias, ymm_normalized_exponent_bias, denormalized_exponent_bias, ymm_dmask )
						# convert e to double
						VMOVSHDUP( ymm_e, ymm_e )
						VBLENDPS( ymm_e, ymm_e, exponent_magic, 0xAA )
						VSUBPD( ymm_e, ymm_exponent_bias )

						# amask = m > sqrt(2)
						VCMPGTPD( ymm_amask, ymm_m, sqrt2 )
						ymm_temp = AVXRegister()
						VANDPD( ymm_temp, ymm_amask, ymm_one )
						VADDPD( ymm_e, ymm_e, ymm_temp )
						VMOVAPD( e[i], ymm_e )
						# if m > sqrt(2) then m *= 0.5
						ymm_half_m = AVXRegister()
						VMULPD( ymm_half_m, ymm_m, half )
						VBLENDVPD( ymm_m, ymm_m, ymm_half_m, ymm_amask)
						VSUBPD( ymm_t, ymm_m, ymm_one )

					ymm_f = [AVXRegister() for i in range(6)]
					ymm_c20 = AVXRegister()
					ymm_c19 = AVXRegister()
					LOAD.CONSTANT( ymm_c20, c20 )
					LOAD.CONSTANT( ymm_c19, c19 )
					for i in range(6):
						VFMADDPD( ymm_f[i], ymm_c20, t[i], ymm_c19 )

					def HORNER_STEP(coef):
						ymm_c = AVXRegister()
						LOAD.CONSTANT( ymm_c, coef )
						for i in range(6):
							VFMADDPD( ymm_f[i], ymm_f[i], t[i], ymm_c )

					HORNER_STEP(c18)
					HORNER_STEP(c17)
					HORNER_STEP(c16)
					HORNER_STEP(c15)
					HORNER_STEP(c14)
					HORNER_STEP(c13)
					HORNER_STEP(c12)
					HORNER_STEP(c11)
					HORNER_STEP(c10)
					HORNER_STEP(c9)
					HORNER_STEP(c8)
					HORNER_STEP(c7)
					HORNER_STEP(c6)
					HORNER_STEP(c5)
					HORNER_STEP(c4)
					HORNER_STEP(c3)
					HORNER_STEP(c2)

					for i in range(6):
						if isinstance(t[i], AVXRegister):
							ymm_t = t[i]
						else:
							ymm_t = AVXRegister()
							VMOVAPD( ymm_t, t[i] )

						VMULPD( ymm_f[i], ymm_f[i], ymm_t )
						VFMADDPD( ymm_f[i], ymm_f[i], ymm_t, ymm_t )

					ymm_ln2_lo = AVXRegister()
					ymm_ln2_hi = AVXRegister()
					LOAD.CONSTANT( ymm_ln2_lo, ln2_lo )
					LOAD.CONSTANT( ymm_ln2_hi, ln2_hi )
					for i in range(6):
						ymm_e = AVXRegister()
						VMOVAPD( ymm_e, e[i] )

						VFMADDPD( ymm_f[i], ymm_e, ymm_ln2_lo, ymm_f[i] )
						VFMADDPD( ymm_f[i], ymm_e, ymm_ln2_hi, ymm_f[i] )

					ymm_zero = AVXRegister()
					ymm_minus_inf = AVXRegister()
					ymm_plus_inf = AVXRegister()
					ymm_nan = AVXRegister()
					VXORPD( ymm_zero, ymm_zero, ymm_zero )
					VMOVAPD( ymm_plus_inf, plus_inf )
					VSUBPD( ymm_minus_inf, ymm_zero, ymm_plus_inf )
					VMULPD( ymm_nan, ymm_plus_inf, ymm_zero )
					for i in range(6):
						ymm_x = AVXRegister()
						VMOVAPD( ymm_x, [xPointer + i * 32] )

						ymm_zero_mask = AVXRegister()
						VCMPEQPD( ymm_zero_mask, ymm_x, ymm_zero )
						VBLENDVPD( ymm_f[i], ymm_f[i], ymm_minus_inf, ymm_zero_mask )
						VBLENDVPD( ymm_f[i], ymm_f[i], ymm_nan, ymm_x )
						ymm_inf_nan_mask = AVXRegister()
						VCMPNLTPD( ymm_inf_nan_mask, ymm_x, ymm_plus_inf )
						VBLENDVPD( ymm_f[i], ymm_f[i], ymm_x, ymm_inf_nan_mask )

						VMOVUPD( [yPointer + i * 32], ymm_f[i].get_oword() )
						VEXTRACTF128( [yPointer + i * 32 + 16], ymm_f[i], 1 )

				Map_V64f_V64f(SCALAR_LOG, VECTOR_LOG, xPointer, yPointer, length, 32, 24)

				return codegen.end_function()

# def Log_V64f_V64f_Bulldozer(codegen, function_signature, module, function, inputs, outputs, arguments):
# 	if codegen.abi.name in ['x64-ms', 'x64-sysv']:
# 		if module == 'Math':
# 			if function == 'Log':
# 				x_argument = arguments[0]
# 				y_argument = arguments[1]
# 				length_argument = arguments[2]
#
# 				x_type = x_argument.get_type().get_primitive_type()
# 				y_type = y_argument.get_type().get_primitive_type()
#
# 				if not x_type.is_floating_point() or not y_type.is_floating_point():
# 					return
#
# 				x_size = x_type.get_size(codegen.abi)
# 				y_size = y_type.get_size(codegen.abi)
#
# 				if x_size != 8 or y_size != 8:
# 					return
#
# 				parameters = [x_argument, y_argument, length_argument]
# 				codegen.begin_function(function_signature, parameters, 'Bulldozer')
#
# 				c2 = Constant.float64x2('-0x1.0000000000004p-1')
# 				c3 = Constant.float64x2('0x1.5555555555524p-2')
# 				c4 = Constant.float64x2('-0x1.FFFFFFFFFD99Cp-3')
# 				c5 = Constant.float64x2('0x1.99999999A037Bp-3')
# 				c6 = Constant.float64x2('-0x1.5555555707EC0p-3')
# 				c7 = Constant.float64x2('0x1.24924922E0177p-3')
# 				c8 = Constant.float64x2('-0x1.FFFFFEE6E9A74p-4')
# 				c9 = Constant.float64x2('0x1.C71C7190489D4p-4')
# 				c10 = Constant.float64x2('-0x1.9999CAC62E0ADp-4')
# 				c11 = Constant.float64x2('0x1.745D4E8088327p-4')
# 				c12 = Constant.float64x2('-0x1.55505B48AD061p-4')
# 				c13 = Constant.float64x2('0x1.3B0A137482D51p-4')
# 				c14 = Constant.float64x2('-0x1.24DCC4EF07DB3p-4')
# 				c15 = Constant.float64x2('0x1.11DFFAEDD082Ep-4')
# 				c16 = Constant.float64x2('-0x1.FB780993249D2p-5')
# 				c17 = Constant.float64x2('0x1.CF5EFF4973CFAp-5')
# 				c18 = Constant.float64x2('-0x1.D0CACFA711D8Cp-5')
# 				c19 = Constant.float64x2('0x1.0BA1125E4CABDp-4')
# 				c20 = Constant.float64x2('-0x1.ED49EDACFD1C0p-5')
# 				c21 = Constant.float64x2('0x1.AE7E3413896B4p-6')
# 				ln2_hi = Constant.float64x2('0x1.62E42FEFA3800p-1')
# 				ln2_lo = Constant.float64x2('0x1.EF35793C76730p-45')
# 				magic_mask = Constant.float64x2('0x1.0000000000040p+52')
# 				magic_bias = Constant.float64x2('0x1.000000000043Fp+52')
# 				sqrt2 = Constant.float64x2('0x1.6A09E667F3BCDp+0')
# 				one = Constant.float64x2('0x1.0000000000000p+0')
# 				mantissa_mask = Constant.uint64x2(0x000FFFFFFFFFFFFFL)
# 				half_exp_mask = Constant.uint64x2(0x0010000000000000L)
#
# 				sign_mask = Constant.uint64x2(0x8000000000000000L)
# 				min_normal = Constant.float64x2('0x1.0000000000000p-1022')
# 				denormal_exp_shift = Constant.uint64x2(0x0400000000000000L)
# 				special_magic_mask = Constant.float64x2('0x1.0000000000000p+52')
# 				nan = Constant.uint64x2(0x7FF8000000000000L)
# 				plus_inf = Constant.uint64x2(0x7FF0000000000000)
# 				minus_inf = Constant.uint64x2(0xFFF0000000000000)
#
# 				e = [LocalVariable(SSERegister) for index in range(10)]
#
# 				xPointer = GeneralPurposeRegister64()
# 				yPointer = GeneralPurposeRegister64()
# 				length = GeneralPurposeRegister64()
#
# 				LOAD.PARAMETER( xPointer, x_argument )
# 				LOAD.PARAMETER( yPointer, y_argument )
# 				LOAD.PARAMETER( length, length_argument )
#
# 				def SCALAR_LOG(xPointer, yPointer):
# 					xmm_denormal_exp_shift = SSERegister()
# 					xmm_one = SSERegister()
# 					xmm_min_normal = SSERegister()
# 					xmm_special_magic_mask = SSERegister()
#
# 					LOAD.CONSTANT( xmm_denormal_exp_shift, denormal_exp_shift )
# 					LOAD.CONSTANT( xmm_one, one )
# 					LOAD.CONSTANT( xmm_min_normal, min_normal )
# 					LOAD.CONSTANT( xmm_special_magic_mask, special_magic_mask )
#
# 					xmm_x = SSERegister()
# 					xmm_e = SSERegister()
# 					xmm_copy = SSERegister()
# 					xmm_mask = SSERegister()
#
# 					# Load an element
# 					VMOVSD( xmm_copy, [xPointer] )
# 					# Check for denormals (zero and negatives will be processed separately later)
# 					VCMPLTSD( xmm_e, xmm_copy, xmm_min_normal )
# 					# Get 0x40 in the exponent field if the input element is denormal
# 					VPAND( xmm_e, xmm_denormal_exp_shift )
# 					# Set the factor to 0x1.0p+64 if the element is denormal (otherwise leave it 1.0)
# 					VPADDD( xmm_x, xmm_one, xmm_e )
# 					# Get 64 in the exponent field if the input element is no denormal
# 					VPXOR( xmm_e, xmm_denormal_exp_shift )
# 					# If the input element is denormal, multiply it by 0x1.0p+64
# 					VMULSD( xmm_x, xmm_copy )
# 					# Get the normalized exponent of the initial number + 64 in the higher 12 bits of xmm_x
# 					# This works for positive number, negative numbers will be separately processed later
# 					VPADDD( xmm_e, xmm_x )
# 					# Shift the (normalized exponent + 64) values to the mantissa
# 					VPSRLQ( xmm_e, 52 )
#
# 					# Get normalized mantissa (without the implied bit)
# 					VPAND( xmm_x, mantissa_mask )
# 					# Insert the exponent to make elements between 1.0 (inclusive) and 2.0 (exclusive)
# 					VPOR( xmm_x, xmm_one )
#
# 					# Load mask with square root of two
# 					LOAD.CONSTANT( xmm_mask, sqrt2 )
# 					# Check if the normalized element is above square root of two
# 					VCMPLEPD( xmm_mask, xmm_x )
# 					# If yes, increment the exponent variable
# 					VPSUBQ( xmm_e, xmm_mask )
# 					# Convert the exponent variable into double precision number (and subtract 64)
# 					VPOR( xmm_e, xmm_special_magic_mask )
# 					# And get 1 in the exponent part of double-precision number
# 					VPAND( xmm_mask, half_exp_mask )
# 					# If normalized element is above square root of two, multiply it by 0.5 (by subtracting 1 from exponent)
# 					VPSUBQ( xmm_x, xmm_mask )
# 					# Store the exponent variable back
# 					VMOVDQA( e[0], xmm_e )
#
# 					xmm_nan = SSERegister()
# 					xmm_ones_mask = SSERegister()
# 					LOAD.CONSTANT( xmm_nan, nan )
# 					VPCMPEQB( xmm_ones_mask, xmm_ones_mask )
#
# 					xmm_mask = SSERegister()
#
# 					# Load the input element
# 					VMOVSD( xmm_mask, [xPointer] )
# 					# Check if the input element is not negative
# 					# Mask is ones if negative
# 					VPCMPGTQ( xmm_mask, xmm_ones_mask )
# 					# If negative, then set x to zero
# 					VPAND( xmm_x, xmm_mask )
# 					# If negative, then set the mask to NaN
# 					VPANDN( xmm_mask, xmm_nan )
# 					# If negative, then set x to NaN
# 					VPOR( xmm_x, xmm_mask )
#
# 					xmm_minus_inf = SSERegister()
# 					xmm_zero = SSERegister()
# 					LOAD.CONSTANT( xmm_minus_inf, minus_inf )
# 					VPXOR( xmm_zero, xmm_zero )
#
# 					xmm_temp = SSERegister()
#
# 					# Load the pair of input elements
# 					VMOVSD( xmm_temp, [xPointer] )
# 					# Compare to +0.0 (-0.0 produces NaN)
# 					VPCMPEQQ( xmm_temp, xmm_zero )
# 					# If the input element is +0.0 get -inf in the temp register
# 					VPAND( xmm_temp, xmm_minus_inf )
# 					# If the input element is +0.0 then x is 1.0
# 					# Set the high 12 bits to get -inf (-inf OR 1.0 == -inf)
# 					VPOR( xmm_x, xmm_temp )
#
# 					xmm_plus_inf = SSERegister()
# 					LOAD.CONSTANT( xmm_plus_inf, plus_inf )
#
# 					xmm_temp = SSERegister()
#
# 					# Load the pair of input elements
# 					VMOVSD( xmm_temp, [xPointer] )
# 					# Check if the input is +inf
# 					VPCMPEQQ( xmm_temp, xmm_plus_inf )
# 					# If the input is +inf, get +inf in the temp register
# 					VPAND( xmm_temp, xmm_plus_inf )
# 					# If the input element is +inf then x is 1.0
# 					# Set the exponent bits of x to get +inf (+inf OR 1.0 == +inf)
# 					VPOR( xmm_x, xmm_temp )
#
# 					xmm_temp = SSERegister()
# 					xmm_copy = SSERegister()
#
# 					# Load the pair of input elements
# 					VMOVSD( xmm_temp, [xPointer] )
# 					# Duplicate the pair of elements
# 					VMOVAPS( xmm_copy, xmm_temp )
# 					# Test the input elements for being NaN.
# 					# If they are not NaN then temp variable is set to all ones
# 					VCMPEQSD( xmm_temp, xmm_temp )
# 					# Zero x if the input element is NaN
# 					VPAND( xmm_x, xmm_temp )
# 					# Get the input element in the temp register if the former is NaN
# 					VPANDN( xmm_temp, xmm_copy )
# 					# Replace x with the input element if the latter is NaN
# 					VPOR( xmm_x, xmm_temp )
#
# 					xmm_one = SSERegister()
# 					LOAD.CONSTANT( xmm_one, one )
#
# 					VSUBPD( xmm_x, xmm_one )
#
# 					acc = SSERegister()
#
# 					LOAD.CONSTANT( acc, c21 )
#
# 					def HORNER_STEP(coef):
# 						xmm_c = SSERegister()
# 						LOAD.CONSTANT( xmm_c, coef )
# 						VFMADDSD( acc, acc, xmm_x, xmm_c )
#
# 					HORNER_STEP(c20)
# 					HORNER_STEP(c19)
# 					HORNER_STEP(c18)
# 					HORNER_STEP(c17)
# 					HORNER_STEP(c16)
# 					HORNER_STEP(c15)
# 					HORNER_STEP(c14)
# 					HORNER_STEP(c13)
# 					HORNER_STEP(c12)
# 					HORNER_STEP(c11)
# 					HORNER_STEP(c10)
# 					HORNER_STEP(c9)
# 					HORNER_STEP(c8)
# 					HORNER_STEP(c7)
# 					HORNER_STEP(c6)
# 					HORNER_STEP(c5)
# 					HORNER_STEP(c4)
# 					HORNER_STEP(c3)
# 					HORNER_STEP(c2)
#
# 					xmm_magic_bias = SSERegister()
# 					LOAD.CONSTANT( xmm_magic_bias, magic_bias )
#
# 					xmm_e = SSERegister()
# 					VMOVAPS( xmm_e, e[0] )
# 					VSUBSD( xmm_e, xmm_magic_bias )
# 					VMOVAPS( e[0], xmm_e )
#
# 					VMULSD( acc, xmm_x )
# 					VFMADDSD( acc, acc, xmm_x, xmm_x )
#
# 					xmm_ln2_lo = SSERegister()
# 					xmm_ln2_hi = SSERegister()
# 					LOAD.CONSTANT( xmm_ln2_lo, ln2_hi )
# 					LOAD.CONSTANT( xmm_ln2_hi, ln2_hi )
#
# 					xmm_e = SSERegister()
# 					xmm_temp = SSERegister()
#
# 					VMOVAPS( xmm_e, e[0] )
#
# 					VFMADDSD( acc, xmm_e, xmm_ln2_lo, acc )
# 					VFMADDSD( acc, xmm_e, xmm_ln2_hi, acc )
# 					VMOVSD( [yPointer], acc )
#
#
# 				LABEL( 'process_by_1_prolog' )
# 				TEST( xPointer, 15 )
# 				JZ( 'process_by_20_prolog' )
#
# 				SCALAR_LOG( xPointer, yPointer )
#
# 				ADD( xPointer, 8 )
# 				ADD( yPointer, 8 )
# 				SUB( length, 1 )
# 				JNZ( 'process_by_1_prolog' )
#
# 				LABEL( 'process_by_20_prolog' )
#
# 				SUB( length, 20 )
# 				JB('process_by_20_epilog')
#
# 				ALIGN(32)
# 				LABEL('process_by_20')
#
# 				xmm_magic_mask = SSERegister()
# 				xmm_half_exp_mask = SSERegister()
# 				xmm_mantissa_mask = SSERegister()
# 				xmm_one = SSERegister()
#
# 				LOAD.CONSTANT( xmm_magic_mask, magic_mask )
# 				LOAD.CONSTANT( xmm_half_exp_mask, half_exp_mask )
# 				LOAD.CONSTANT( xmm_mantissa_mask, mantissa_mask )
# 				LOAD.CONSTANT( xmm_one, one )
#
# 				xmm_x_global = [SSERegister() for index in range(10)]
#
# 				xmm_x = xmm_x_global
#
# 				for index in range(10):
# 					x_hi = GeneralPurposeRegister32()
# 					xmm_temp = SSERegister()
# 					xmm_mask = SSERegister()
#
# 					# Load a pair of elements
# 					VMOVDQA( xmm_x[index], [xPointer + index * 16] )
# 					# Load the high part of the first element
# 					MOV( x_hi, [xPointer + index * 16 + 4] )
# 					VPSRLQ( xmm_temp, xmm_x[index], 52 )
# 					VPAND( xmm_x[index], xmm_mantissa_mask )
# 					SUB( x_hi, 0x80100000 )
# 					VPOR( xmm_x[index], xmm_one )
# 					CMP( x_hi, 0xFFD00000 )
# 					JG( 'process_by_20_special' )
# 					LOAD.CONSTANT( xmm_mask, sqrt2 )
# 					VCMPLEPD( xmm_mask, xmm_x[index] )
# 					MOV( x_hi, [xPointer + index * 16 + 12] )
# 					VPSUBQ( xmm_temp, xmm_mask )
# 					VPADDQ( xmm_temp, xmm_magic_mask )
# 					SUB( x_hi, 0x80100000 )
# 					VPAND( xmm_mask, xmm_half_exp_mask )
# 					VPSUBQ( xmm_x[index], xmm_mask )
# 					CMP( x_hi, 0xFFD00000 )
# 					JG( 'process_by_20_special' )
# 					VMOVDQA( e[index], xmm_temp )
#
# 				LABEL( 'process_by_20_horner' )
#
# 				x = xmm_x[0:4] + [LocalVariable(SSERegister) for index in range(6)]
#
# 				xmm_one = SSERegister()
# 				LOAD.CONSTANT( xmm_one, one )
#
# 				for index in range(10):
# 					VSUBPD( xmm_x[index], xmm_one )
# 					if isinstance(x[index], LocalVariable):
# 						VMOVAPS( x[index], xmm_x[index] )
#
# 				acc = [SSERegister() for index in range(10)]
#
# 				xmm_c21 = SSERegister()
# 				LOAD.CONSTANT( xmm_c21, c21 )
#
# 				xmm_c20 = SSERegister()
# 				LOAD.CONSTANT( xmm_c20, c20 )
# 				for index in range(10):
# 					VFMADDPD( acc[index], xmm_c21, x[index], xmm_c20 )
#
# 				def HORNER_STEP(coef):
# 					xmm_c = SSERegister()
# 					LOAD.CONSTANT( xmm_c, coef )
#
# 					for index in range(10):
# 						VFMADDPD( acc[index], acc[index], x[index], xmm_c )
#
# 				HORNER_STEP(c19)
# 				HORNER_STEP(c18)
# 				HORNER_STEP(c17)
# 				HORNER_STEP(c16)
# 				HORNER_STEP(c15)
# 				HORNER_STEP(c14)
# 				HORNER_STEP(c13)
# 				HORNER_STEP(c12)
# 				HORNER_STEP(c11)
# 				HORNER_STEP(c10)
# 				HORNER_STEP(c9)
# 				HORNER_STEP(c8)
# 				HORNER_STEP(c7)
# 				HORNER_STEP(c6)
# 				HORNER_STEP(c5)
# 				HORNER_STEP(c4)
# 				HORNER_STEP(c3)
# 				HORNER_STEP(c2)
#
#
# 				for index in range(10):
# 					if isinstance(x[index], SSERegister):
# 						xmm_x = x[index]
# 					else:
# 						xmm_x = SSERegister()
# 						VMOVAPS( xmm_x, x[index] )
#
# 					VMULPD( acc[index], xmm_x )
# 					VFMADDPD( acc[index], acc[index], xmm_x, xmm_x )
#
# 				xmm_ln2_lo = SSERegister()
# 				xmm_ln2_hi = SSERegister()
# 				LOAD.CONSTANT( xmm_ln2_lo, ln2_lo )
# 				LOAD.CONSTANT( xmm_ln2_hi, ln2_hi )
#
#
# 				xmm_magic_bias = SSERegister()
# 				LOAD.CONSTANT( xmm_magic_bias, magic_bias )
# 				for index in range(10):
# 					xmm_e = SSERegister()
#
# 					VMOVAPS( xmm_e, e[index] )
# 					VSUBPD( xmm_e, xmm_e, xmm_magic_bias )
# 					VFMADDPD( acc[index], xmm_ln2_lo, xmm_e, acc[index] )
# 					VFMADDPD( acc[index], xmm_ln2_hi, xmm_e, acc[index] )
# 					VMOVUPS( [yPointer + 16 * index], acc[index] )
#
# 				ADD( xPointer, 160 )
# 				ADD( yPointer, 160 )
# 				SUB( length, 20 )
# 				JAE( 'process_by_20' )
#
# 				LABEL( 'process_by_20_epilog' )
#
# 				ADD( length, 20 )
# 				JZ( 'return_ok' )
#
# 				LABEL( 'process_by_1_epilog' )
#
# 				SCALAR_LOG( xPointer, yPointer )
#
# 				ADD( xPointer, 8 )
# 				ADD( yPointer, 8 )
# 				SUB( length, 1 )
# 				JNZ( 'process_by_1_epilog' )
#
# 				LABEL( 'return_ok' )
# 				RETURN( 0 )
#
# 				LABEL( 'process_by_20_special' )
#
# 				xmm_denormal_exp_shift = SSERegister()
# 				xmm_one = SSERegister()
# 				xmm_min_normal = SSERegister()
# 				xmm_special_magic_mask = SSERegister()
#
# 				LOAD.CONSTANT( xmm_denormal_exp_shift, denormal_exp_shift )
# 				LOAD.CONSTANT( xmm_one, one )
# 				LOAD.CONSTANT( xmm_min_normal, min_normal )
# 				LOAD.CONSTANT( xmm_special_magic_mask, special_magic_mask )
#
# 				xmm_x = xmm_x_global
#
# 				for index in range(10):
# 					xmm_e = SSERegister()
# 					xmm_copy = SSERegister()
# 					xmm_mask = SSERegister()
#
# 					# Load a pair of elements
# 					VMOVAPS( xmm_copy, [xPointer + index * 16] )
# 					# Check for denormals (zero and negatives will be processed separately later)
# 					VCMPLTPD( xmm_e, xmm_copy, xmm_min_normal )
# 					# Get 0x40 in the exponent field if the input element is denormal
# 					VPAND( xmm_e, xmm_denormal_exp_shift )
# 					# Set the factor to 0x1.0p+64 if the element is denormal (otherwise leave it 1.0)
# 					VPADDD( xmm_x[index], xmm_one, xmm_e )
# 					# Get 64 in the exponent field if the input element is no denormal
# 					VPXOR( xmm_e, xmm_denormal_exp_shift )
# 					# If the input element is denormal, multiply it by 0x1.0p+64
# 					VMULPD( xmm_x[index], xmm_copy )
# 					# Get the normalized exponent of the initial number + 64 in the higher 12 bits of xmm_x
# 					# This works for positive number, negative numbers will be separately processed later
# 					VPADDD( xmm_e, xmm_x[index] )
# 					# Shift the (normalized exponent + 64) values to the mantissa
# 					VPSRLQ( xmm_e, 52 )
#
# 					# Get normalized mantissa (without the implied bit)
# 					VPAND( xmm_x[index], mantissa_mask )
# 					# Insert the exponent to make elements between 1.0 (inclusive) and 2.0 (exclusive)
# 					VPOR( xmm_x[index], xmm_one )
#
# 					# Load mask with square root of two
# 					LOAD.CONSTANT( xmm_mask, sqrt2 )
# 					# Check if the normalized element is above square root of two
# 					VCMPLEPD( xmm_mask, xmm_x[index] )
# 					# If yes, increment the exponent variable
# 					VPSUBQ( xmm_e, xmm_mask )
# 					# Convert the exponent variable into double precision number (and subtract 64)
# 					VPOR( xmm_e, xmm_special_magic_mask )
# 					# And get 1 in the exponent part of double-precision number
# 					VPAND( xmm_mask, half_exp_mask )
# 					# If normalized element is above square root of two, multiply it by 0.5 (by subtracting 1 from exponent)
# 					VPSUBQ( xmm_x[index], xmm_mask )
# 					# Store the exponent variable back
# 					VMOVDQA( e[index], xmm_e )
#
# 				xmm_nan = SSERegister()
# 				xmm_ones_mask = SSERegister()
# 				LOAD.CONSTANT( xmm_nan, nan )
# 				VPCMPEQB( xmm_ones_mask, xmm_ones_mask )
#
# 				for index in range(10):
# 					xmm_mask = SSERegister()
#
# 					# Load the input element
# 					VMOVDQA( xmm_mask, [xPointer + index * 16] )
# 					# Check if the input element is not negative
# 					# Mask is ones if negative
# 					VPCMPGTQ( xmm_mask, xmm_ones_mask )
# 					# If negative, then set x to zero
# 					VPAND( xmm_x[index], xmm_mask )
# 					# If negative, then set the mask to NaN
# 					VPANDN( xmm_mask, xmm_nan )
# 					# If negative, then set x to NaN
# 					VPOR( xmm_x[index], xmm_mask )
#
# 				xmm_minus_inf = SSERegister()
# 				xmm_zero = SSERegister()
# 				LOAD.CONSTANT( xmm_minus_inf, minus_inf )
# 				VPXOR( xmm_zero, xmm_zero )
#
# 				for index in range(10):
# 					xmm_temp = SSERegister()
#
# 					# Load the pair of input elements
# 					VMOVDQA( xmm_temp, [xPointer + index * 16] )
# 					# Compare to +0.0 (-0.0 produces NaN)
# 					VPCMPEQQ( xmm_temp, xmm_zero )
# 					# If the input element is +0.0 get -inf in the temp register
# 					VPAND( xmm_temp, xmm_minus_inf )
# 					# If the input element is +0.0 then x is 1.0
# 					# Set the high 12 bits to get -inf (-inf OR 1.0 == -inf)
# 					VPOR( xmm_x[index], xmm_temp )
#
# 				xmm_plus_inf = SSERegister()
# 				LOAD.CONSTANT( xmm_plus_inf, plus_inf )
#
# 				for index in range(10):
# 					xmm_temp = SSERegister()
#
# 					# Load the pair of input elements
# 					VMOVDQA( xmm_temp, [xPointer + index * 16] )
# 					# Check if the input is +inf
# 					VPCMPEQQ( xmm_temp, xmm_plus_inf )
# 					# If the input is +inf, get +inf in the temp register
# 					VPAND( xmm_temp, xmm_plus_inf )
# 					# If the input element is +inf then x is 1.0
# 					# Set the exponent bits of x to get +inf (+inf OR 1.0 == +inf)
# 					VPOR( xmm_x[index], xmm_temp )
#
# 				for index in range(10):
# 					xmm_temp = SSERegister()
# 					xmm_copy = SSERegister()
#
# 					# Load the pair of input elements
# 					VMOVAPS( xmm_copy, [xPointer + index * 16] )
# 					# Test the input elements for being NaN.
# 					# If they are not NaN then temp variable is set to all ones
# 					VCMPEQPD( xmm_temp, xmm_copy, xmm_copy )
# 					# Zero x if the input element is NaN
# 					VPAND( xmm_x[index], xmm_temp )
# 					# Get the input element in the temp register if the former is NaN
# 					VPANDN( xmm_temp, xmm_copy )
# 					# Replace x with the input element if the latter is NaN
# 					VPOR( xmm_x[index], xmm_temp )
#
# 				JMP('process_by_20_horner')
#
# 				return codegen.end_function()

# def Exp_V64f_V64f_Nehalem(codegen, function_signature, module, function, inputs, outputs, arguments):
# 	if codegen.abi.name in ['x64-sysv', 'x64-ms']:
# 		if module == 'Math':
# 			if function == 'Exp':
# 				x_argument = arguments[0]
# 				y_argument = arguments[1]
# 				length_argument = arguments[2]
#
# 				x_type = x_argument.get_type().get_primitive_type()
# 				y_type = y_argument.get_type().get_primitive_type()
#
# 				if not x_type.is_floating_point() or not y_type.is_floating_point():
# 					return
#
# 				x_size = x_type.get_size(codegen.abi)
# 				y_size = y_type.get_size(codegen.abi)
#
# 				if x_size != 8 or y_size != 8:
# 					return
#
# 				parameters = [x_argument, y_argument, length_argument]
# 				codegen.begin_function(function_signature, parameters, 'Nehalem')
#
# 				signMask = Constant.float64x2(-0.0)
# 				magicBias = Constant.float64x2('0x1.00000000003FFp+52')
# 				specialMagicBias = Constant.float64x2('0x1.00000000007FEp+52')
# 				zeroCutoff = Constant.float64x2('-0x1.74385446D71C3p+9')
# 				infCutoff = Constant.float64x2('0x1.62E42FEFA39EFp+9')
# 				log2e = Constant.float64x2('0x1.71547652B82FEp+0')
# 				ln2_hi = Constant.float64x2('0x1.62E42FEFA3800p-1')
# 				ln2_lo = Constant.float64x2('0x1.EF35793C76730p-45')
#
# 				one = Constant.float64x2(1.0)
# 				c2 = Constant.float64x2('0x1.000000000000Cp-1')
# 				c3 = Constant.float64x2('0x1.5555555555522p-3')
# 				c4 = Constant.float64x2('0x1.555555554FE5Cp-5')
# 				c5 = Constant.float64x2('0x1.111111111DC0Ap-7')
# 				c6 = Constant.float64x2('0x1.6C16C185EC9E1p-10')
# 				c7 = Constant.float64x2('0x1.A01A016020E85p-13')
# 				c8 = Constant.float64x2('0x1.A019960BCB82Ap-16')
# 				c9 = Constant.float64x2('0x1.71DEADCE6F1F1p-19')
# 				c10 = Constant.float64x2('0x1.28B0A7EA5C532p-22')
# 				c11 = Constant.float64x2('0x1.AE3BB8191C002p-26')
#
# 				exponentCutDown = Constant.uint64x2(0x0010000000000000L)
# 				exponentCutUp   = Constant.uint64x2(0x7F00000000000000L)
#
# 				inf = Constant.uint64x2(0x7FF0000000000000L)
#
# 				xPointer = GeneralPurposeRegister64()
# 				yPointer = GeneralPurposeRegister64()
# 				length = GeneralPurposeRegister64()
#
# 				LOAD.PARAMETER( xPointer, x_argument )
# 				LOAD.PARAMETER( yPointer, y_argument )
# 				LOAD.PARAMETER( length, length_argument )
#
# 				def scalar_exp():
# 					xmm_x = SSERegister()
#
# 					xmm_ln2_lo = SSERegister()
# 					xmm_ln2_hi = SSERegister()
# 					xmm_magic_bias = SSERegister()
# 					xmm_log2e = SSERegister()
# 					LOAD.CONSTANT( xmm_ln2_lo, ln2_lo )
# 					LOAD.CONSTANT( xmm_ln2_hi, ln2_hi )
# 					LOAD.CONSTANT( xmm_magic_bias, magicBias )
# 					LOAD.CONSTANT( xmm_log2e, log2e )
#
# 					xmm_temp = SSERegister()
# 					xmm_copy = SSERegister()
# 					xmm_factor_extra = SSERegister()
# 					xmm_factor   = SSERegister()
#
# 					# Load two elements
# 					MOVSD( xmm_temp, [xPointer] )
# 					# Duplicate loaded elements
# 					MOVAPS( xmm_x, xmm_temp )
# 					# Multiply by log2e
# 					MULSD( xmm_temp, xmm_log2e )
# 					# Round to integer
# 					ADDSD( xmm_temp, xmm_magic_bias )
# 					# Save the integer factor int(round(x * log2e)) + 0x3FF
# 					MOVAPS( xmm_factor, xmm_temp )
# 					# Subtract the bias. Get round(x * log2e)
# 					SUBSD( xmm_temp, xmm_magic_bias )
# 					# Make a copy of the round(x * log2e) values
# 					MOVAPS( xmm_copy, xmm_temp )
# 					# Muliply round(x * log2e) by ln2 (high part)
# 					MULSD( xmm_temp, xmm_ln2_hi )
# 					# Compute x - round(x * log2e) * ln2_hi
# 					SUBSD( xmm_x, xmm_temp )
# 					# Multiply round(x * log2e) by ln2 (low part)
# 					MULPD( xmm_copy, xmm_ln2_lo )
# 					# Compute x - round(x * log2e) * ln2_hi - round(x * log2e) * ln2_lo
# 					SUBSD( xmm_x, xmm_copy )
#
# 					xmm_exponent_cut_down = SSERegister()
# 					xmm_exponent_cut_up   = SSERegister()
# 					xmm_one               = SSERegister()
#
# 					LOAD.CONSTANT( xmm_exponent_cut_down, exponentCutDown )
# 					LOAD.CONSTANT( xmm_exponent_cut_up,   exponentCutUp )
# 					LOAD.CONSTANT( xmm_one,               one )
#
#
# 					PSLLQ( xmm_factor, 52 )
# 					MOVDQA( xmm_factor_extra, xmm_factor )
# 					PMAXUW( xmm_factor, xmm_exponent_cut_down )
# 					PADDW( xmm_factor_extra, xmm_one )
# 					PMINUW( xmm_factor, xmm_exponent_cut_up   )
# 					PSUBW( xmm_factor_extra, xmm_factor )
#
# 					acc = SSERegister()
#
# 					LOAD.CONSTANT( acc, c11 )
#
# 					def horner_step(coef, acc):
# 						xmm_c = SSERegister()
# 						LOAD.CONSTANT( xmm_c, coef )
# 						MULSD( acc, xmm_x )
# 						ADDSD( acc, xmm_c )
#
# 					horner_step(c10, acc)
# 					horner_step(c9, acc)
# 					horner_step(c8, acc)
# 					horner_step(c7, acc)
# 					horner_step(c6, acc)
# 					horner_step(c5, acc)
# 					horner_step(c4, acc)
# 					horner_step(c3, acc)
# 					horner_step(c2, acc)
#
# 					MULSD( acc, xmm_x )
# 					MULSD( acc, xmm_x )
# 					ADDSD( acc, xmm_x )
#
# 					MULSD( acc, xmm_factor_extra )
# 					ADDSD( acc, xmm_factor_extra )
#
# 					xmm_zero_cutoff = SSERegister()
# 					xmm_inf_cutoff  = SSERegister()
# 					xmm_inf         = SSERegister()
# 					LOAD.CONSTANT( xmm_zero_cutoff, zeroCutoff )
# 					LOAD.CONSTANT( xmm_inf_cutoff, infCutoff )
# 					LOAD.CONSTANT( xmm_inf, inf )
#
# 					xmm_zero_mask = SSERegister()
#
# 					MULSD( acc, xmm_factor )
# 					MOVSD( xmm_zero_mask, [xPointer] )
# 					CMPNLTSD( xmm_zero_mask, xmm_zero_cutoff )
# 					ANDPD( acc, xmm_zero_mask )
#
# 					MOVAPS( xmm0, xmm_inf_cutoff )
# 					CMPLTSD( xmm0, [xPointer] )
# 					BLENDVPD( acc, xmm_inf, xmm0 )
# 					MOVSD( [yPointer], acc )
#
#
# 				LABEL( 'process_by_1_prologue' )
# 				TEST( xPointer, 15 )
# 				JZ( 'process_by_20_prologue' )
#
# 				scalar_exp()
# 				ADD( xPointer, 8 )
# 				ADD( yPointer, 8 )
# 				SUB( length, 1 )
# 				JNZ( 'process_by_1_prologue' )
#
# 				LABEL( 'process_by_20_prologue' )
# 				SUB( length, 20 )
# 				JB( 'process_by_20_epilogue' )
#
# 				ALIGN( 32 )
# 				LABEL( 'process_by_20' )
#
# 				xmm_ln2_lo = SSERegister()
# 				xmm_ln2_hi = SSERegister()
# 				xmm_magic_bias = SSERegister()
# 				xmm_log2e = SSERegister()
# 				LOAD.CONSTANT( xmm_ln2_lo, ln2_lo )
# 				LOAD.CONSTANT( xmm_ln2_hi, ln2_hi )
# 				LOAD.CONSTANT( xmm_magic_bias, magicBias )
# 				LOAD.CONSTANT( xmm_log2e, log2e )
#
# 				x_vars = [LocalVariable(SSERegister) for index in range(6)]
# 				x = [SSERegister() for index in range(4)] + x_vars
# 				factors = [LocalVariable(SSERegister) for index in range(10)]
# 				factors_extra = [LocalVariable(SSERegister) for index in range(10)]
#
# 				for index in range(10):
# 					if isinstance(x[index], Register):
# 						xmm_x = x[index]
# 					else:
# 						xmm_x = SSERegister()
#
# 					xmm_temp = SSERegister()
# 					xmm_factor = SSERegister()
# 					xmm_copy = SSERegister()
# 					x_hi = GeneralPurposeRegister32()
#
# 					# Load two elements
# 					MOVAPS( xmm_x, [xPointer + index * 16] )
# 					# Duplicate loaded elements
# 					MOVAPS( xmm_temp, xmm_x )
# 					# Load the high part of the first element in the SSE register
# 					MOV( x_hi, [xPointer + index * 16 + 4] )
# 					# Multiply by log2e
# 					MULPD( xmm_temp, xmm_log2e )
# 					# Remove the sign of the high part of the first element in the SSE register
# 					ADD( x_hi, x_hi )
# 					# Round to integer
# 					ADDPD( xmm_temp, xmm_magic_bias )
# 					# Check the high part of the first element in the SSE register for special case
# 					CMP( x_hi, 0x810C4BE0 )
# 					JA( 'process_by_20_special' )
# 					# Extract the integer factor int(round(x * log2e)) + 0x3FF
# 					MOVAPS( xmm_factor, xmm_temp )
# 					# Move the scaling factor to the exponent field of double-precision number
# 					PSLLQ( xmm_factor, 52 )
# 					# Subtract the bias. Get round(x * log2e)
# 					SUBPD( xmm_temp, xmm_magic_bias )
# 					# Load the high part of the second element in the SSE register
# 					MOV( x_hi, [xPointer + index * 16 + 12] )
# 					# Save the scaling factor to a local variable
# 					MOVAPS( factors[index], xmm_factor )
# 					# Make a copy of the round(x * log2e) values
# 					MOVAPS( xmm_copy, xmm_temp )
# 					# Muliply round(x * log2e) by ln2 (high part)
# 					MULPD( xmm_temp, xmm_ln2_hi )
# 					# Remove the sign of the high part of the second element in the SSE register
# 					ADD( x_hi, x_hi )
# 					# Compute x - round(x * log2e) * ln2_hi
# 					SUBPD( xmm_x, xmm_temp )
# 					# Multiply round(x * log2e) by ln2 (low part)
# 					MULPD( xmm_copy, xmm_ln2_lo )
# 					# Check the high part of the first element in the SSE register for special case
# 					CMP( x_hi, 0x810C4BE0 )
# 					JA( 'process_by_20_special' )
# 					# Compute x - round(x * log2e) * ln2_hi - round(x * log2e) * ln2_lo
# 					SUBPD( xmm_x, xmm_copy )
# 					if isinstance(x[index], LocalVariable):
# 						MOVAPS(x[index], xmm_x)
#
# 				acc = [SSERegister() for index in range(10)]
#
# 				for index in range(10):
# 					if index % 4 == 0:
# 						LOAD.CONSTANT( acc[index], c11 )
# 					else:
# 						MOVAPS( acc[index], acc[index & -4] )
#
# 				def horner_step(coef, acc):
# 					xmm_c = SSERegister()
# 					LOAD.CONSTANT( xmm_c, coef )
# 					for index in range(10):
# 						if isinstance(x[index], Register):
# 							xmm_x = x[index]
# 						else:
# 							xmm_x = SSERegister()
# 							MOVAPS( xmm_x, x[index] )
#
# 						MULPD( acc[index], xmm_x )
# 						ADDPD( acc[index], xmm_c )
#
# 				horner_step(c10, acc)
# 				horner_step(c9, acc)
# 				horner_step(c8, acc)
# 				horner_step(c7, acc)
# 				horner_step(c6, acc)
# 				horner_step(c5, acc)
# 				horner_step(c4, acc)
# 				horner_step(c3, acc)
# 				horner_step(c2, acc)
#
# 				for index in range(10):
# 					if isinstance(x[index], Register):
# 						xmm_x = x[index]
# 					else:
# 						xmm_x = SSERegister()
# 						MOVAPS( xmm_x, x[index] )
# 					MULPD( acc[index], xmm_x )
# 					MULPD( acc[index], xmm_x )
# 					ADDPD( acc[index], xmm_x )
#
# 				for index in range(10):
# 					xmm_factor = SSERegister()
# 					MOVAPS( xmm_factor, factors[index] )
# 					MULPD( acc[index], xmm_factor )
# 					ADDPD( acc[index], xmm_factor )
# 					MOVUPS( [yPointer + index * 16], acc[index] )
#
# 				ADD( xPointer, 160 )
# 				ADD( yPointer, 160 )
# 				SUB( length, 20 )
# 				JAE( 'process_by_20' )
#
# 				LABEL( 'process_by_20_epilogue' )
# 				ADD( length, 20 )
# 				JZ( 'return_ok' )
#
# 				LABEL( 'process_by_1_epilogue' )
# 				scalar_exp()
# 				ADD( xPointer, 8 )
# 				ADD( yPointer, 8 )
# 				SUB( length, 1 )
# 				JNZ( 'process_by_1_epilogue' )
#
# 				LABEL( 'return_ok' )
# 				RETURN(0)
#
# 				LABEL( 'process_by_20_special' )
#
# 				x = [SSERegister() for index in range(4)] + x_vars
#
# 				xmm_ln2_lo = SSERegister()
# 				xmm_ln2_hi = SSERegister()
# 				xmm_magic_bias = SSERegister()
# 				xmm_log2e = SSERegister()
# 				LOAD.CONSTANT( xmm_ln2_lo, ln2_lo )
# 				LOAD.CONSTANT( xmm_ln2_hi, ln2_hi )
# 				LOAD.CONSTANT( xmm_magic_bias, magicBias )
# 				LOAD.CONSTANT( xmm_log2e, log2e )
#
# 				for index in range(10):
# 					if isinstance(x[index], Register):
# 						xmm_x = x[index]
# 					else:
# 						xmm_x = SSERegister()
#
# 					xmm_temp = SSERegister()
# 					xmm_copy = SSERegister()
#
# 					# Load two elements
# 					MOVAPS( xmm_temp, [xPointer + index * 16] )
# 					# Duplicate loaded elements
# 					MOVAPS( xmm_x, xmm_temp )
# 					# Multiply by log2e
# 					MULPD( xmm_temp, xmm_log2e )
# 					# Round to integer
# 					ADDPD( xmm_temp, xmm_magic_bias )
# 					# Save the integer factor int(round(x * log2e)) + 0x3FF
# 					MOVAPS( factors[index], xmm_temp )
# 					# Subtract the bias. Get round(x * log2e)
# 					SUBPD( xmm_temp, xmm_magic_bias )
# 					# Make a copy of the round(x * log2e) values
# 					MOVAPS( xmm_copy, xmm_temp )
# 					# Muliply round(x * log2e) by ln2 (high part)
# 					MULPD( xmm_temp, xmm_ln2_hi )
# 					# Compute x - round(x * log2e) * ln2_hi
# 					SUBPD( xmm_x, xmm_temp )
# 					# Multiply round(x * log2e) by ln2 (low part)
# 					MULPD( xmm_copy, xmm_ln2_lo )
# 					# Compute x - round(x * log2e) * ln2_hi - round(x * log2e) * ln2_lo
# 					SUBPD( xmm_x, xmm_copy )
# 					if isinstance(x[index], LocalVariable):
# 						MOVAPS(x[index], xmm_x)
#
# 				xmm_exponent_cut_down = SSERegister()
# 				xmm_exponent_cut_up   = SSERegister()
# 				xmm_one               = SSERegister()
#
# 				LOAD.CONSTANT( xmm_exponent_cut_down, exponentCutDown )
# 				LOAD.CONSTANT( xmm_exponent_cut_up,   exponentCutUp )
# 				LOAD.CONSTANT( xmm_one,               one )
#
# 				for index in range(10):
# 					xmm_factor_extra = SSERegister()
# 					xmm_factor   = SSERegister()
#
# 					MOVDQA( xmm_factor, factors[index] )
# 					PSLLQ( xmm_factor, 52 )
# 					MOVDQA( xmm_factor_extra, xmm_factor )
# 					PMAXUW( xmm_factor, xmm_exponent_cut_down )
# 					PADDW( xmm_factor_extra, xmm_one )
# 					PMINUW( xmm_factor, xmm_exponent_cut_up   )
# 					MOVDQA( factors[index], xmm_factor )
# 					PSUBW( xmm_factor_extra, xmm_factor )
# 					MOVDQA( factors_extra[index], xmm_factor_extra )
#
# 				acc = [SSERegister() for index in range(10)]
#
# 				for index in range(10):
# 					if index % 4 == 0:
# 						LOAD.CONSTANT( acc[index], c11 )
# 					else:
# 						MOVAPS( acc[index], acc[index & -4] )
#
# 				def horner_step(coef, acc):
# 					xmm_c = SSERegister()
# 					LOAD.CONSTANT( xmm_c, coef )
# 					for index in range(10):
# 						if isinstance(x[index], Register):
# 							xmm_x = x[index]
# 						else:
# 							xmm_x = SSERegister()
# 							MOVAPS( xmm_x, x[index] )
#
# 						MULPD( acc[index], xmm_x )
# 						ADDPD( acc[index], xmm_c )
#
# 				horner_step(c10, acc)
# 				horner_step(c9, acc)
# 				horner_step(c8, acc)
# 				horner_step(c7, acc)
# 				horner_step(c6, acc)
# 				horner_step(c5, acc)
# 				horner_step(c4, acc)
# 				horner_step(c3, acc)
# 				horner_step(c2, acc)
#
# 				for index in range(10):
# 					if isinstance(x[index], Register):
# 						xmm_x = x[index]
# 					else:
# 						xmm_x = SSERegister()
# 						MOVAPS( xmm_x, x[index] )
# 					MULPD( acc[index], xmm_x )
# 					MULPD( acc[index], xmm_x )
# 					ADDPD( acc[index], xmm_x )
#
# 				for index in range(10):
# 					xmm_factor_extra = SSERegister()
# 					MOVAPS( xmm_factor_extra, factors_extra[index] )
# 					MULPD( acc[index], xmm_factor_extra )
# 					ADDPD( acc[index], xmm_factor_extra )
#
# 				xmm_zero_cutoff = SSERegister()
# 				xmm_inf_cutoff  = SSERegister()
# 				xmm_inf         = SSERegister()
# 				LOAD.CONSTANT( xmm_zero_cutoff, zeroCutoff )
# 				LOAD.CONSTANT( xmm_inf_cutoff, infCutoff )
# 				LOAD.CONSTANT( xmm_inf, inf )
#
# 				for index in range(10):
# 					xmm_factor = SSERegister()
# 					xmm_zero_mask = SSERegister()
#
# 					MOVAPS( xmm_factor, factors[index] )
# 					MULPD( acc[index], xmm_factor )
# 					MOVAPS( xmm_zero_mask, [xPointer + index * 16] )
# 					CMPNLTPD( xmm_zero_mask, xmm_zero_cutoff )
# 					ANDPD( acc[index], xmm_zero_mask )
#
# 					MOVAPS( xmm0, xmm_inf_cutoff )
# 					CMPLTPD( xmm0, [xPointer + index * 16] )
# 					BLENDVPD( acc[index], xmm_inf, xmm0 )
# 					MOVUPS( [yPointer + index * 16], acc[index] )
#
# 				ADD( xPointer, 160 )
# 				ADD( yPointer, 160 )
# 				SUB( length, 20 )
# 				JAE( 'process_by_20' )
# 				JMP( 'process_by_20_epilogue' )
#
# 				return codegen.end_function()

def Exp_V64f_V64f_Bulldozer(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-sysv', 'x64-ms']:
		if module == 'Math':
			if function == 'Exp':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'Bulldozer')

				magicBias = Constant.float64x2('0x1.8000000000000p+52')
				log2e = Constant.float64x2('0x1.71547652B82FEp+0')
				minus_ln2_hi = Constant.float64x2('-0x1.62E42FEFA39EFp-1')
				minus_ln2_lo = Constant.float64x2('-0x1.ABC9E3B39803Fp-56')

				c2 = Constant.float64x2('0x1.0000000000005p-1')
				c3 = Constant.float64x2('0x1.5555555555540p-3')
				c4 = Constant.float64x2('0x1.5555555552115p-5')
				c5 = Constant.float64x2('0x1.11111111173CAp-7')
				c6 = Constant.float64x2('0x1.6C16C17F2BF99p-10')
				c7 = Constant.float64x2('0x1.A01A017EEB164p-13')

				c8 = Constant.float64x2('0x1.A019A6AC02A7Dp-16')
				c9 = Constant.float64x2('0x1.71DE71651CE7Ap-19')
				c10 = Constant.float64x2('0x1.28A284098D813p-22')
				c11 = Constant.float64x2('0x1.AE9043CA87A40p-26')

				minExponent = Constant.uint64x2(-1022L << 52)
				maxExponent = Constant.uint64x2(1023L << 52)
				defaultExponent = Constant.uint64x2(0x3FF0000000000000L)

				zeroCutoff = Constant.float64x2('-0x1.74910D52D3051p+9')
				infCutoff = Constant.float64x2('0x1.62E42FEFA39EFp+9')
				inf = Constant.uint64x2(0x7FF0000000000000L)

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				def SCALAR_EXP(xPointer, yPointer):
					xmm_x = SSERegister()
					xmm_t = SSERegister()
					xmm_rx = SSERegister()
					xmm_rf = SSERegister()

					xmm_e1 = SSERegister()
					xmm_e2 = SSERegister()
					xmm_s1 = SSERegister()
					xmm_s2 = SSERegister()

					xmm_magic_bias = SSERegister()
					xmm_default_exponent = SSERegister()
					LOAD.CONSTANT( xmm_magic_bias,       magicBias )
					LOAD.CONSTANT( xmm_default_exponent, defaultExponent )

					# x = *xPointer
					VMOVSD( xmm_x, [xPointer] )
					# t = x * log2e + magic_bias
					VFMADDPD( xmm_t, xmm_x, log2e, xmm_magic_bias )
					# e2 = as_uint(t) << 52
					VPSLLQ( xmm_e2, xmm_t, 52 )
					# t = t - magic_bias
					VSUBPD( xmm_t, xmm_t, xmm_magic_bias )
					# rx = fma(x, t, -ln2.high)
					VFMADDPD( xmm_rx, xmm_t, minus_ln2_hi, xmm_x )
					# rx = fma(rx, t, -ln2.low)
					VFMADDPD( xmm_rx, xmm_t, minus_ln2_lo, xmm_rx )

					# e1 = min(e2, max_exponent)
					VPMINSD( xmm_e1, xmm_e2, maxExponent )
					# e1 = max(e1, min_exponent)
					VPMAXSD( xmm_e1, xmm_e1, minExponent )
					# e2 -= e1
					VPSUBD( xmm_e2, xmm_e2, xmm_e1 )
					# s1 = as_double(e1 + defaultExponent)
					VPADDD( xmm_s1, xmm_e1, xmm_default_exponent)
					# s2 = as_double(e2 + defaultExponent)
					VPADDD( xmm_s2, xmm_e2, xmm_default_exponent)

					LOAD.CONSTANT( xmm_rf, c11 )

					def horner_step(coef, acc):
						VFMADDPD( xmm_rf, xmm_rf, xmm_rx, coef )

					horner_step(c10, xmm_rf)
					horner_step(c9, xmm_rf)
					horner_step(c8, xmm_rf)
					horner_step(c7, xmm_rf)
					horner_step(c6, xmm_rf)
					horner_step(c5, xmm_rf)
					horner_step(c4, xmm_rf)
					horner_step(c3, xmm_rf)
					horner_step(c2, xmm_rf)

					VMULPD( xmm_rf, xmm_rf, xmm_rx )
					VFMADDPD( xmm_rf, xmm_rf, xmm_rx, xmm_rx )
					VFMADDPD( xmm_rf, xmm_rf, xmm_s1, xmm_s1 )
					VMULPD( xmm_rf, xmm_rf, xmm_s2 )

					xmm_zero_mask = SSERegister()
					# Fixup underflow to zero:
					# - If x < zeroCutoff then zeroMask is true
					# - If x is NaN then zeroMask is false
					VCMPLTPD( xmm_zero_mask, xmm_x, zeroCutoff )
					# - If (zeroMask) rf = 0.0
					VANDNPD( xmm_rf, xmm_zero_mask, xmm_rf )

					xmm_inf_mask = SSERegister()
					# Fixup overflow:
					# - If x > infCutoff then infMask is true
					# - If x is NaN then infMask is false
					VCMPGTPD( xmm_inf_mask, xmm_x, infCutoff )
					# If (infMask) rf = inf
					VBLENDVPD( xmm_rf, xmm_rf, inf, xmm_inf_mask )
					VMOVSD( [yPointer], xmm_rf )

				def VECTOR_EXP(xPointer, yPointer):
					magicBias = Constant.float64x4('0x1.8000000000000p+52')
					log2e = Constant.float64x4('0x1.71547652B82FEp+0')
					minus_ln2_hi = Constant.float64x4('-0x1.62E42FEFA39EFp-1')
					minus_ln2_lo = Constant.float64x4('-0x1.ABC9E3B39803Fp-56')

					c2 = Constant.float64x4('0x1.0000000000005p-1')
					c3 = Constant.float64x4('0x1.5555555555540p-3')
					c4 = Constant.float64x4('0x1.5555555552115p-5')
					c5 = Constant.float64x4('0x1.11111111173CAp-7')
					c6 = Constant.float64x4('0x1.6C16C17F2BF99p-10')
					c7 = Constant.float64x4('0x1.A01A017EEB164p-13')

					c8 = Constant.float64x4('0x1.A019A6AC02A7Dp-16')
					c9 = Constant.float64x4('0x1.71DE71651CE7Ap-19')
					c10 = Constant.float64x4('0x1.28A284098D813p-22')
					c11 = Constant.float64x4('0x1.AE9043CA87A40p-26')

					minExponent = Constant.uint64x2(-1022L << 52)
					maxExponent = Constant.uint64x2(1023L << 52)
					defaultExponent = Constant.uint64x2(0x3FF0000000000000L)

					zeroCutoff = Constant.float64x4('-0x1.74910D52D3051p+9')
					infCutoff = Constant.float64x4('0x1.62E42FEFA39EFp+9')
					inf = Constant.uint64x4(0x7FF0000000000000L)

					ymm_magic_bias = AVXRegister()
					xmm_max_exponent = SSERegister()
					xmm_min_exponent = SSERegister()
					xmm_default_exponent = SSERegister()
					ymm_minus_ln2_hi = AVXRegister()
					ymm_minus_ln2_lo = AVXRegister()
					ymm_log2e = AVXRegister()
					LOAD.CONSTANT( ymm_log2e, log2e )
					LOAD.CONSTANT( ymm_minus_ln2_hi, minus_ln2_hi )
					LOAD.CONSTANT( ymm_minus_ln2_lo, minus_ln2_lo )
					LOAD.CONSTANT( ymm_magic_bias, magicBias )
					LOAD.CONSTANT( xmm_max_exponent, maxExponent )
					LOAD.CONSTANT( xmm_min_exponent, minExponent )
					LOAD.CONSTANT( xmm_default_exponent, defaultExponent )

					ymm_rx = [AVXRegister() for i in range(5)]

					e1 = [LocalVariable(AVXRegister) for i in range(5)]
					e2 = [LocalVariable(AVXRegister) for i in range(5)]

					for i in range(5):
						ymm_x = AVXRegister()
						ymm_t = AVXRegister()
						xmm_e1_lo = SSERegister()
						xmm_e1_hi = SSERegister()
						xmm_e2_lo = SSERegister()
						xmm_e2_hi = SSERegister()

						# x = *xPointer
						VMOVAPD( ymm_x, [xPointer + i * 32] )
						# t = x * log2e + magic_bias
						VFMADDPD( ymm_t, ymm_x, ymm_log2e, ymm_magic_bias )
						# e2 = as_uint(t) << 52
						VPSLLQ( xmm_e2_lo, ymm_t.get_oword(), 52 )
						VEXTRACTF128( xmm_e2_hi, ymm_t, 1 )
						VPSLLQ( xmm_e2_hi, xmm_e2_hi, 52 )
						# t = t - magic_bias
						VSUBPD( ymm_t, ymm_t, ymm_magic_bias )
						# rx = t * (-ln2.high) + x
						VFMADDPD( ymm_rx[i], ymm_t, ymm_minus_ln2_hi, ymm_x )
						# rx = t * (-ln2.low) + rx
						VFMADDPD( ymm_rx[i], ymm_t, ymm_minus_ln2_lo, ymm_rx[i] )

						# e1 = min(e2, max_exponent)
						VPMINSD( xmm_e1_lo, xmm_e2_lo, xmm_max_exponent )
						VPMINSD( xmm_e1_hi, xmm_e2_hi, xmm_max_exponent )
						# e1 = max(e1, min_exponent)
						VPMAXSD( xmm_e1_lo, xmm_e1_lo, xmm_min_exponent )
						VPMAXSD( xmm_e1_hi, xmm_e1_hi, xmm_min_exponent )
						# e2 -= e1
						VPSUBD( xmm_e2_lo, xmm_e2_lo, xmm_e1_lo )
						VPSUBD( xmm_e2_hi, xmm_e2_hi, xmm_e1_hi )
						# s1 = as_double(e1 + defaultExponent)
						VPADDD( xmm_e1_lo, xmm_e1_lo, xmm_default_exponent)
						VPADDD( xmm_e1_hi, xmm_e1_hi, xmm_default_exponent )
						VMOVDQA( e1[i].get_low(), xmm_e1_lo )
						VMOVDQA( e1[i].get_high(), xmm_e1_hi )
						# s2 = as_double(e2 + defaultExponent)
						VPADDD( xmm_e2_lo, xmm_e2_lo, xmm_default_exponent)
						VPADDD( xmm_e2_hi, xmm_e2_hi, xmm_default_exponent )
						VMOVDQA( e2[i].get_low(), xmm_e2_lo )
						VMOVDQA( e2[i].get_high(), xmm_e2_hi )

					ymm_rf = [AVXRegister() for i in range(5)]

					ymm_c11 = AVXRegister()
					ymm_c10 = AVXRegister()
					LOAD.CONSTANT( ymm_c11, c11 )
					LOAD.CONSTANT( ymm_c10, c10 )
					for i in range(5):
						VFMADDPD( ymm_rf[i], ymm_c11, ymm_rx[i], ymm_c10 )

					def horner_step(coef):
						ymm_c = AVXRegister()
						LOAD.CONSTANT( ymm_c, coef )
						for i in range(5):
							VFMADDPD( ymm_rf[i], ymm_rf[i], ymm_rx[i], ymm_c )

					horner_step(c9)
					horner_step(c8)
					horner_step(c7)
					horner_step(c6)
					horner_step(c5)
					horner_step(c4)
					horner_step(c3)
					horner_step(c2)

					for i in range(5):
						# rf = rf * rx
						VMULPD( ymm_rf[i], ymm_rf[i], ymm_rx[i] )
						# rf = rf * rx + rx
						VFMADDPD( ymm_rf[i], ymm_rf[i], ymm_rx[i], ymm_rx[i] )

					for i in range(5):
						ymm_e1 = AVXRegister()
						VMOVAPD( ymm_e1, e1[i] )
						# rf = rf * s1 + s1
						VFMADDPD( ymm_rf[i], ymm_rf[i], ymm_e1, ymm_e1 )

					for i in range(5):
						# rf = rf * s2
						VMULPD( ymm_rf[i], ymm_rf[i], e2[i] )

					ymm_inf = AVXRegister()
					ymm_inf_cutoff = AVXRegister()
					ymm_zero_cutoff = AVXRegister()
					VMOVAPD( ymm_inf, inf )
					LOAD.CONSTANT( ymm_inf_cutoff, infCutoff )
					LOAD.CONSTANT( ymm_zero_cutoff, zeroCutoff )
					for i in range(5):
						ymm_zero_mask = AVXRegister()
						ymm_inf_mask = AVXRegister()
						ymm_x = AVXRegister()

						VMOVAPD( ymm_x, [xPointer + i * 32] )
						# Fixup underflow to zero:
						# - If x < zeroCutoff then zeroMask is true
						# - If x is NaN then zeroMask is false
						VCMPLTPD( ymm_zero_mask, ymm_x, ymm_zero_cutoff )
						# - If (zeroMask) rf = 0.0
						VANDNPD( ymm_rf[i], ymm_zero_mask, ymm_rf[i] )
						# Fixup overflow:
						# - If x > infCutoff then infMask is true
						# - If x is NaN then infMask is false
						VCMPGTPD( ymm_inf_mask, ymm_x, ymm_inf_cutoff )
						# If (infMask) rf = inf
						VBLENDVPD( ymm_rf[i], ymm_rf[i], ymm_inf, ymm_inf_mask )
						# *yPointer = rf
						VMOVUPD( [yPointer + i * 32], ymm_rf[i].get_oword() )
						VEXTRACTF128( [yPointer + i * 32 + 16], ymm_rf[i], 1 )

				Map_V64f_V64f(SCALAR_EXP, VECTOR_EXP, xPointer, yPointer, length, 32, 20)

				return codegen.end_function()

def Exp_V64f_V64f_Nehalem(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-sysv', 'x64-ms']:
		if module == 'Math':
			if function == 'Exp':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'Nehalem')

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				def SCALAR_EXP(xPointer, yPointer):
					magicBias = Constant.float64x2('0x1.8000000000000p+52')
					log2e = Constant.float64x2('0x1.71547652B82FEp+0')
					minus_ln2_hi = Constant.float64x2('-0x1.62E42FEFA3800p-1')
					minus_ln2_lo = Constant.float64x2('-0x1.EF35793C76730p-45')

					c2 = Constant.float64x2('0x1.0000000000005p-1')
					c3 = Constant.float64x2('0x1.5555555555540p-3')
					c4 = Constant.float64x2('0x1.5555555552115p-5')
					c5 = Constant.float64x2('0x1.11111111173CAp-7')
					c6 = Constant.float64x2('0x1.6C16C17F2BF99p-10')
					c7 = Constant.float64x2('0x1.A01A017EEB164p-13')
					c8 = Constant.float64x2('0x1.A019A6AC02A7Dp-16')
					c9 = Constant.float64x2('0x1.71DE71651CE7Ap-19')
					c10 = Constant.float64x2('0x1.28A284098D813p-22')
					c11 = Constant.float64x2('0x1.AE9043CA87A40p-26')

					minExponent = Constant.uint64x2(-1022L << 52)
					maxExponent = Constant.uint64x2(1023L << 52)
					defaultExponent = Constant.uint64x2(0x3FF0000000000000L)

					zeroCutoff = Constant.float64x2('-0x1.74910D52D3051p+9')
					infCutoff = Constant.float64x2('0x1.62E42FEFA39EFp+9')
					inf = Constant.uint64x2(0x7FF0000000000000L)

					xmm_x = SSERegister()
					xmm_t = SSERegister()
					xmm_rx = SSERegister()
					xmm_rf = SSERegister()

					xmm_e1 = SSERegister()
					xmm_e2 = SSERegister()

					xmm_magic_bias = SSERegister()
					xmm_default_exponent = SSERegister()
					LOAD.CONSTANT( xmm_magic_bias,       magicBias )
					LOAD.CONSTANT( xmm_default_exponent, defaultExponent )

					# x = *xPointer
					MOVSD( xmm_x, [xPointer] )
					# t = x * log2e + magic_bias
					MOVAPD( xmm_t, xmm_x )
					MULPD( xmm_t, log2e )
					ADDPD( xmm_t, xmm_magic_bias )
					# e2 = as_uint(t) << 52
					MOVDQA( xmm_e2, xmm_t )
					PSLLQ( xmm_e2, 52 )
					# t = t - magic_bias
					SUBPD( xmm_t, xmm_magic_bias )
					# rx = t * (-ln2.high) + x
					MOVAPD( xmm_rx, xmm_t )
					MULPD( xmm_rx, minus_ln2_hi )
					ADDPD( xmm_rx, xmm_x )
					# rx = t * (-ln2.low) + rx
					MULPD( xmm_t, minus_ln2_lo )
					ADDPD( xmm_rx, xmm_t )

					# e1 = min(e2, max_exponent)
					MOVDQA( xmm_e1, xmm_e2 )
					xmm_max_exponent = SSERegister()
					LOAD.CONSTANT( xmm_max_exponent, maxExponent )
					PMINSD( xmm_e1, xmm_max_exponent )
					# e1 = max(e1, min_exponent)
					xmm_min_exponent = SSERegister()
					LOAD.CONSTANT( xmm_min_exponent, minExponent )
					PMAXSD( xmm_e1, xmm_min_exponent )
					# e2 -= e1
					PSUBD( xmm_e2, xmm_e1 )
					# s1 = as_double(e1 + defaultExponent)
					PADDD( xmm_e1, xmm_default_exponent)
					# s2 = as_double(e2 + defaultExponent)
					PADDD( xmm_e2, xmm_default_exponent)

					LOAD.CONSTANT( xmm_rf, c11 )

					def horner_step(coef):
						MULPD( xmm_rf, xmm_rx )
						ADDPD( xmm_rf, coef )

					horner_step(c10)
					horner_step(c9)
					horner_step(c8)
					horner_step(c7)
					horner_step(c6)
					horner_step(c5)
					horner_step(c4)
					horner_step(c3)
					horner_step(c2)

					# rf = rf * rx
					MULPD( xmm_rf, xmm_rx )
					# rf = rf * rx + rx
					MULPD( xmm_rf, xmm_rx )
					ADDPD( xmm_rf, xmm_rx )
					# rf = rf * s1 + s1
					MULPD( xmm_rf, xmm_e1 )
					ADDPD( xmm_rf, xmm_e1 )
					# rf = rf * s2
					MULPD( xmm_rf, xmm_e2 )

					xmm_inf_mask = xmm0
					LOAD.CONSTANT( xmm_inf_mask, infCutoff )
					# Fixup overflow:
					# - If x > infCutoff then infMask is true
					# - If x is NaN then infMask is false
					CMPLEPD( xmm_inf_mask, xmm_x )
					# If (infMask) rf = inf
					xmm_inf = SSERegister()
					LOAD.CONSTANT( xmm_inf, inf )
					BLENDVPD( xmm_rf, xmm_inf, xmm_inf_mask )

					# Fixup underflow to zero:
					# - If x < zeroCutoff then zeroMask is true
					# - If x is NaN then zeroMask is false
					CMPLTPD( xmm_x, zeroCutoff )
					xmm_zero_mask = xmm_x
					# xmm_x = None
					# - If (zeroMask) rf = 0.0
					ANDNPD( xmm_zero_mask, xmm_rf )
					xmm_rf = xmm_zero_mask
					xmm_zero_mask = None

					MOVSD( [yPointer], xmm_rf )

				def VECTOR_EXP(xPointer, yPointer):
					magicBias = Constant.float64x2('0x1.8000000000000p+52')
					log2e = Constant.float64x2('0x1.71547652B82FEp+0')
					minus_ln2_hi = Constant.float64x2('-0x1.62E42FEFA3800p-1')
					minus_ln2_lo = Constant.float64x2('-0x1.EF35793C76730p-45')

					c2 = Constant.float64x2('0x1.0000000000005p-1')
					c3 = Constant.float64x2('0x1.5555555555540p-3')
					c4 = Constant.float64x2('0x1.5555555552115p-5')
					c5 = Constant.float64x2('0x1.11111111173CAp-7')
					c6 = Constant.float64x2('0x1.6C16C17F2BF99p-10')
					c7 = Constant.float64x2('0x1.A01A017EEB164p-13')

					c8 = Constant.float64x2('0x1.A019A6AC02A7Dp-16')
					c9 = Constant.float64x2('0x1.71DE71651CE7Ap-19')
					c10 = Constant.float64x2('0x1.28A284098D813p-22')
					c11 = Constant.float64x2('0x1.AE9043CA87A40p-26')

					minExponent = Constant.uint64x2(-1022L << 52)
					maxExponent = Constant.uint64x2(1023L << 52)
					defaultExponent = Constant.uint64x2(0x3FF0000000000000L)

					zeroCutoff = Constant.float64x2('-0x1.74910D52D3051p+9')
					infCutoff = Constant.float64x2('0x1.62E42FEFA39EFp+9')
					inf = Constant.uint64x2(0x7FF0000000000000L)

					xmm_magic_bias = SSERegister()
					xmm_max_exponent = SSERegister()
					xmm_min_exponent = SSERegister()
					xmm_default_exponent = SSERegister()
					xmm_minus_ln2_hi = SSERegister()
					# ymm_minus_ln2_lo = AVXRegister()
					xmm_log2e = SSERegister()
					LOAD.CONSTANT( xmm_log2e, log2e )
					LOAD.CONSTANT( xmm_magic_bias, magicBias )
					LOAD.CONSTANT( xmm_max_exponent, maxExponent )
					LOAD.CONSTANT( xmm_min_exponent, minExponent )
					LOAD.CONSTANT( xmm_default_exponent, defaultExponent )

					rx = [SSERegister() for i in range(6)] + [LocalVariable(SSERegister) for i in range(2)]

					e1 = [LocalVariable(SSERegister) for i in range(8)]
					e2 = [LocalVariable(SSERegister) for i in range(8)]

					for i in range(8):
						xmm_x = SSERegister()
						xmm_t = SSERegister()
						if isinstance(rx[i], SSERegister):
							xmm_rx = rx[i]
						else:
							xmm_rx = SSERegister()
						xmm_e1 = SSERegister()
						xmm_e2 = SSERegister()

						# x = *xPointer
						MOVAPD( xmm_x, [xPointer + i * 16] )
						# t = x * log2e + magic_bias
						MOVAPD( xmm_t, xmm_x )
						MULPD( xmm_t, xmm_log2e )
						ADDPD( xmm_t, xmm_magic_bias )
						# e2 = as_uint(t) << 52
						MOVDQA( xmm_e2, xmm_t )
						PSLLQ( xmm_e2, 52 )
						# t = t - magic_bias
						SUBPD( xmm_t, xmm_magic_bias )
						# rx = t * (-ln2.high) + x
						xmm_temp = SSERegister()
						MOVAPD( xmm_rx, xmm_t )
						MULPD( xmm_rx, minus_ln2_hi )
						ADDPD( xmm_rx, xmm_x )
						# rx = t * (-ln2.low) + rx
						MULPD( xmm_t, minus_ln2_lo )
						ADDPD( xmm_rx, xmm_t )
						if isinstance( rx[i], LocalVariable ):
							MOVAPD( rx[i], xmm_rx )

						# e1 = min(e2, max_exponent)
						MOVAPD( xmm_e1, xmm_e2 )
						PMINSD( xmm_e1, xmm_max_exponent )
						# e1 = max(e1, min_exponent)
						PMAXSD( xmm_e1, xmm_min_exponent )
						# e2 -= e1
						PSUBD( xmm_e2, xmm_e1 )
						# s1 = as_double(e1 + defaultExponent)
						PADDD( xmm_e1, xmm_default_exponent)
						MOVDQA( e1[i], xmm_e1 )
						# s2 = as_double(e2 + defaultExponent)
						PADDD( xmm_e2, xmm_default_exponent)
						MOVDQA( e2[i], xmm_e2 )

					xmm_rf = [SSERegister() for i in range(8)]

					for i in range(8):
						if i % 4 == 0:
							LOAD.CONSTANT( xmm_rf[i], c11 )
						else:
							MOVAPD( xmm_rf[i], xmm_rf[(i/4)*4] )

					def horner_step(coef):
						xmm_c = SSERegister()
						LOAD.CONSTANT( xmm_c, coef )
						for i in range(8):
							MULPD( xmm_rf[i], rx[i] )
							ADDPD( xmm_rf[i], xmm_c )

					horner_step(c10)
					horner_step(c9)
					horner_step(c8)
					horner_step(c7)
					horner_step(c6)
					horner_step(c5)
					horner_step(c4)
					horner_step(c3)
					horner_step(c2)

					for i in range(8):
						if isinstance(rx[i], SSERegister):
							xmm_rx = rx[i]
						else:
							xmm_rx = SSERegister()
							MOVAPD( xmm_rx, rx[i] )
						# rf = rf * rx
						MULPD( xmm_rf[i], xmm_rx )
						# rf = rf * rx + rx
						MULPD( xmm_rf[i], xmm_rx )
						ADDPD( xmm_rf[i], xmm_rx )

					for i in range(8):
						xmm_e1 = SSERegister()
						MOVAPD( xmm_e1, e1[i] )
						# rf = rf * s1 + s1
						MULPD( xmm_rf[i], xmm_e1 )
						ADDPD( xmm_rf[i], xmm_e1 )

					for i in range(8):
						# rf = rf * s2
						MULPD( xmm_rf[i], e2[i] )

					xmm_inf = SSERegister()
					xmm_inf_cutoff = SSERegister()
					xmm_zero_cutoff = SSERegister()
					MOVAPD( xmm_inf, inf )
					LOAD.CONSTANT( xmm_inf_cutoff, infCutoff )
					LOAD.CONSTANT( xmm_zero_cutoff, zeroCutoff )
					for i in range(8):
						xmm_x = SSERegister()
						MOVAPD( xmm_x, [xPointer + i * 16] )

						xmm_inf_mask = xmm0
						LOAD.CONSTANT( xmm_inf_mask, infCutoff )
						# Fixup overflow:
						# - If x > infCutoff then infMask is true
						# - If x is NaN then infMask is false
						CMPLEPD( xmm_inf_mask, xmm_x )
						# If (infMask) rf = inf
						BLENDVPD( xmm_rf[i], xmm_inf, xmm_inf_mask )

						# Fixup underflow to zero:
						# - If x < zeroCutoff then zeroMask is true
						# - If x is NaN then zeroMask is false
						CMPLTPD( xmm_x, xmm_zero_cutoff )
						xmm_zero_mask = xmm_x
						# xmm_x = None
						# - If (zeroMask) rf = 0.0
						ANDNPD( xmm_zero_mask, xmm_rf[i] )
						xmm_rf[i] = xmm_zero_mask

						MOVUPD( [yPointer + i * 16], xmm_rf[i] )

				Map_V64f_V64f(SCALAR_EXP, VECTOR_EXP, xPointer, yPointer, length, 16, 16)

				return codegen.end_function()

def Exp_V64f_V64f_SandyBridge(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-sysv', 'x64-ms']:
		if module == 'Math':
			if function == 'Exp':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'SandyBridge')

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				def SCALAR_EXP(xPointer, yPointer):
					magicBias = Constant.float64x2('0x1.8000000000000p+52')
					log2e = Constant.float64x2('0x1.71547652B82FEp+0')
					minus_ln2_hi = Constant.float64x2('-0x1.62E42FEFA3800p-1')
					minus_ln2_lo = Constant.float64x2('-0x1.EF35793C76730p-45')

					c2 = Constant.float64x2('0x1.0000000000005p-1')
					c3 = Constant.float64x2('0x1.5555555555540p-3')
					c4 = Constant.float64x2('0x1.5555555552115p-5')
					c5 = Constant.float64x2('0x1.11111111173CAp-7')
					c6 = Constant.float64x2('0x1.6C16C17F2BF99p-10')
					c7 = Constant.float64x2('0x1.A01A017EEB164p-13')
					c8 = Constant.float64x2('0x1.A019A6AC02A7Dp-16')
					c9 = Constant.float64x2('0x1.71DE71651CE7Ap-19')
					c10 = Constant.float64x2('0x1.28A284098D813p-22')
					c11 = Constant.float64x2('0x1.AE9043CA87A40p-26')

					minExponent = Constant.uint64x2(-1022L << 52)
					maxExponent = Constant.uint64x2(1023L << 52)
					defaultExponent = Constant.uint64x2(0x3FF0000000000000L)

					zeroCutoff = Constant.float64x2('-0x1.74910D52D3051p+9')
					infCutoff = Constant.float64x2('0x1.62E42FEFA39EFp+9')
					inf = Constant.uint64x2(0x7FF0000000000000L)

					xmm_x = SSERegister()
					xmm_t = SSERegister()
					xmm_rx = SSERegister()
					xmm_rf = SSERegister()

					xmm_e1 = SSERegister()
					xmm_e2 = SSERegister()
					xmm_s1 = SSERegister()
					xmm_s2 = SSERegister()

					xmm_magic_bias = SSERegister()
					xmm_default_exponent = SSERegister()
					LOAD.CONSTANT( xmm_magic_bias,       magicBias )
					LOAD.CONSTANT( xmm_default_exponent, defaultExponent )

					# x = *xPointer
					VMOVSD( xmm_x, [xPointer] )
					# t = x * log2e + magic_bias
					VMULPD( xmm_t, xmm_x, log2e )
					VADDPD( xmm_t, xmm_t, xmm_magic_bias )
					# e2 = as_uint(t) << 52
					VPSLLQ( xmm_e2, xmm_t, 52 )
					# t = t - magic_bias
					VSUBPD( xmm_t, xmm_t, xmm_magic_bias )
					# rx = t * (-ln2.high) + x
					xmm_temp = SSERegister()
					VMULPD( xmm_temp, xmm_t, minus_ln2_hi )
					VADDPD( xmm_rx, xmm_temp, xmm_x )
					# rx = t * (-ln2.low) + rx
					xmm_temp = SSERegister()
					VMULPD( xmm_temp, xmm_t, minus_ln2_lo )
					VADDPD( xmm_rx, xmm_rx, xmm_x )

					# e1 = min(e2, max_exponent)
					VPMINSD( xmm_e1, xmm_e2, maxExponent )
					# e1 = max(e1, min_exponent)
					VPMAXSD( xmm_e1, xmm_e1, minExponent )
					# e2 -= e1
					VPSUBD( xmm_e2, xmm_e2, xmm_e1 )
					# s1 = as_double(e1 + defaultExponent)
					VPADDD( xmm_s1, xmm_e1, xmm_default_exponent)
					# s2 = as_double(e2 + defaultExponent)
					VPADDD( xmm_s2, xmm_e2, xmm_default_exponent)

					LOAD.CONSTANT( xmm_rf, c11 )

					def horner_step(coef, acc):
						VMULPD( xmm_rf, xmm_rf, xmm_rx )
						VADDPD( xmm_rf, xmm_rf, coef )

					horner_step(c10, xmm_rf)
					horner_step(c9, xmm_rf)
					horner_step(c8, xmm_rf)
					horner_step(c7, xmm_rf)
					horner_step(c6, xmm_rf)
					horner_step(c5, xmm_rf)
					horner_step(c4, xmm_rf)
					horner_step(c3, xmm_rf)
					horner_step(c2, xmm_rf)

					# rf = rf * rx
					VMULPD( xmm_rf, xmm_rf, xmm_rx )
					# rf = rf * rx + rx
					VMULPD( xmm_rf, xmm_rf, xmm_rx )
					VADDPD( xmm_rf, xmm_rf, xmm_rx )
					# rf = rf * s1 + s1
					VMULPD( xmm_rf, xmm_rf, xmm_s1 )
					VADDPD( xmm_rf, xmm_rf, xmm_s1 )
					# rf = rf * s2
					VMULPD( xmm_rf, xmm_rf, xmm_s2 )

					xmm_zero_mask = SSERegister()
					# Fixup underflow to zero:
					# - If x < zeroCutoff then zeroMask is true
					# - If x is NaN then zeroMask is false
					VCMPLTPD( xmm_zero_mask, xmm_x, zeroCutoff )
					# - If (zeroMask) rf = 0.0
					VANDNPD( xmm_rf, xmm_zero_mask, xmm_rf )

					xmm_inf_mask = SSERegister()
					# Fixup overflow:
					# - If x > infCutoff then infMask is true
					# - If x is NaN then infMask is false
					VCMPGTPD( xmm_inf_mask, xmm_x, infCutoff )
					# If (infMask) rf = inf
					VBLENDVPD( xmm_rf, xmm_rf, inf, xmm_inf_mask )
					VMOVSD( [yPointer], xmm_rf )


				def VECTOR_EXP(xPointer, yPointer):
					magicBias = Constant.float64x4('0x1.8000000000000p+52')
					log2e = Constant.float64x4('0x1.71547652B82FEp+0')
					minus_ln2_hi = Constant.float64x4('-0x1.62E42FEFA3800p-1')
					minus_ln2_lo = Constant.float64x4('-0x1.EF35793C76730p-45')

					c2 = Constant.float64x4('0x1.0000000000005p-1')
					c3 = Constant.float64x4('0x1.5555555555540p-3')
					c4 = Constant.float64x4('0x1.5555555552115p-5')
					c5 = Constant.float64x4('0x1.11111111173CAp-7')
					c6 = Constant.float64x4('0x1.6C16C17F2BF99p-10')
					c7 = Constant.float64x4('0x1.A01A017EEB164p-13')

					c8 = Constant.float64x4('0x1.A019A6AC02A7Dp-16')
					c9 = Constant.float64x4('0x1.71DE71651CE7Ap-19')
					c10 = Constant.float64x4('0x1.28A284098D813p-22')
					c11 = Constant.float64x4('0x1.AE9043CA87A40p-26')

					minExponent = Constant.uint64x2(-1022L << 52)
					maxExponent = Constant.uint64x2(1023L << 52)
					defaultExponent = Constant.uint64x2(0x3FF0000000000000L)

					zeroCutoff = Constant.float64x4('-0x1.74910D52D3051p+9')
					infCutoff = Constant.float64x4('0x1.62E42FEFA39EFp+9')
					inf = Constant.uint64x4(0x7FF0000000000000L)

					ymm_magic_bias = AVXRegister()
					xmm_max_exponent = SSERegister()
					xmm_min_exponent = SSERegister()
					xmm_default_exponent = SSERegister()
					ymm_minus_ln2_hi = AVXRegister()
					# ymm_minus_ln2_lo = AVXRegister()
					ymm_log2e = AVXRegister()
					LOAD.CONSTANT( ymm_log2e, log2e )
					LOAD.CONSTANT( ymm_magic_bias, magicBias )
					LOAD.CONSTANT( xmm_max_exponent, maxExponent )
					LOAD.CONSTANT( xmm_min_exponent, minExponent )
					LOAD.CONSTANT( xmm_default_exponent, defaultExponent )

					rx = [AVXRegister() for i in range(6)] + [LocalVariable(AVXRegister) for i in range(2)]

					e1 = [LocalVariable(AVXRegister) for i in range(8)]
					e2 = [LocalVariable(AVXRegister) for i in range(8)]

					for i in range(8):
						ymm_x = AVXRegister()
						ymm_t = AVXRegister()
						if isinstance(rx[i], AVXRegister):
							ymm_rx = rx[i]
						else:
							ymm_rx = AVXRegister()
						xmm_e1_lo = SSERegister()
						xmm_e1_hi = SSERegister()
						xmm_e2_lo = SSERegister()
						xmm_e2_hi = SSERegister()

						# x = *xPointer
						VMOVAPD( ymm_x, [xPointer + i * 32] )
						# t = x * log2e + magic_bias
						VMULPD( ymm_t, ymm_x, ymm_log2e )
						VADDPD( ymm_t, ymm_t, ymm_magic_bias )
						# e2 = as_uint(t) << 52
						VPSLLQ( xmm_e2_lo, ymm_t.get_oword(), 52 )
						VEXTRACTF128( xmm_e2_hi, ymm_t, 1 )
						VPSLLQ( xmm_e2_hi, xmm_e2_hi, 52 )
						# t = t - magic_bias
						VSUBPD( ymm_t, ymm_t, ymm_magic_bias )
						# rx = t * (-ln2.high) + x
						ymm_temp = AVXRegister()
						VMULPD( ymm_temp, ymm_t, minus_ln2_hi )
						VADDPD( ymm_rx, ymm_temp, ymm_x )
						# rx = t * (-ln2.low) + rx
						ymm_temp = AVXRegister()
						VMULPD( ymm_temp, ymm_t, minus_ln2_lo )
						VADDPD( ymm_rx, ymm_rx, ymm_temp )
						if isinstance( rx[i], LocalVariable ):
							VMOVAPD( rx[i], ymm_rx )

						# e1 = min(e2, max_exponent)
						VPMINSD( xmm_e1_lo, xmm_e2_lo, xmm_max_exponent )
						VPMINSD( xmm_e1_hi, xmm_e2_hi, xmm_max_exponent )
						# e1 = max(e1, min_exponent)
						VPMAXSD( xmm_e1_lo, xmm_e1_lo, xmm_min_exponent )
						VPMAXSD( xmm_e1_hi, xmm_e1_hi, xmm_min_exponent )
						# e2 -= e1
						VPSUBD( xmm_e2_lo, xmm_e2_lo, xmm_e1_lo )
						VPSUBD( xmm_e2_hi, xmm_e2_hi, xmm_e1_hi )
						# s1 = as_double(e1 + defaultExponent)
						VPADDD( xmm_e1_lo, xmm_e1_lo, xmm_default_exponent)
						VPADDD( xmm_e1_hi, xmm_e1_hi, xmm_default_exponent )
						VMOVDQA( e1[i].get_low(), xmm_e1_lo )
						VMOVDQA( e1[i].get_high(), xmm_e1_hi )
						# s2 = as_double(e2 + defaultExponent)
						VPADDD( xmm_e2_lo, xmm_e2_lo, xmm_default_exponent)
						VPADDD( xmm_e2_hi, xmm_e2_hi, xmm_default_exponent )
						VMOVDQA( e2[i].get_low(), xmm_e2_lo )
						VMOVDQA( e2[i].get_high(), xmm_e2_hi )

					ymm_rf = [AVXRegister() for i in range(8)]

					ymm_c11 = AVXRegister()
					ymm_c10 = AVXRegister()
					LOAD.CONSTANT( ymm_c11, c11 )
					LOAD.CONSTANT( ymm_c10, c10 )
					for i in range(8):
						VMULPD( ymm_rf[i], ymm_c11, rx[i] )
						VADDPD( ymm_rf[i], ymm_rf[i], ymm_c10 )

					def horner_step(coef):
						ymm_c = AVXRegister()
						LOAD.CONSTANT( ymm_c, coef )
						for i in range(8):
							VMULPD( ymm_rf[i], ymm_rf[i], rx[i] )
							VADDPD( ymm_rf[i], ymm_rf[i], ymm_c )

					horner_step(c9)
					horner_step(c8)
					horner_step(c7)
					horner_step(c6)
					horner_step(c5)
					horner_step(c4)
					horner_step(c3)
					horner_step(c2)

					for i in range(8):
						if isinstance(rx[i], AVXRegister):
							ymm_rx = rx[i]
						else:
							ymm_rx = AVXRegister()
							VMOVAPD( ymm_rx, rx[i] )
						# rf = rf * rx
						VMULPD( ymm_rf[i], ymm_rf[i], ymm_rx )
						# rf = rf * rx + rx
						VMULPD( ymm_rf[i], ymm_rf[i], ymm_rx )
						VADDPD( ymm_rf[i], ymm_rf[i], ymm_rx )

					for i in range(8):
						ymm_e1 = AVXRegister()
						VMOVAPD( ymm_e1, e1[i] )
						# rf = rf * s1 + s1
						VMULPD( ymm_rf[i], ymm_rf[i], ymm_e1 )
						VADDPD( ymm_rf[i], ymm_rf[i], ymm_e1 )

					for i in range(8):
						# rf = rf * s2
						VMULPD( ymm_rf[i], ymm_rf[i], e2[i] )

					ymm_inf = AVXRegister()
					ymm_inf_cutoff = AVXRegister()
					ymm_zero_cutoff = AVXRegister()
					VMOVAPD( ymm_inf, inf )
					LOAD.CONSTANT( ymm_inf_cutoff, infCutoff )
					LOAD.CONSTANT( ymm_zero_cutoff, zeroCutoff )
					for i in range(8):
						ymm_zero_mask = AVXRegister()
						ymm_inf_mask = AVXRegister()
						ymm_x = AVXRegister()

						VMOVAPD( ymm_x, [xPointer + i * 32] )
						# Fixup underflow to zero:
						# - If x < zeroCutoff then zeroMask is true
						# - If x is NaN then zeroMask is false
						VCMPLTPD( ymm_zero_mask, ymm_x, ymm_zero_cutoff )
						# - If (zeroMask) rf = 0.0
						VANDNPD( ymm_rf[i], ymm_zero_mask, ymm_rf[i] )
						# Fixup overflow:
						# - If x > infCutoff then infMask is true
						# - If x is NaN then infMask is false
						VCMPGTPD( ymm_inf_mask, ymm_x, ymm_inf_cutoff )
						# If (infMask) rf = inf
						VBLENDVPD( ymm_rf[i], ymm_rf[i], ymm_inf, ymm_inf_mask )
						# *yPointer = rf
						VMOVUPD( [yPointer + i * 32], ymm_rf[i].get_oword() )
						VEXTRACTF128( [yPointer + i * 32 + 16], ymm_rf[i], 1 )

				Map_V64f_V64f(SCALAR_EXP, VECTOR_EXP, xPointer, yPointer, length, 32, 32)

				return codegen.end_function()

def Sin_V64f_V64f_Nehalem(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-sysv', 'x64-ms']:
		if module == 'Math':
			if function == 'Sin':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'Nehalem')

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				minusPio2_hi = Constant.float64x2('-0x1.921FB54440000p+0')
				minusPio2_me = Constant.float64x2('-0x1.68C234C4C8000p-39')
				minusPio2_lo = Constant.float64x2( '0x1.9D747F23E32EDp-79')
				twoOPi = Constant.float64x2('0x1.45F306DC9C883p-1')
				magicBias = Constant.float64x2('0x1.8000000000000p+52')

				c0  = Constant.float64x2( '0x1.0000000000000p+0')
				c2  = Constant.float64x2('-0x1.0000000000000p-1')
				c3  = Constant.float64x2('-0x1.5555555555546p-3')
				c4  = Constant.float64x2( '0x1.555555555554Bp-5')
				c5  = Constant.float64x2( '0x1.111111110F51Ep-7')
				c6  = Constant.float64x2('-0x1.6C16C16C15038p-10')
				c7  = Constant.float64x2('-0x1.A01A019BB92C0p-13')
				c8  = Constant.float64x2( '0x1.A01A019C94874p-16')
				c9  = Constant.float64x2( '0x1.71DE3535C8A8Ap-19')
				c10 = Constant.float64x2('-0x1.27E4F7F65104Fp-22')
				c11 = Constant.float64x2('-0x1.AE5E38936D046p-26')
				c12 = Constant.float64x2( '0x1.1EE9DF6693F7Ep-29')
				c13 = Constant.float64x2( '0x1.5D8711D281543p-33')
				c14 = Constant.float64x2('-0x1.8FA87EF79AE3Fp-37')

				signMask = Constant.float64x2('-0x0.0000000000000p+0')

				def SCALAR_SIN(xPointer, yPointer):
					# x = *xPointer
					xmm_x = SSERegister()
					MOVSD( xmm_x, [xPointer] )
					# t = (x * (2/Pi)) + magicBias
					xmm_t = SSERegister()
					MOVAPS( xmm_t, xmm_x )
					MULPD( xmm_t, twoOPi )
					ADDPD( xmm_t, magicBias )
					# n = (int(t) % 4) << 62
					xmm_n = xmm0
					MOVAPS( xmm_n, xmm_t )
					PSLLQ( xmm_n, 62 )
					# t -= magicBias
					SUBPD( xmm_t, magicBias )
					# x += t * minusPio2_hi
					xmm_temp = SSERegister()
					MOVAPS( xmm_temp, minusPio2_hi )
					MULPD( xmm_temp, xmm_t )
					ADDPD( xmm_x, xmm_temp )
					# x += t * minusPio2_me
					xmm_a = SSERegister()
					MOVAPS( xmm_a, xmm_x )
					xmm_temp = SSERegister()
					MOVAPS( xmm_temp, minusPio2_me )
					MULPD( xmm_temp, xmm_t )
					ADDPD( xmm_x, xmm_temp )
					xmm_z = SSERegister()
					MOVAPS( xmm_z, xmm_x )
					SUBPD( xmm_z, xmm_a )
					SUBPD( xmm_temp, xmm_z )
					# x += t * minusPio2_lo
					MULPD( xmm_t, minusPio2_lo )
					ADDPD( xmm_t, xmm_temp )
					ADDPD( xmm_x, xmm_t )

					# sqrx = x * x
					xmm_sqrx = SSERegister()
					MOVAPS( xmm_sqrx, xmm_x )
					MULPD( xmm_sqrx, xmm_sqrx )

					xmm_sin = SSERegister()
					xmm_cos = SSERegister()
					LOAD.CONSTANT( xmm_cos, c14 )
					LOAD.CONSTANT( xmm_sin, c13 )

					def HORNER_STEP(acc, coef):
						MULPD( acc, xmm_sqrx )
						ADDPD( acc, coef )

					HORNER_STEP(xmm_cos, c12 )
					HORNER_STEP(xmm_sin, c11 )
					HORNER_STEP(xmm_cos, c10 )
					HORNER_STEP(xmm_sin, c9 )
					HORNER_STEP(xmm_cos, c8 )
					HORNER_STEP(xmm_sin, c7 )
					HORNER_STEP(xmm_cos, c6 )
					HORNER_STEP(xmm_sin, c5 )
					HORNER_STEP(xmm_cos, c4 )
					HORNER_STEP(xmm_sin, c3 )
					HORNER_STEP(xmm_cos, c2 )
					MULPD( xmm_sin, xmm_sqrx )
					MULPD( xmm_cos, xmm_sqrx )
					MULPD( xmm_sin, xmm_x )
					ADDPD( xmm_sin, xmm_x )
					ADDPD( xmm_cos, c0 )

					xmm_sign = SSERegister()
					LOAD.CONSTANT( xmm_sign, signMask )
					PAND( xmm_sign, xmm_n )
					PADDQ( xmm_n, xmm_n )
					BLENDVPD( xmm_sin, xmm_cos, xmm_n )
					XORPD( xmm_sin, xmm_sign )
					MOVSD( [yPointer], xmm_sin )

				def VECTOR_SIN(xPointer, yPointer):
					xmm_x = [SSERegister() for i in range(5)]
					xmm_t = [SSERegister() for i in range(5)]
					xmm_r = [SSERegister() for i in range(5)]
					n = [LocalVariable(SSERegister) for i in range(5)]
					x = [LocalVariable(SSERegister) for i in range(5)]
					for i in range(5):
						xmm_n = SSERegister()

						# x = *xPointer
						MOVAPD( xmm_x[i], [xPointer + i * 16] )
						# t = (x * (2/Pi)) + magicBias
						MOVAPS( xmm_t[i], xmm_x[i] )
						MULPD( xmm_t[i], twoOPi )
						ADDPD( xmm_t[i], magicBias )

					for i in range(5):
						# n = (int(t) % 4) << 62
						MOVAPS( xmm_n, xmm_t[i] )
						PSLLQ( xmm_n, 62 )
						MOVDQA( n[i], xmm_n )
						# t -= magicBias
						SUBPD( xmm_t[i], magicBias )

					for i in range(5):
						# x += t * minusPio2_hi
						xmm_temp = SSERegister()
						MOVAPS( xmm_temp, minusPio2_hi )
						MULPD( xmm_temp, xmm_t[i] )
						ADDPD( xmm_x[i], xmm_temp )

					for i in range(5):
						# x += t * minusPio2_me
						xmm_a = SSERegister()
						MOVAPS( xmm_a, xmm_x[i] )
						MOVAPS( xmm_r[i], minusPio2_me )
						MULPD( xmm_r[i], xmm_t[i] )
						ADDPD( xmm_x[i], xmm_r[i] )
						xmm_z = SSERegister()
						MOVAPS( xmm_z, xmm_x[i] )
						SUBPD( xmm_z, xmm_a )
						SUBPD( xmm_r[i], xmm_z )
						# x += t * minusPio2_lo
						MULPD( xmm_t[i], minusPio2_lo )
						ADDPD( xmm_t[i], xmm_r[i] )
						ADDPD( xmm_x[i], xmm_t[i] )


					xmm_sqrx = [SSERegister() for i in range(5)]
					for i in range(5):
						# sqrx = x * x
						MOVAPD( x[i], xmm_x[i] )
						MULPD( xmm_x[i], xmm_x[i] )
						xmm_sqrx[i] = xmm_x[i]

					xmm_sin = [SSERegister() for i in range(5)]
					xmm_cos = [SSERegister() for i in range(5)]
					for i in range(5):
						LOAD.CONSTANT( xmm_cos[i], c14 )
						LOAD.CONSTANT( xmm_sin[i], c13 )

					def HORNER_STEP(acc, coef):
						xmm_c = SSERegister()
						LOAD.CONSTANT( xmm_c, coef )
						for i in range(5):
							MULPD( acc[i], xmm_sqrx[i] )
							ADDPD( acc[i], xmm_c )

					HORNER_STEP(xmm_cos, c12 )
					HORNER_STEP(xmm_sin, c11 )
					HORNER_STEP(xmm_cos, c10 )
					HORNER_STEP(xmm_sin, c9 )
					HORNER_STEP(xmm_cos, c8 )
					HORNER_STEP(xmm_sin, c7 )
					HORNER_STEP(xmm_cos, c6 )
					HORNER_STEP(xmm_sin, c5 )
					HORNER_STEP(xmm_cos, c4 )
					HORNER_STEP(xmm_sin, c3 )
					HORNER_STEP(xmm_cos, c2 )

					for i in range(5):
						MULPD( xmm_sin[i], xmm_sqrx[i] )
						MULPD( xmm_cos[i], xmm_sqrx[i] )
						xmm_x = SSERegister()
						MOVAPD( xmm_x, x[i] )
						MULPD( xmm_sin[i], xmm_x )
						ADDPD( xmm_sin[i], xmm_x )
						ADDPD( xmm_cos[i], c0 )

					for i in range(5):
						xmm_n = xmm0
						MOVAPD( xmm_n, n[i] )
						xmm_sign = SSERegister()
						LOAD.CONSTANT( xmm_sign, signMask )
						PAND( xmm_sign, xmm_n )
						PADDQ( xmm_n, xmm_n )
						BLENDVPD( xmm_sin[i], xmm_cos[i], xmm_n )
						XORPD( xmm_sin[i], xmm_sign )
						MOVUPD( [yPointer + 16 * i], xmm_sin[i] )

				Map_V64f_V64f(SCALAR_SIN, VECTOR_SIN, xPointer, yPointer, length, 32, 10)

				return codegen.end_function()

def Sin_V64f_V64f_SandyBridge(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-sysv', 'x64-ms']:
		if module == 'Math':
			if function == 'Sin':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'SandyBridge')

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				def SCALAR_SIN(xPointer, yPointer):
					minusPio2_hi = Constant.float64x2('-0x1.921FB54440000p+0')
					minusPio2_me = Constant.float64x2('-0x1.68C234C4C8000p-39')
					minusPio2_lo = Constant.float64x2( '0x1.9D747F23E32EDp-79')
					twoOPi = Constant.float64x2('0x1.45F306DC9C883p-1')
					magicBias = Constant.float64x2('0x1.8000000000000p+52')

					c0  = Constant.float64x2( '0x1.0000000000000p+0')
					c2  = Constant.float64x2('-0x1.0000000000000p-1')
					c3  = Constant.float64x2('-0x1.5555555555546p-3')
					c4  = Constant.float64x2( '0x1.555555555554Bp-5')
					c5  = Constant.float64x2( '0x1.111111110F51Ep-7')
					c6  = Constant.float64x2('-0x1.6C16C16C15038p-10')
					c7  = Constant.float64x2('-0x1.A01A019BB92C0p-13')
					c8  = Constant.float64x2( '0x1.A01A019C94874p-16')
					c9  = Constant.float64x2( '0x1.71DE3535C8A8Ap-19')
					c10 = Constant.float64x2('-0x1.27E4F7F65104Fp-22')
					c11 = Constant.float64x2('-0x1.AE5E38936D046p-26')
					c12 = Constant.float64x2( '0x1.1EE9DF6693F7Ep-29')
					c13 = Constant.float64x2( '0x1.5D8711D281543p-33')
					c14 = Constant.float64x2('-0x1.8FA87EF79AE3Fp-37')

					signMask = Constant.float64x2('-0x0.0000000000000p+0')

					# x = *xPointer
					xmm_x = SSERegister()
					VMOVSD( xmm_x, [xPointer] )
					# t = (x * (2/Pi)) + magicBias
					xmm_t = SSERegister()
					VMULPD( xmm_t, xmm_x, twoOPi )
					VADDPD( xmm_t, xmm_t, magicBias )
					# n = (int(t) % 4) << 62
					xmm_n = SSERegister()
					VPSLLQ( xmm_n, xmm_t, 62 )
					# t -= magicBias
					VSUBPD( xmm_t, xmm_t, magicBias )
					# x += t * minusPio2_hi
					xmm_temp = SSERegister()
					VMULPD( xmm_temp, xmm_t, minusPio2_hi )
					VADDPD( xmm_x, xmm_x, xmm_temp )
					# x += t * minusPio2_me
					xmm_a = SSERegister()
					VMOVAPS( xmm_a, xmm_x )
					xmm_temp = SSERegister()
					VMULPD( xmm_temp, xmm_t, minusPio2_me )
					VADDPD( xmm_x, xmm_temp )
					xmm_z = SSERegister()
					VSUBPD( xmm_z, xmm_x, xmm_a )
					VSUBPD( xmm_temp, xmm_temp, xmm_z )
					# x += t * minusPio2_lo
					VMULPD( xmm_t, xmm_t, minusPio2_lo )
					VADDPD( xmm_t, xmm_t, xmm_temp )
					VADDPD( xmm_x, xmm_x, xmm_t )

					# sqrx = x * x
					xmm_sqrx = SSERegister()
					VMULPD( xmm_sqrx, xmm_x, xmm_x )

					xmm_sin = SSERegister()
					xmm_cos = SSERegister()
					LOAD.CONSTANT( xmm_cos, c14 )
					LOAD.CONSTANT( xmm_sin, c13 )

					def HORNER_STEP(acc, coef):
						VMULPD( acc, acc, xmm_sqrx )
						VADDPD( acc, acc, coef )

					HORNER_STEP(xmm_cos, c12 )
					HORNER_STEP(xmm_sin, c11 )
					HORNER_STEP(xmm_cos, c10 )
					HORNER_STEP(xmm_sin, c9 )
					HORNER_STEP(xmm_cos, c8 )
					HORNER_STEP(xmm_sin, c7 )
					HORNER_STEP(xmm_cos, c6 )
					HORNER_STEP(xmm_sin, c5 )
					HORNER_STEP(xmm_cos, c4 )
					HORNER_STEP(xmm_sin, c3 )
					HORNER_STEP(xmm_cos, c2 )
					VMULPD( xmm_sin, xmm_sin, xmm_sqrx )
					VMULPD( xmm_cos, xmm_cos, xmm_sqrx )
					VMULPD( xmm_sin, xmm_sin, xmm_x )
					VADDPD( xmm_sin, xmm_sin, xmm_x )
					VADDPD( xmm_cos, xmm_cos, c0 )

					xmm_sign = SSERegister()
					LOAD.CONSTANT( xmm_sign, signMask )
					VPAND( xmm_sign, xmm_n )
					VPADDQ( xmm_n, xmm_n )
					VBLENDVPD( xmm_sin, xmm_sin, xmm_cos, xmm_n )
					VXORPD( xmm_sin, xmm_sign )
					VMOVSD( [yPointer], xmm_sin )

				def VECTOR_SIN(xPointer, yPointer):
					minusPio2_hi = Constant.float64x4('-0x1.921FB54440000p+0')
					minusPio2_me = Constant.float64x4('-0x1.68C234C4C8000p-39')
					minusPio2_lo = Constant.float64x4( '0x1.9D747F23E32EDp-79')
					twoOPi = Constant.float64x4('0x1.45F306DC9C883p-1')
					magicBias = Constant.float64x4('0x1.8000000000000p+52')

					c0  = Constant.float64x4( '0x1.0000000000000p+0')
					c2  = Constant.float64x4('-0x1.0000000000000p-1')
					c3  = Constant.float64x4('-0x1.5555555555546p-3')
					c4  = Constant.float64x4( '0x1.555555555554Bp-5')
					c5  = Constant.float64x4( '0x1.111111110F51Ep-7')
					c6  = Constant.float64x4('-0x1.6C16C16C15038p-10')
					c7  = Constant.float64x4('-0x1.A01A019BB92C0p-13')
					c8  = Constant.float64x4( '0x1.A01A019C94874p-16')
					c9  = Constant.float64x4( '0x1.71DE3535C8A8Ap-19')
					c10 = Constant.float64x4('-0x1.27E4F7F65104Fp-22')
					c11 = Constant.float64x4('-0x1.AE5E38936D046p-26')
					c12 = Constant.float64x4( '0x1.1EE9DF6693F7Ep-29')
					c13 = Constant.float64x4( '0x1.5D8711D281543p-33')
					c14 = Constant.float64x4('-0x1.8FA87EF79AE3Fp-37')

					signMask = Constant.float64x4('-0x0.0000000000000p+0')

					ymm_x = [AVXRegister() for i in range(5)]
					ymm_t = [AVXRegister() for i in range(5)]
					n = [LocalVariable(AVXRegister) for i in range(5)]
					x = [LocalVariable(AVXRegister) for i in range(5)]

					ymm_two_over_pi = AVXRegister()
					ymm_magic_bias = AVXRegister()
					LOAD.CONSTANT( ymm_two_over_pi, twoOPi )
					LOAD.CONSTANT( ymm_magic_bias, magicBias )
					for i in range(5):
						# x = *xPointer
						VMOVAPD( ymm_x[i], [xPointer + i * 32] )
						# t = (x * (2/Pi)) + magicBias
						VMULPD( ymm_t[i], ymm_x[i], ymm_two_over_pi )
						VADDPD( ymm_t[i], ymm_t[i], ymm_magic_bias )

					for i in range(5):
						xmm_n_lo = SSERegister()
						xmm_n_hi = SSERegister()
						# n = (int(t) % 4) << 62
						VEXTRACTF128( xmm_n_hi, ymm_t[i], 1 )
						VPSLLQ( xmm_n_lo, ymm_t[i].get_oword(), 62 )
						VMOVDQA( n[i].get_low(), xmm_n_lo )
						VPSLLQ( xmm_n_hi, xmm_n_hi, 62 )
						VMOVDQA( n[i].get_high(), xmm_n_hi )
						# t -= magicBias
						VSUBPD( ymm_t[i], ymm_t[i], ymm_magic_bias )

					for i in range(5):
						# x += t * minusPio2_hi
						ymm_temp = AVXRegister()
						VMULPD( ymm_temp, ymm_t[i], minusPio2_hi )
						VADDPD( ymm_x[i], ymm_x[i], ymm_temp )

					for i in range(5):
						ymm_temp = AVXRegister()
						# x += t * minusPio2_me
						ymm_a = ymm_x[i]
						ymm_x[i] = AVXRegister()
						VMULPD( ymm_temp, ymm_t[i], minusPio2_me )
						VADDPD( ymm_x[i], ymm_a, ymm_temp )
						ymm_z = AVXRegister()
						VSUBPD( ymm_z, ymm_x[i], ymm_a )
						VSUBPD( ymm_temp, ymm_temp, ymm_z )
						# x += t * minusPio2_lo
						VMULPD( ymm_t[i], ymm_t[i], minusPio2_lo )
						VADDPD( ymm_t[i], ymm_t[i], ymm_temp )
						VADDPD( ymm_x[i], ymm_x[i], ymm_t[i] )

					ymm_sqrx = [AVXRegister() for i in range(5)]
					for i in range(5):
						# sqrx = x * x
						VMOVAPD( x[i], ymm_x[i] )
						VMULPD( ymm_sqrx[i], ymm_x[i], ymm_x[i] )


					ymm_sin = [AVXRegister() for i in range(5)]
					ymm_cos = [AVXRegister() for i in range(5)]

					ymm_c14 = AVXRegister()
					ymm_c12 = AVXRegister()
					LOAD.CONSTANT( ymm_c14, c14 )
					LOAD.CONSTANT( ymm_c12, c12 )
					for i in range(5):
						VMULPD( ymm_cos[i], ymm_c14, ymm_sqrx[i] )
						VADDPD( ymm_cos[i], ymm_cos[i], ymm_c12 )

					ymm_c13 = AVXRegister()
					ymm_c11 = AVXRegister()
					LOAD.CONSTANT( ymm_c13, c13 )
					LOAD.CONSTANT( ymm_c11, c11 )
					for i in range(5):
						VMULPD( ymm_sin[i], ymm_c13, ymm_sqrx[i] )
						VADDPD( ymm_sin[i], ymm_sin[i], ymm_c11 )

					def HORNER_STEP(acc, coef):
						ymm_c = AVXRegister()
						LOAD.CONSTANT( ymm_c, coef )
						for i in range(5):
							VMULPD( acc[i], acc[i], ymm_sqrx[i] )
							VADDPD( acc[i], acc[i], ymm_c )

					HORNER_STEP(ymm_cos, c10 )
					HORNER_STEP(ymm_sin, c9 )
					HORNER_STEP(ymm_cos, c8 )
					HORNER_STEP(ymm_sin, c7 )
					HORNER_STEP(ymm_cos, c6 )
					HORNER_STEP(ymm_sin, c5 )
					HORNER_STEP(ymm_cos, c4 )
					HORNER_STEP(ymm_sin, c3 )
					HORNER_STEP(ymm_cos, c2 )

					ymm_c0 = AVXRegister()
					LOAD.CONSTANT( ymm_c0, c0 )
					for i in range(5):
						VMULPD( ymm_sin[i], ymm_sqrx[i] )
						VMULPD( ymm_cos[i], ymm_sqrx[i] )
						ymm_x = AVXRegister()
						VMOVAPD( ymm_x, x[i] )
						VMULPD( ymm_sin[i], ymm_x )
						VADDPD( ymm_sin[i], ymm_x )
						VADDPD( ymm_cos[i], ymm_c0 )

					ymm_sign_mask = AVXRegister()
					LOAD.CONSTANT( ymm_sign_mask, signMask )
					for i in range(5):
						ymm_n = AVXRegister()
						VMOVAPD( ymm_n, n[i] )
						ymm_sign = AVXRegister()
						VANDPD( ymm_sign, ymm_n, ymm_sign_mask )
						VANDNPD( ymm_n, ymm_sign_mask, ymm_n )
						# n = !(n & 1)
						VCMPEQPD( ymm_n, ymm_n, ymm_sign )
						VBLENDVPD( ymm_sin[i], ymm_cos[i], ymm_sin[i], ymm_n )
						VXORPD( ymm_sin[i], ymm_sign )
						VMOVUPD( [yPointer + 32 * i], ymm_sin[i].get_oword() )
						VEXTRACTF128( [yPointer + 32 * i + 16], ymm_sin[i], 1 )

				Map_V64f_V64f(SCALAR_SIN, VECTOR_SIN, xPointer, yPointer, length, 32, 20)

				return codegen.end_function()

def Sin_V64f_V64f_Bulldozer(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-sysv', 'x64-ms']:
		if module == 'Math':
			if function == 'Sin':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'Bulldozer')

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				def SCALAR_SIN(xPointer, yPointer):
					minusPio2_hi = Constant.float64x2('-0x1.921FB54440000p+0')
					minusPio2_me = Constant.float64x2('-0x1.68C234C4C8000p-39')
					minusPio2_lo = Constant.float64x2( '0x1.9D747F23E32EDp-79')
					twoOPi = Constant.float64x2('0x1.45F306DC9C883p-1')
					magicBias = Constant.float64x2('0x1.8000000000000p+52')

					c0  = Constant.float64x2( '0x1.0000000000000p+0')
					c2  = Constant.float64x2('-0x1.0000000000000p-1')
					c3  = Constant.float64x2('-0x1.5555555555546p-3')
					c4  = Constant.float64x2( '0x1.555555555554Bp-5')
					c5  = Constant.float64x2( '0x1.111111110F51Ep-7')
					c6  = Constant.float64x2('-0x1.6C16C16C15038p-10')
					c7  = Constant.float64x2('-0x1.A01A019BB92C0p-13')
					c8  = Constant.float64x2( '0x1.A01A019C94874p-16')
					c9  = Constant.float64x2( '0x1.71DE3535C8A8Ap-19')
					c10 = Constant.float64x2('-0x1.27E4F7F65104Fp-22')
					c11 = Constant.float64x2('-0x1.AE5E38936D046p-26')
					c12 = Constant.float64x2( '0x1.1EE9DF6693F7Ep-29')
					c13 = Constant.float64x2( '0x1.5D8711D281543p-33')
					c14 = Constant.float64x2('-0x1.8FA87EF79AE3Fp-37')

					signMask = Constant.float64x2('-0x0.0000000000000p+0')

					# x = *xPointer
					xmm_x = SSERegister()
					VMOVSD( xmm_x, [xPointer] )
					# t = (x * (2/Pi)) + magicBias
					xmm_t = SSERegister()
					VMULPD( xmm_t, xmm_x, twoOPi )
					VADDPD( xmm_t, xmm_t, magicBias )
					# n = (int(t) % 4) << 62
					xmm_n = SSERegister()
					VPSLLQ( xmm_n, xmm_t, 62 )
					# t -= magicBias
					VSUBPD( xmm_t, xmm_t, magicBias )
					# x += t * minusPio2_hi
					xmm_temp = SSERegister()
					VMULPD( xmm_temp, xmm_t, minusPio2_hi )
					VADDPD( xmm_x, xmm_x, xmm_temp )
					# x += t * minusPio2_me
					xmm_a = SSERegister()
					VMOVAPS( xmm_a, xmm_x )
					xmm_temp = SSERegister()
					VMULPD( xmm_temp, xmm_t, minusPio2_me )
					VADDPD( xmm_x, xmm_temp )
					xmm_z = SSERegister()
					VSUBPD( xmm_z, xmm_x, xmm_a )
					VSUBPD( xmm_temp, xmm_temp, xmm_z )
					# x += t * minusPio2_lo
					VMULPD( xmm_t, xmm_t, minusPio2_lo )
					VADDPD( xmm_t, xmm_t, xmm_temp )
					VADDPD( xmm_x, xmm_x, xmm_t )

					# sqrx = x * x
					xmm_sqrx = SSERegister()
					VMULPD( xmm_sqrx, xmm_x, xmm_x )

					xmm_sin = SSERegister()
					xmm_cos = SSERegister()
					LOAD.CONSTANT( xmm_cos, c14 )
					LOAD.CONSTANT( xmm_sin, c13 )

					def HORNER_STEP(acc, coef):
						VFMADDPD( acc, acc, xmm_sqrx, coef )

					HORNER_STEP(xmm_cos, c12 )
					HORNER_STEP(xmm_sin, c11 )
					HORNER_STEP(xmm_cos, c10 )
					HORNER_STEP(xmm_sin, c9 )
					HORNER_STEP(xmm_cos, c8 )
					HORNER_STEP(xmm_sin, c7 )
					HORNER_STEP(xmm_cos, c6 )
					HORNER_STEP(xmm_sin, c5 )
					HORNER_STEP(xmm_cos, c4 )
					HORNER_STEP(xmm_sin, c3 )
					HORNER_STEP(xmm_cos, c2 )
					VMULPD( xmm_sin, xmm_sin, xmm_sqrx )
					VFMADDPD( xmm_cos, xmm_cos, xmm_sqrx, c0 )
					VFMADDPD( xmm_sin, xmm_sin, xmm_x, xmm_x )

					xmm_sign = SSERegister()
					LOAD.CONSTANT( xmm_sign, signMask )
					VPAND( xmm_sign, xmm_n )
					VPADDQ( xmm_n, xmm_n )
					VBLENDVPD( xmm_sin, xmm_sin, xmm_cos, xmm_n )
					VXORPD( xmm_sin, xmm_sign )
					VMOVSD( [yPointer], xmm_sin )

				def VECTOR_SIN(xPointer, yPointer):
					minusPio2_hi = Constant.float64x4('-0x1.921FB54440000p+0')
					minusPio2_me = Constant.float64x4('-0x1.68C234C4C8000p-39')
					minusPio2_lo = Constant.float64x4( '0x1.9D747F23E32EDp-79')
					twoOPi = Constant.float64x4('0x1.45F306DC9C883p-1')
					magicBias = Constant.float64x4('0x1.8000000000000p+52')

					c0  = Constant.float64x4( '0x1.0000000000000p+0')
					c2  = Constant.float64x4('-0x1.0000000000000p-1')
					c3  = Constant.float64x4('-0x1.5555555555546p-3')
					c4  = Constant.float64x4( '0x1.555555555554Bp-5')
					c5  = Constant.float64x4( '0x1.111111110F51Ep-7')
					c6  = Constant.float64x4('-0x1.6C16C16C15038p-10')
					c7  = Constant.float64x4('-0x1.A01A019BB92C0p-13')
					c8  = Constant.float64x4( '0x1.A01A019C94874p-16')
					c9  = Constant.float64x4( '0x1.71DE3535C8A8Ap-19')
					c10 = Constant.float64x4('-0x1.27E4F7F65104Fp-22')
					c11 = Constant.float64x4('-0x1.AE5E38936D046p-26')
					c12 = Constant.float64x4( '0x1.1EE9DF6693F7Ep-29')
					c13 = Constant.float64x4( '0x1.5D8711D281543p-33')
					c14 = Constant.float64x4('-0x1.8FA87EF79AE3Fp-37')

					signMask = Constant.float64x4('-0x0.0000000000000p+0')

					ymm_x = [AVXRegister() for i in range(5)]
					ymm_t = [AVXRegister() for i in range(5)]
					n = [LocalVariable(AVXRegister) for i in range(5)]
					x = [LocalVariable(AVXRegister) for i in range(5)]

					ymm_two_over_pi = AVXRegister()
					ymm_magic_bias = AVXRegister()
					LOAD.CONSTANT( ymm_two_over_pi, twoOPi )
					LOAD.CONSTANT( ymm_magic_bias, magicBias )
					for i in range(5):
						# x = *xPointer
						VMOVAPD( ymm_x[i], [xPointer + i * 32] )
						# t = (x * (2/Pi)) + magicBias
						VMULPD( ymm_t[i], ymm_x[i], ymm_two_over_pi )
						VADDPD( ymm_t[i], ymm_t[i], ymm_magic_bias )

					for i in range(5):
						xmm_n_lo = SSERegister()
						xmm_n_hi = SSERegister()
						# n = (int(t) % 4) << 62
						VEXTRACTF128( xmm_n_hi, ymm_t[i], 1 )
						VPSLLQ( xmm_n_lo, ymm_t[i].get_oword(), 62 )
						VMOVDQA( n[i].get_low(), xmm_n_lo )
						VPSLLQ( xmm_n_hi, xmm_n_hi, 62 )
						VMOVDQA( n[i].get_high(), xmm_n_hi )
						# t -= magicBias
						VSUBPD( ymm_t[i], ymm_t[i], ymm_magic_bias )

					for i in range(5):
						# x += t * minusPio2_hi
						ymm_temp = AVXRegister()
						VMULPD( ymm_temp, ymm_t[i], minusPio2_hi )
						VADDPD( ymm_x[i], ymm_x[i], ymm_temp )

					for i in range(5):
						ymm_temp = AVXRegister()
						# x += t * minusPio2_me
						ymm_a = ymm_x[i]
						ymm_x[i] = AVXRegister()
						VMULPD( ymm_temp, ymm_t[i], minusPio2_me )
						VADDPD( ymm_x[i], ymm_a, ymm_temp )
						ymm_z = AVXRegister()
						VSUBPD( ymm_z, ymm_x[i], ymm_a )
						VSUBPD( ymm_temp, ymm_temp, ymm_z )
						# x += t * minusPio2_lo
						VMULPD( ymm_t[i], ymm_t[i], minusPio2_lo )
						VADDPD( ymm_t[i], ymm_t[i], ymm_temp )
						VADDPD( ymm_x[i], ymm_x[i], ymm_t[i] )

					ymm_sqrx = [AVXRegister() for i in range(5)]
					for i in range(5):
						# sqrx = x * x
						VMOVAPD( x[i], ymm_x[i] )
						VMULPD( ymm_sqrx[i], ymm_x[i], ymm_x[i] )


					ymm_sin = [AVXRegister() for i in range(5)]
					ymm_cos = [AVXRegister() for i in range(5)]

					ymm_c14 = AVXRegister()
					ymm_c12 = AVXRegister()
					LOAD.CONSTANT( ymm_c14, c14 )
					LOAD.CONSTANT( ymm_c12, c12 )
					for i in range(5):
						VFMADDPD( ymm_cos[i], ymm_c14, ymm_sqrx[i], ymm_c12 )

					ymm_c13 = AVXRegister()
					ymm_c11 = AVXRegister()
					LOAD.CONSTANT( ymm_c13, c13 )
					LOAD.CONSTANT( ymm_c11, c11 )
					for i in range(5):
						VFMADDPD( ymm_sin[i], ymm_c13, ymm_sqrx[i], ymm_c11 )

					def HORNER_STEP(acc, coef):
						ymm_c = AVXRegister()
						LOAD.CONSTANT( ymm_c, coef )
						for i in range(5):
							VFMADDPD( acc[i], acc[i], ymm_sqrx[i], ymm_c )

					HORNER_STEP(ymm_cos, c10 )
					HORNER_STEP(ymm_sin, c9 )
					HORNER_STEP(ymm_cos, c8 )
					HORNER_STEP(ymm_sin, c7 )
					HORNER_STEP(ymm_cos, c6 )
					HORNER_STEP(ymm_sin, c5 )
					HORNER_STEP(ymm_cos, c4 )
					HORNER_STEP(ymm_sin, c3 )
					HORNER_STEP(ymm_cos, c2 )

					ymm_c0 = AVXRegister()
					LOAD.CONSTANT( ymm_c0, c0 )
					for i in range(5):
						VMULPD( ymm_sin[i], ymm_sqrx[i] )
						VFMADDPD( ymm_cos[i], ymm_cos[i], ymm_sqrx[i], ymm_c0 )
						ymm_x = AVXRegister()
						VMOVAPD( ymm_x, x[i] )
						VFMADDPD( ymm_sin[i], ymm_sin[i], ymm_x, ymm_x )

					ymm_sign_mask = AVXRegister()
					LOAD.CONSTANT( ymm_sign_mask, signMask )
					for i in range(5):
						ymm_n = AVXRegister()
						VMOVAPD( ymm_n, n[i] )
						ymm_sign = AVXRegister()
						VANDPD( ymm_sign, ymm_n, ymm_sign_mask )
						VANDNPD( ymm_n, ymm_sign_mask, ymm_n )
						# n = !(n & 1)
						VCMPEQPD( ymm_n, ymm_n, ymm_sign )
						VBLENDVPD( ymm_sin[i], ymm_cos[i], ymm_sin[i], ymm_n )
						VXORPD( ymm_sin[i], ymm_sign )
						VMOVUPD( [yPointer + 32 * i], ymm_sin[i].get_oword() )
						VEXTRACTF128( [yPointer + 32 * i + 16], ymm_sin[i], 1 )

				Map_V64f_V64f(SCALAR_SIN, VECTOR_SIN, xPointer, yPointer, length, 32, 20)

				return codegen.end_function()

def Tan_V64f_V64f_Bulldozer(codegen, function_signature, module, function, inputs, outputs, arguments):
	if codegen.abi.name in ['x64-sysv', 'x64-ms']:
		if module == 'Math':
			if function == 'Tan':
				x_argument = arguments[0]
				y_argument = arguments[1]
				length_argument = arguments[2]

				x_type = x_argument.get_type().get_primitive_type()
				y_type = y_argument.get_type().get_primitive_type()

				if not x_type.is_floating_point() or not y_type.is_floating_point():
					return

				x_size = x_type.get_size(codegen.abi)
				y_size = y_type.get_size(codegen.abi)

				if x_size != 8 or y_size != 8:
					return

				parameters = [x_argument, y_argument, length_argument]
				codegen.begin_function(function_signature, parameters, 'Bulldozer')

				xPointer = GeneralPurposeRegister64()
				yPointer = GeneralPurposeRegister64()
				length = GeneralPurposeRegister64()

				LOAD.PARAMETER( xPointer, x_argument )
				LOAD.PARAMETER( yPointer, y_argument )
				LOAD.PARAMETER( length, length_argument )

				def SCALAR_TAN(xPointer, yPointer):
					minusPio2_hi = Constant.float64x2('-0x1.921FB54440000p+0')
					minusPio2_me = Constant.float64x2('-0x1.68C234C4C8000p-39')
					minusPio2_lo = Constant.float64x2( '0x1.9D747F23E32EDp-79')
					twoOPi = Constant.float64x2('0x1.45F306DC9C883p-1')
					magicBias = Constant.float64x2('0x1.8000000000000p+52')
					half  = Constant.float64x2( '0x1.0000000000000p-1')
					one = Constant.float64x2( '0x1.0000000000000p+0')

					c2  = Constant.float64x2('-0x1.0000000000000p-1')
					c3  = Constant.float64x2('-0x1.5555555555546p-3')
					c4  = Constant.float64x2( '0x1.555555555554Bp-5')
					c5  = Constant.float64x2( '0x1.111111110F51Ep-7')
					c6  = Constant.float64x2('-0x1.6C16C16C15038p-10')
					c7  = Constant.float64x2('-0x1.A01A019BB92C0p-13')
					c8  = Constant.float64x2( '0x1.A01A019C94874p-16')
					c9  = Constant.float64x2( '0x1.71DE3535C8A8Ap-19')
					c10 = Constant.float64x2('-0x1.27E4F7F65104Fp-22')
					c11 = Constant.float64x2('-0x1.AE5E38936D046p-26')
					c12 = Constant.float64x2( '0x1.1EE9DF6693F7Ep-29')
					c13 = Constant.float64x2( '0x1.5D8711D281543p-33')
					c14 = Constant.float64x2('-0x1.8FA87EF79AE3Fp-37')

					exponent_mask = Constant.uint64x2(0x7FF0000000000000L)

					# x = *xPointer
					xmm_x = SSERegister()
					VMOVSD( xmm_x, [xPointer] )
					# t = (x * (2/Pi)) + magicBias
					xmm_t = SSERegister()
					VMULPD( xmm_t, xmm_x, twoOPi )
					VADDPD( xmm_t, xmm_t, magicBias )
					# n = (int(t) % 4) << 63
					xmm_n = SSERegister()
					VPSLLQ( xmm_n, xmm_t, 63 )
					# t -= magicBias
					VSUBPD( xmm_t, xmm_t, magicBias )
					# x += t * minusPio2_hi
					xmm_temp = SSERegister()
					VMULPD( xmm_temp, xmm_t, minusPio2_hi )
					VADDPD( xmm_x, xmm_x, xmm_temp )
					# x += t * minusPio2_me
					xmm_a = SSERegister()
					VMOVAPS( xmm_a, xmm_x )
					xmm_temp = SSERegister()
					VMULPD( xmm_temp, xmm_t, minusPio2_me )
					VADDPD( xmm_x, xmm_temp )
					xmm_z = SSERegister()
					VSUBPD( xmm_z, xmm_x, xmm_a )
					VSUBPD( xmm_temp, xmm_temp, xmm_z )
					# x += t * minusPio2_lo
					VMULPD( xmm_t, xmm_t, minusPio2_lo )
					VADDPD( xmm_t, xmm_t, xmm_temp )
					VADDPD( xmm_x, xmm_x, xmm_t )

					# sqrx = x * x
					xmm_sqrx = SSERegister()
					VMULPD( xmm_sqrx, xmm_x, xmm_x )

					xmm_sin = SSERegister()
					xmm_cos = SSERegister()
					LOAD.CONSTANT( xmm_cos, c14 )
					LOAD.CONSTANT( xmm_sin, c13 )

					def HORNER_STEP(acc, coef):
						VFMADDPD( acc, acc, xmm_sqrx, coef )

					HORNER_STEP(xmm_cos, c12 )
					HORNER_STEP(xmm_sin, c11 )
					HORNER_STEP(xmm_cos, c10 )
					HORNER_STEP(xmm_sin, c9 )
					HORNER_STEP(xmm_cos, c8 )
					HORNER_STEP(xmm_sin, c7 )
					HORNER_STEP(xmm_cos, c6 )
					HORNER_STEP(xmm_sin, c5 )
					HORNER_STEP(xmm_cos, c4 )
					HORNER_STEP(xmm_sin, c3 )
					HORNER_STEP(xmm_cos, c2 )
					VMULPD( xmm_sin, xmm_sin, xmm_sqrx )
					VFMADDPD( xmm_cos, xmm_cos, xmm_sqrx, one )
					VFMADDPD( xmm_sin, xmm_sin, xmm_x, xmm_x )

					xmm_p = SSERegister()
					xmm_q = SSERegister()
					VXORPD( xmm_sin, xmm_sin, xmm_n )
					VBLENDVPD( xmm_p, xmm_sin, xmm_cos, xmm_n )
					VBLENDVPD( xmm_q, xmm_cos, xmm_sin, xmm_n )
					xmm_tan = SSERegister()
					# VDIVPD( xmm_tan, xmm_p, xmm_q )

					xmm_exponent_mask = SSERegister()
					LOAD.CONSTANT(xmm_exponent_mask, exponent_mask)

					xmm_q_exponent = SSERegister()
					VANDPD( xmm_q_exponent, xmm_q, xmm_exponent_mask )
					VXORPD( xmm_q_exponent, xmm_q_exponent, xmm_exponent_mask )
					VMULPD( xmm_q_exponent, half )
					xmm_q_mantissa = SSERegister()
					VANDNPD( xmm_q_mantissa, xmm_exponent_mask, xmm_q )
					VORPS( xmm_q_mantissa, xmm_q_mantissa, one )

					xmm_q_mantissa_32f = SSERegister()
					VCVTPD2PS( xmm_q_mantissa_32f, xmm_q_mantissa )
					VRCPPS( xmm_q_mantissa_32f, xmm_q_mantissa_32f )
					xmm_q_mantissa_reciprocal = SSERegister()
					VCVTPS2PD( xmm_q_mantissa_reciprocal, xmm_q_mantissa_32f )

					xmm_epsilon = SSERegister()
					VFNMADDPD( xmm_epsilon, xmm_q_mantissa_reciprocal, xmm_q_mantissa, one )
					VFMADDPD( xmm_q_mantissa_reciprocal, xmm_q_mantissa_reciprocal, xmm_epsilon, xmm_q_mantissa_reciprocal )
					VFNMADDPD( xmm_epsilon, xmm_q_mantissa_reciprocal, xmm_q_mantissa, one )
					VFMADDPD( xmm_q_mantissa_reciprocal, xmm_q_mantissa_reciprocal, xmm_epsilon, xmm_q_mantissa_reciprocal )
					VFNMADDPD( xmm_epsilon, xmm_q_mantissa_reciprocal, xmm_q_mantissa, one )
					VFMADDPD( xmm_q_mantissa_reciprocal, xmm_q_mantissa_reciprocal, xmm_epsilon, xmm_q_mantissa_reciprocal )

					xmm_q_reciprocal = SSERegister()
					VMULPD( xmm_q_reciprocal, xmm_q_mantissa_reciprocal, xmm_q_exponent )

					VMULPD( xmm_tan, xmm_p, xmm_q_reciprocal )
					VFNMADDPD( xmm_epsilon, xmm_q, xmm_tan, xmm_p )
					VFMADDPD( xmm_tan, xmm_epsilon, xmm_q_reciprocal, xmm_tan )

					VMOVSD( [yPointer], xmm_tan )

				def VECTOR_TAN(xPointer, yPointer):
					minusPio2_hi = Constant.float64x4('-0x1.921FB54440000p+0')
					minusPio2_me = Constant.float64x4('-0x1.68C234C4C8000p-39')
					minusPio2_lo = Constant.float64x4( '0x1.9D747F23E32EDp-79')
					twoOPi = Constant.float64x4('0x1.45F306DC9C883p-1')
					magicBias = Constant.float64x4('0x1.8000000000000p+52')

					half  = Constant.float64x4( '0x1.0000000000000p-1')
					one  = Constant.float64x4( '0x1.0000000000000p+0')
					c0  = Constant.float64x4( '0x1.0000000000000p+0')
					c2  = Constant.float64x4('-0x1.0000000000000p-1')
					c3  = Constant.float64x4('-0x1.5555555555546p-3')
					c4  = Constant.float64x4( '0x1.555555555554Bp-5')
					c5  = Constant.float64x4( '0x1.111111110F51Ep-7')
					c6  = Constant.float64x4('-0x1.6C16C16C15038p-10')
					c7  = Constant.float64x4('-0x1.A01A019BB92C0p-13')
					c8  = Constant.float64x4( '0x1.A01A019C94874p-16')
					c9  = Constant.float64x4( '0x1.71DE3535C8A8Ap-19')
					c10 = Constant.float64x4('-0x1.27E4F7F65104Fp-22')
					c11 = Constant.float64x4('-0x1.AE5E38936D046p-26')
					c12 = Constant.float64x4( '0x1.1EE9DF6693F7Ep-29')
					c13 = Constant.float64x4( '0x1.5D8711D281543p-33')
					c14 = Constant.float64x4('-0x1.8FA87EF79AE3Fp-37')

					exponent_mask = Constant.uint64x4(0x7FF0000000000000L)

					signMask = Constant.float64x4('-0x0.0000000000000p+0')

					ymm_x = [AVXRegister() for i in range(5)]
					ymm_t = [AVXRegister() for i in range(5)]
					n = [LocalVariable(AVXRegister) for i in range(5)]
					x = [LocalVariable(AVXRegister) for i in range(5)]

					ymm_two_over_pi = AVXRegister()
					ymm_magic_bias = AVXRegister()
					LOAD.CONSTANT( ymm_two_over_pi, twoOPi )
					LOAD.CONSTANT( ymm_magic_bias, magicBias )
					for i in range(5):
						# x = *xPointer
						VMOVAPD( ymm_x[i], [xPointer + i * 32] )
						# t = (x * (2/Pi)) + magicBias
						VMULPD( ymm_t[i], ymm_x[i], ymm_two_over_pi )
						VADDPD( ymm_t[i], ymm_t[i], ymm_magic_bias )

					for i in range(5):
						xmm_n_lo = SSERegister()
						xmm_n_hi = SSERegister()
						# n = (int(t) % 4) << 62
						VEXTRACTF128( xmm_n_hi, ymm_t[i], 1 )
						VPSLLQ( xmm_n_lo, ymm_t[i].get_oword(), 63 )
						VMOVDQA( n[i].get_low(), xmm_n_lo )
						VPSLLQ( xmm_n_hi, xmm_n_hi, 63 )
						VMOVDQA( n[i].get_high(), xmm_n_hi )
						# t -= magicBias
						VSUBPD( ymm_t[i], ymm_t[i], ymm_magic_bias )

					for i in range(5):
						# x += t * minusPio2_hi
						ymm_temp = AVXRegister()
						VMULPD( ymm_temp, ymm_t[i], minusPio2_hi )
						VADDPD( ymm_x[i], ymm_x[i], ymm_temp )

					for i in range(5):
						ymm_temp = AVXRegister()
						# x += t * minusPio2_me
						ymm_a = ymm_x[i]
						ymm_x[i] = AVXRegister()
						VMULPD( ymm_temp, ymm_t[i], minusPio2_me )
						VADDPD( ymm_x[i], ymm_a, ymm_temp )
						ymm_z = AVXRegister()
						VSUBPD( ymm_z, ymm_x[i], ymm_a )
						VSUBPD( ymm_temp, ymm_temp, ymm_z )
						# x += t * minusPio2_lo
						VMULPD( ymm_t[i], ymm_t[i], minusPio2_lo )
						VADDPD( ymm_t[i], ymm_t[i], ymm_temp )
						VADDPD( ymm_x[i], ymm_x[i], ymm_t[i] )

					ymm_sqrx = [AVXRegister() for i in range(5)]
					for i in range(5):
						# sqrx = x * x
						VMOVAPD( x[i], ymm_x[i] )
						VMULPD( ymm_sqrx[i], ymm_x[i], ymm_x[i] )


					ymm_sin = [AVXRegister() for i in range(5)]
					ymm_cos = [AVXRegister() for i in range(5)]

					ymm_c14 = AVXRegister()
					ymm_c12 = AVXRegister()
					LOAD.CONSTANT( ymm_c14, c14 )
					LOAD.CONSTANT( ymm_c12, c12 )
					for i in range(5):
						VFMADDPD( ymm_cos[i], ymm_c14, ymm_sqrx[i], ymm_c12 )

					ymm_c13 = AVXRegister()
					ymm_c11 = AVXRegister()
					LOAD.CONSTANT( ymm_c13, c13 )
					LOAD.CONSTANT( ymm_c11, c11 )
					for i in range(5):
						VFMADDPD( ymm_sin[i], ymm_c13, ymm_sqrx[i], ymm_c11 )

					def HORNER_STEP(acc, coef):
						ymm_c = AVXRegister()
						LOAD.CONSTANT( ymm_c, coef )
						for i in range(5):
							VFMADDPD( acc[i], acc[i], ymm_sqrx[i], ymm_c )

					HORNER_STEP(ymm_cos, c10 )
					HORNER_STEP(ymm_sin, c9 )
					HORNER_STEP(ymm_cos, c8 )
					HORNER_STEP(ymm_sin, c7 )
					HORNER_STEP(ymm_cos, c6 )
					HORNER_STEP(ymm_sin, c5 )
					HORNER_STEP(ymm_cos, c4 )
					HORNER_STEP(ymm_sin, c3 )
					HORNER_STEP(ymm_cos, c2 )

					ymm_c0 = AVXRegister()
					LOAD.CONSTANT( ymm_c0, c0 )
					for i in range(5):
						VMULPD( ymm_sin[i], ymm_sqrx[i] )
						VFMADDPD( ymm_cos[i], ymm_cos[i], ymm_sqrx[i], ymm_c0 )
						ymm_x = AVXRegister()
						VMOVAPD( ymm_x, x[i] )
						VFMADDPD( ymm_sin[i], ymm_sin[i], ymm_x, ymm_x )

					# ymm_sign_mask = AVXRegister()
					# LOAD.CONSTANT( ymm_sign_mask, signMask )

					ymm_p = [AVXRegister() for i in range(5)]
					ymm_q = [AVXRegister() for i in range(5)]
					for i in range(5):
						ymm_n = AVXRegister()
						VMOVAPD( ymm_n, n[i] )
						# ymm_sign = AVXRegister()
						# VANDPD( ymm_sign, ymm_n, ymm_sign_mask )
						# VANDNPD( ymm_n, ymm_sign_mask, ymm_n )
						# n = !(n & 1)
						# VCMPEQPD( ymm_n, ymm_n, ymm_sign )
						# VBLENDVPD( ymm_sin[i], ymm_cos[i], ymm_sin[i], ymm_n )
						# VXORPD( ymm_sin[i], ymm_sign )

						VXORPD( ymm_sin[i], ymm_sin[i], ymm_n )
						VBLENDVPD( ymm_p[i], ymm_sin[i], ymm_cos[i], ymm_n )
						VBLENDVPD( ymm_q[i], ymm_cos[i], ymm_sin[i], ymm_n )

					ymm_exponent_mask = AVXRegister()
					ymm_one = AVXRegister()
					VMOVAPD(ymm_exponent_mask, exponent_mask)
					VMOVAPD(ymm_one, one)
					for i in range(5):
						ymm_tan = AVXRegister()
						# VDIVPD( ymm_tan, ymm_p[i], ymm_q[i] )

						ymm_q_exponent = AVXRegister()
						VANDPD( ymm_q_exponent, ymm_q[i], ymm_exponent_mask )
						VXORPD( ymm_q_exponent, ymm_q_exponent, ymm_exponent_mask )
						VMULPD( ymm_q_exponent, half )
						ymm_q_mantissa = AVXRegister()
						VANDNPD( ymm_q_mantissa, ymm_exponent_mask, ymm_q[i] )
						VORPS( ymm_q_mantissa, ymm_q_mantissa, ymm_one )

						xmm_q_mantissa_32f = SSERegister()
						VCVTPD2PS( xmm_q_mantissa_32f, ymm_q_mantissa )
						VRCPPS( xmm_q_mantissa_32f, xmm_q_mantissa_32f )
						ymm_q_mantissa_reciprocal = AVXRegister()
						VCVTPS2PD( ymm_q_mantissa_reciprocal, xmm_q_mantissa_32f )

						ymm_epsilon = AVXRegister()
						VFNMADDPD( ymm_epsilon, ymm_q_mantissa_reciprocal, ymm_q_mantissa, ymm_one )
						VFMADDPD( ymm_q_mantissa_reciprocal, ymm_q_mantissa_reciprocal, ymm_epsilon, ymm_q_mantissa_reciprocal )
						VFNMADDPD( ymm_epsilon, ymm_q_mantissa_reciprocal, ymm_q_mantissa, ymm_one )
						VFMADDPD( ymm_q_mantissa_reciprocal, ymm_q_mantissa_reciprocal, ymm_epsilon, ymm_q_mantissa_reciprocal )
						VFNMADDPD( ymm_epsilon, ymm_q_mantissa_reciprocal, ymm_q_mantissa, ymm_one )
						VFMADDPD( ymm_q_mantissa_reciprocal, ymm_q_mantissa_reciprocal, ymm_epsilon, ymm_q_mantissa_reciprocal )

						ymm_q_reciprocal = AVXRegister()
						VMULPD( ymm_q_reciprocal, ymm_q_mantissa_reciprocal, ymm_q_exponent )

						VMULPD( ymm_tan, ymm_p[i], ymm_q_reciprocal )
						VFNMADDPD( ymm_epsilon, ymm_q[i], ymm_tan, ymm_p[i] )
						VFMADDPD( ymm_tan, ymm_epsilon, ymm_q_reciprocal, ymm_tan )

						VMOVUPD( [yPointer + 32 * i], ymm_tan.get_oword() )
						VEXTRACTF128( [yPointer + 32 * i + 16], ymm_tan, 1 )

				Map_V64f_V64f(SCALAR_TAN, VECTOR_TAN, xPointer, yPointer, length, 32, 20)

				return codegen.end_function()

